(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    846510,      14996]
NotebookOptionsPosition[    839004,      14838]
NotebookOutlinePosition[    839347,      14853]
CellTagsIndexPosition[    839304,      14850]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Copyright (c) [2019] Madeline Hamilton, Pavel Nadolsky \
(nadolsky@smu.edu)\n\nPermission is hereby granted, free of charge, to any \
person obtaining a copy\nof this software and associated documentation files \
(the \"Software\"), to deal\nin the Software without restriction, including \
without limitation the rights\nto use, copy, modify, merge, publish, \
distribute, sublicense, and/or sell\ncopies of the Software, and to permit \
persons to whom the Software is\nfurnished to do so, subject to the following \
conditions:\n\n1. The above copyright notice, citation policy, permission \
notice, and program description \nshall be included in all copies or \
substantial portions of the Software.\n\n2. You shall cite the following \
research article on which this program is based in the publications \nthat \
use any results obtained with this program:\n\n",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Bold"],
 StyleBox["Fast Ellipsoidal Fitting of Discrete Multi-Dimensional Data,  \nby \
Rafey Anwar, Madeline Hamilton, Pavel Nadolsky\nE-print: arXiv:1901.05511 \
[physics.data-an] (https://arxiv.org/abs/1901.05511)\nSMU Journal of \
Undergraduate Research: Vol. 5 , Article 4 \n\
https://doi.org/10.25172/jour.5.1.4",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontColor->RGBColor[0.6, 0.4, 0.2]],
 StyleBox["\n\nPermission notice: THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT \
WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE \
WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND \
NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE \
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF \
CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE \
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n \nProgram \
description: Reconstruction of a 5-dimensional ellipsoid from quasi-Gaussian \
data\nVersion 2019-01-10\n\n",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Bold"],
 StyleBox["This Mathematica notebook is the fastest available version of the \
ellipsoid reconstruction algorithm developed by Anwar, Hamilton and Nadolsky. \
\nIts inputs are a dataset and a desired confidence level, and its outputs \
are graphs visualizing the ellipses fitted to each orthogonal projection of \
the data, \nmatrices calculated using both the Covariance Matrix Method and \
the Convex Hull Method that characterize the reconstructed ellipsoids, \nand \
metrics that evaluate the quality of these ellipsoids.The notebook may be \
repurposed for any dataset and any confidence level, \ngiven that the data is \
entirely numerical takes the form of an array of equally sized arrays.\nThe \
notebook was developed for Mathematica 11.1 and is not guaranteed to work for \
earlier or later versions.", "Text",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Bold"]
}], "Input",
 CellChangeTimes->{{3.7560719011308856`*^9, 3.7560719251396637`*^9}, {
  3.7560719863919277`*^9, 3.756072055899104*^9}, {3.7561353318320932`*^9, 
  3.7561353606859703`*^9}, {3.7561356900971136`*^9, 3.756135690713403*^9}, {
  3.7940597577341986`*^9, 3.7940597685287247`*^9}, {3.794095053378705*^9, 
  3.7940950937931395`*^9}},ExpressionUUID->"2b72e9b6-19d2-49ca-bcad-\
7ca3c600975b"],

Cell[CellGroupData[{

Cell["Visual and Convex Hull Setup", "Section",
 CellChangeTimes->{{3.7560720799288225`*^9, 3.756072105362821*^9}, {
  3.7560721585911303`*^9, 3.756072167797488*^9}, {3.7560722958501186`*^9, 
  3.756072341230821*^9}, {3.7560725645883484`*^9, 3.7560725652186728`*^9}, {
  3.7560827121948957`*^9, 3.7560827148574343`*^9}, {3.7560828557271013`*^9, 
  3.756082858930272*^9}},ExpressionUUID->"9c0ed206-b84c-4484-9046-\
0eddbc6f2836"],

Cell[TextData[{
 StyleBox["This section sets up the style of the notebook's visuals. This may \
be edited to taste. Matrices necessary for the Convex Hull Method are also \
initialized in this cell, so this cell ", "Text",
  FontWeight->"Plain"],
 StyleBox["must ", "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["be executed before the fit.", "Text",
  FontWeight->"Plain"]
}], "Input",
 CellChangeTimes->{{3.7560724275360713`*^9, 3.756072551418564*^9}, {
  3.7560827349175453`*^9, 3.7560828066826506`*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"32e9448b-6481-4ae1-8304-61a7521b59ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Visual", " ", "setup"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"StringTake", "[", 
         RowBox[{"$Version", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "//", "ToExpression"}], "//",
        "Round"}], ",", "\[IndentingNewLine]", "6", ",", 
      RowBox[{
       RowBox[{"<<", "\"\<BarCharts`\>\""}], ";", 
       RowBox[{"<<", "\"\<Histograms`\>\""}], ";", 
       RowBox[{"<<", "\"\<PieCharts`\>\""}], ";", 
       RowBox[{"<<", "\"\<ErrorBarPlots`\>\""}], ";", 
       RowBox[{"SetOptions", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "Plot", ",", "ListPlot", ",", "ErrorListPlot", ",", "Graphics", ",",
            "ParametricPlot"}], "}"}], ",", 
         RowBox[{"BaseStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
            "16"}], "}"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", "7", ",", 
      RowBox[{"SetOptions", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "Plot", ",", "ListPlot", ",", "ErrorListPlot", ",", "Graphics", ",", 
          "ParametricPlot"}], "}"}], ",", 
        RowBox[{"BaseStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           "16"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "8", ",", 
      RowBox[{"SetOptions", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "Plot", ",", "ListPlot", ",", "ListLogLinearPlot", ",", "Graphics", 
          ",", "ParametricPlot"}], "}"}], ",", 
        RowBox[{"BaseStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           "16"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "9", ",", 
      RowBox[{"SetOptions", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "Plot", ",", "ListPlot", ",", "ListLogLinearPlot", ",", "Graphics", 
          ",", "ParametricPlot"}], "}"}], ",", 
        RowBox[{"BaseStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           "16"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "10", ",", 
      RowBox[{"SetOptions", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "Plot", ",", "ListPlot", ",", "ListLogPlot", ",", 
          "ListLogLinearPlot", ",", "Graphics", ",", "ParametricPlot"}], 
         "}"}], ",", 
        RowBox[{"BaseStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           "16"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "11", ",", 
      RowBox[{"SetOptions", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "Plot", ",", "ListPlot", ",", "ListLogPlot", ",", 
          "ListLogLinearPlot", ",", "Graphics", ",", "ParametricPlot"}], 
         "}"}], ",", 
        RowBox[{"BaseStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           "16"}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", "_", ",", 
      RowBox[{
       RowBox[{"<<", " ", "Graphics`Graphics`"}], ";", 
       RowBox[{"<<", "Graphics`FilledPlot`"}], ";"}]}], "\[IndentingNewLine]",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Matrices", " ", "necessary", " ", "for", " ", "Convex", " ", "Hull", " ",
      "Method"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CC", "=", 
     RowBox[{"(", GridBox[{
        {"0", "0", "2", "0", "0", "0"},
        {"0", 
         RowBox[{"-", "1"}], "0", "0", "0", "0"},
        {"2", "0", "0", "0", "0", "0"},
        {"0", "0", "0", "0", "0", "0"},
        {"0", "0", "0", "0", "0", "0"},
        {"0", "0", "0", "0", "0", "0"}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"U", ",", "L", ",", "V"}], "}"}], "=", 
     RowBox[{"SingularValueDecomposition", "[", "CC", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"U", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"U", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"U", "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{"U", "[", 
        RowBox[{"[", "6", "]"}], "]"}], ",", 
       RowBox[{"U", "[", 
        RowBox[{"[", "5", "]"}], "]"}], ",", 
       RowBox[{"U", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"V2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"V", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"V", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"V", "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{"V", "[", 
        RowBox[{"[", "6", "]"}], "]"}], ",", 
       RowBox[{"V", "[", 
        RowBox[{"[", "5", "]"}], "]"}], ",", 
       RowBox[{"V", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CC", "-", 
     RowBox[{"U", ".", "L", ".", 
      RowBox[{"Transpose", "[", "V", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CC", "-", 
     RowBox[{"U2", ".", "L", ".", 
      RowBox[{"Transpose", "[", "V2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"U", ".", 
     RowBox[{"Transpose", "[", "U", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"V", ".", 
     RowBox[{"Transpose", "[", "V", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "U", "]"}], ".", "U"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "V", "]"}], ".", "V"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cc1", "=", 
     RowBox[{"CC", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "3"}], ",", 
        RowBox[{"1", ";;", "3"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"u1", "=", 
     RowBox[{"U", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "3"}], ",", 
        RowBox[{"1", ";;", "3"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v1", "=", 
     RowBox[{"V", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "3"}], ",", 
        RowBox[{"1", ";;", "3"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"L", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "3"}], ",", 
        RowBox[{"1", ";;", "3"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"linv", "=", 
     RowBox[{"Inverse", "[", "l", "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.756072312008953*^9, 3.756072312984317*^9}, {
  3.7560723441290445`*^9, 3.7560723449448876`*^9}, {3.756072383665344*^9, 
  3.7560723949013023`*^9}, {3.7560828147423077`*^9, 
  3.7560828504166574`*^9}},ExpressionUUID->"ce4d1521-b14a-4278-9100-\
69a463c6c622"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialize Inputs", "Section",
 CellChangeTimes->{{3.7560816247647743`*^9, 3.75608162526423*^9}, {
  3.7561324291964755`*^9, 
  3.756132432200835*^9}},ExpressionUUID->"f4ec3887-773a-43bd-9d55-\
bdc532d57e65"],

Cell[TextData[StyleBox["In this section, the algorithm's two main inputs, the \
dataset and the confidence level, are initialized. This is cell must be \
adapted if one wishes to repurpose this notebook for their own analyses.\nThe \
dataset \"data\" must be an array of arrays: all observations should be \
arrays with an equal number of elements, and these arrays should in turn be \
stored in an array. All data must be numerical. \"nsigma\" is a number that \
represents the confidence level outlined by the ellipsoid. Below are the \
proper \"nsigma\" values for the most commonly used confidence levels. A Z \
Table can be used to find the z-score of any other confidence level.\n\n68% \
confidence: 1.\n90% confidence: 1.645\n95% confidence: 1.96\n99% confidence: \
2.575", "Text",
 FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.756081709623773*^9, 3.7560825932150173`*^9}, {
  3.756125273104557*^9, 3.756125273385741*^9}, {3.7561255542111077`*^9, 
  3.756125613586032*^9}, {3.756126892385232*^9, 3.756126901948185*^9}, {
  3.7561271610326157`*^9, 3.7561271629343348`*^9}, {3.756132444942395*^9, 
  3.7561324458139534`*^9}},ExpressionUUID->"7224941d-0dea-4b09-9213-\
b1c3caaa248d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"plist", " ", "initialization"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"file", "=", " ", 
     RowBox[{"OpenRead", "[", "\"\<data.txt\>\"", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"headers", "=", 
     RowBox[{"Read", "[", 
      RowBox[{"file", ",", 
       RowBox[{"{", 
        RowBox[{"String", ",", "String"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    StyleBox[
     RowBox[{"data", "=", 
      RowBox[{"ReadList", "[", 
       RowBox[{"file", ",", 
        RowBox[{"LF", "[", 
         RowBox[{
         "Number", ",", "Number", ",", "Number", ",", "Number", ",", 
          "Number"}], "]"}]}], "]"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"<", 
        RowBox[{
         RowBox[{"-", " ", "in"}], " ", "this", " ", "line"}]}], ",", " ", 
       RowBox[{
       "the", " ", "number", " ", "of", " ", "\"\<Number\>\"", " ", "entries",
         " ", "must", " ", "match", " ", "the", " ", "number", " ", "of", " ",
         "your", " ", "dimensions"}]}], " ", "*)"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["\[IndentingNewLine]",
     FontColor->RGBColor[1, 0, 0]], 
    RowBox[{"Close", "[", "file", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"nsigma", " ", "initialization"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nsigma", "=", " ", "1"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.756081660921238*^9, 3.7560816618907795`*^9}, 
   3.756081704120284*^9, {3.7560826275230184`*^9, 3.7560826339495897`*^9}, {
   3.756082917214509*^9, 3.756082964943008*^9}, {3.7561269101024523`*^9, 
   3.7561269363648944`*^9}, {3.7561270820399227`*^9, 3.756127084564599*^9}, {
   3.756127153636977*^9, 3.7561271559506893`*^9}, {3.7561659984175806`*^9, 
   3.756165999025782*^9}, {3.7941342160611725`*^9, 3.794134222539627*^9}, {
   3.7941342673020163`*^9, 3.794134276451065*^9}, {3.794135764519732*^9, 
   3.794135815272439*^9}, {3.794135913362035*^9, 
   3.7941359163564863`*^9}},ExpressionUUID->"155d6491-2b35-4e0b-9c77-\
b4a6100fa3d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Normalization", "Section",
 CellChangeTimes->{{3.7560826868757763`*^9, 
  3.7560826952854896`*^9}},ExpressionUUID->"f0dba2db-d99d-4dea-ac1a-\
4a39d912fae3"],

Cell[TextData[StyleBox[" In this section, the data is normalized to ensure \
optimal results. This cell is not essential and may be skipped. However, if \
the scales of the input data's dimensions differ significantly, executing \
this cell is recommended. \nThe data is normalized such that the mean value \
across each dimension is exactly 1.  ", "Text",
 FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.7560830765696554`*^9, 3.7560831357220445`*^9}, {
  3.756083170981666*^9, 3.7560833967852182`*^9}, {3.7560834528118467`*^9, 
  3.756083469343088*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"b54ed4d0-2d3e-49a5-a77b-ca805af63a4e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MeanX", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"data", "/.", 
       RowBox[{
        RowBox[{"LF", "[", "a__", "]"}], "\[RuleDelayed]", 
        RowBox[{
         RowBox[{"{", "a", "}"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], "//", "Mean"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", 
        RowBox[{"data", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reldata", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"data", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "/.", 
          RowBox[{"LF", "\[RuleDelayed]", "List"}]}], ")"}], "/", "MeanX"}], 
       ")"}], "/.", 
      RowBox[{"List", "\[RuleDelayed]", "LF"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "data", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"relMeanX", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "MeanX", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.756083404754713*^9, 3.756083449567791*^9}, {
  3.756127145206465*^9, 
  3.756127147293414*^9}},ExpressionUUID->"a35e4336-234a-41ea-a6cd-\
5a11b5182b68"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Preparation for Reconstruction", "Section",
 CellChangeTimes->{{3.7561568276050243`*^9, 
  3.7561568441468506`*^9}},ExpressionUUID->"55ecc271-3bfc-4aa6-95ae-\
657cf82f42a1"],

Cell[TextData[StyleBox["Here, the final steps in preparing the algorithm's \
inputs are performed. \"dsmear\" is a variable related to the Convex Hull \
method; it is a measure to suppress the method's tendency to randomly \
fluctuate in the presence of outliers and noise. If \"dsmear\" is set to some \
positive value rather than 0, the method fits an ellipse not to the convex \
hull, but to the band of width (1\[PlusMinus]dsmear) around the boundary of \
the fitted region. \"dsmear\" should be set to 0 if the \"default\" Convex \
Hull method is desired. Otherwise, values between 0.04 - 0.1 usually produce \
good results. \n\nIf the \"Data Normalization\" cell was executed, the rest \
of the cell does not need edited. If it was not executed, then the \"mean\" \
and \"plist\" variables will have to be edited before execution. \"mean\" \
must be supplied manually, as an array containing the mean of each of the \
data's columns. \"plist\" must be set to \"data\" rather than \"reldata\".", \
"Text",
 FontWeight->"Plain"]], "Input",
 CellChangeTimes->{{3.7561568484287314`*^9, 3.7561569889940825`*^9}, {
  3.7561645641009903`*^9, 3.7561646001372485`*^9}, {3.7561646521351166`*^9, 
  3.756164704898554*^9}, {3.756164809879922*^9, 3.756164825149325*^9}, {
  3.75616487888457*^9, 3.7561648809480076`*^9}, {3.7561649166893044`*^9, 
  3.7561652901995373`*^9}, {3.75616537810614*^9, 3.7561653846372766`*^9}, {
  3.756165424279812*^9, 3.75616542449043*^9}, {3.756165510823019*^9, 
  3.7561655586575875`*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"22e6b0f3-4b9e-45a0-94d6-5eee94976ad2"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dsmear", "=", "0.07"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mean", "=", "relMeanX"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Example", " ", "of", " ", "\"\<mean\>\"", " ", "for", " ", "non"}], "-", 
     RowBox[{"normalized", " ", "5"}], "-", 
     RowBox[{"dimensional", " ", 
      RowBox[{"data", ":", " ", 
       RowBox[{"{", 
        RowBox[{"1.65", ",", " ", ".7", ",", " ", "10.6", ",", " ", 
         RowBox[{"-", ".4"}], ",", " ", "4.11"}], "}"}]}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plist", "=", "reldata"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"plist", " ", "=", " ", "data"}], " ", "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.756165367890686*^9, 3.756165368054718*^9}, {
  3.7561655667861347`*^9, 3.7561655774957714`*^9}, {3.7561656147394094`*^9, 
  3.7561657007745495`*^9}, {3.756166720772954*^9, 3.7561667210114155`*^9}, {
  3.756226843384615*^9, 
  3.756226843534565*^9}},ExpressionUUID->"278a4f69-e2eb-4102-9d99-\
8887773e85d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Projection Reconstruction", "Section",
 CellChangeTimes->{{3.7561256786634007`*^9, 3.756125682845019*^9}, {
  3.756127775531188*^9, 
  3.7561277855216093`*^9}},ExpressionUUID->"f6526e91-7948-499d-9355-\
ef0a894166ef"],

Cell["\<\
This section examines each unique two-dimensional projection of the data and \
fits ellipses to these projections with both the Convex Hull Method and the \
Covariance Matrix Method. This cell produces graphical output: if the data is \
d-dimensional, then d*(d-1)*.5 graphs of each two-dimensional projection and \
its two fitted ellipses are generated.

This cell is completely automatic; no edits are needed regardless of whether \
or not the data was normalized.\
\>", "Text",
 CellChangeTimes->{{3.7561257534022207`*^9, 3.756125922960414*^9}, {
  3.756125970267251*^9, 3.7561262909762793`*^9}, {3.756127243911031*^9, 
  3.756127259390026*^9}, {3.756127790334236*^9, 3.7561279350959992`*^9}, {
  3.756165767142789*^9, 
  3.7561658187912464`*^9}},ExpressionUUID->"88a0ad96-b0a0-4ef1-8a76-\
895d11448d38"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", "=", " ", 
     RowBox[{"Length", "[", 
      RowBox[{"plist", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Reconstruct the ellipsoid's projections:\\naCM (correlation \
ellipse, solid red); aHull (convex hull, black dashed)\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aCM", ",", "aHull"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"d", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "-", "1"}], ")"}], "/", "2"}]}]}], "]"}], ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"d", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"d", "-", "1"}], ")"}], "/", "2"}]}]}], "]"}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "x1", ",", "y1", ",", "x0", ",", "y0", ",", "dx", ",", "dy", ",", 
       "xmin", ",", "xmax", ",", "ymin", ",", "ymax", ",", "\[Delta]x", ",", 
       "\[Delta]y", ",", "cosphi", ",", "phi", ",", "s02", ",", "xy", ",", 
       "oneZScore", ",", "a", ",", "id"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"ix", "=", "1"}], ",", 
        RowBox[{"ix", "\[LessEqual]", 
         RowBox[{"d", "-", "1"}]}], ",", 
        RowBox[{"ix", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"iy", "=", 
           RowBox[{"ix", "+", "1"}]}], ",", 
          RowBox[{"iy", "\[LessEqual]", "d"}], ",", 
          RowBox[{"iy", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<Plotting plane x\>\"", "<>", 
             RowBox[{"ToString", "[", "ix", "]"}], "<>", "\"\<x\>\"", "<>", 
             RowBox[{"ToString", "[", "iy", "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"id", "++"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"Mean", "-", 
             RowBox[{
             "subtract", " ", "the", " ", "data", " ", "and", " ", 
              "calculate", " ", "statistics", " ", "necessary", " ", "for", 
              " ", "both", " ", "ellipse"}], "-", 
             RowBox[{"fitting", " ", 
              RowBox[{"methods", "."}]}]}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"x1", "=", 
            RowBox[{"plist", "/.", 
             RowBox[{
              RowBox[{"LF", "[", "a__", "]"}], "\[RuleDelayed]", 
              RowBox[{
               RowBox[{"{", "a", "}"}], "[", 
               RowBox[{"[", "ix", "]"}], "]"}]}]}]}], ";", " ", 
           "\[IndentingNewLine]", 
           RowBox[{"y1", "=", 
            RowBox[{"plist", "/.", 
             RowBox[{
              RowBox[{"LF", "[", "a__", "]"}], "\[RuleDelayed]", 
              RowBox[{
               RowBox[{"{", "a", "}"}], "[", 
               RowBox[{"[", "iy", "]"}], "]"}]}]}]}], ";", "  ", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x0", ",", "y0"}], "}"}], "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"mean", "[", 
               RowBox[{"[", "ix", "]"}], "]"}], ",", 
              RowBox[{"mean", "[", 
               RowBox[{"[", "iy", "]"}], "]"}]}], "}"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<The center of the ellipse is at {\>\"", "<>", 
             RowBox[{"ToString", "[", "x0", "]"}], "<>", "\"\<,\>\"", "<>", 
             RowBox[{"ToString", "[", "y0", "]"}], "<>", "\"\<}\>\""}], "]"}],
            ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"dx", ",", " ", "dy"}], "}"}], " ", "=", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x1", "-", "x0"}], ",", " ", 
              RowBox[{"y1", " ", "-", " ", "y0"}]}], "}"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"xmin", ",", "xmax"}], "}"}], "=", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Min", "[", "#", "]"}], ",", 
                RowBox[{"Max", "[", "#", "]"}]}], "}"}], "&"}], "@", " ", 
             "x1"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"ymin", ",", "ymax"}], "}"}], "=", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Min", "[", "#", "]"}], ",", 
                RowBox[{"Max", "[", "#", "]"}]}], "}"}], "&"}], "@", " ", 
             "y1"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\[Delta]x", ",", " ", "\[Delta]y"}], "}"}], " ", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"StandardDeviation", "[", "x1", "]"}], ",", 
              RowBox[{"StandardDeviation", "[", "y1", "]"}]}], "}"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{
            "Fit", " ", "the", " ", "Covariance", " ", "Matrix", " ", 
             "ellipse"}], " ", "*)"}], "\[IndentingNewLine]", 
           RowBox[{"cosphi", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"Mean", "[", 
               RowBox[{"dx", " ", "dy"}], "]"}], "/", "\[Delta]x"}], "/", 
             "\[Delta]y"}]}], ";", "   ", "\[IndentingNewLine]", 
           RowBox[{"phi", "=", 
            RowBox[{"ArcCos", "[", "cosphi", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"z1x", ",", "z1y"}], "}"}], " ", "=", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"nsigma", "*", " ", "\[Delta]x"}], ",", " ", 
              RowBox[{"nsigma", "*", " ", "\[Delta]y"}]}], "}"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"s02", " ", "=", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "phi", "]"}], "2"]}], " ", ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"aCM", "[", 
             RowBox[{"[", "id", "]"}], "]"}], "=", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                FractionBox["1", 
                 RowBox[{
                  SuperscriptBox["\[Delta]x", "2"], " ", "s02"}]], ",", " ", 
                RowBox[{"-", 
                 FractionBox["cosphi", 
                  RowBox[{"\[Delta]x", " ", "\[Delta]y", " ", "s02"}]]}]}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["cosphi", 
                  RowBox[{"\[Delta]x", " ", "\[Delta]y", " ", "s02"}]]}], ",", 
                FractionBox["1", 
                 RowBox[{
                  SuperscriptBox["\[Delta]y", "2"], " ", "s02"}]]}], "}"}]}], 
             "}"}]}], ";", " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{
             "Fit", " ", "the", " ", "Convex", " ", "Hull", " ", "ellipse"}], 
             " ", "*)"}],
            Background->RGBColor[1, 0.925, 0.925]], "\[IndentingNewLine]", 
           RowBox[{"Print", "[", "\"\<-----------------------\>\"", "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"xy", " ", "=", " ", 
            RowBox[{"plist", "/.", 
             RowBox[{
              RowBox[{"LF", "[", "a__", "]"}], "\[RuleDelayed]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", "a", "}"}], "[", 
                 RowBox[{"[", "ix", "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"{", "a", "}"}], "[", 
                 RowBox[{"[", "iy", "]"}], "]"}]}], "}"}]}]}]}], ";", " ", 
           "\[IndentingNewLine]", 
           RowBox[{"zsmear", "=", 
            RowBox[{"1.0", "+", "dsmear"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"oneZScore", "=", " ", 
            RowBox[{"Select", "[", 
             RowBox[{"xy", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ">", 
                    RowBox[{"(", 
                    RowBox[{"x0", "-", " ", 
                    RowBox[{"zsmear", " ", "z1x"}]}], ")"}]}], ")"}], " ", "&&",
                    " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<", 
                    RowBox[{"(", 
                    RowBox[{"x0", "+", 
                    RowBox[{"zsmear", " ", "z1x"}]}], ")"}]}], ")"}]}], ")"}],
                  " ", "&&", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ">", 
                    RowBox[{"(", 
                    RowBox[{"y0", "-", 
                    RowBox[{"zsmear", " ", "z1y"}]}], ")"}]}], ")"}], " ", "&&",
                    " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", 
                    RowBox[{"(", 
                    RowBox[{"y0", "+", 
                    RowBox[{"zsmear", " ", "z1y"}]}], ")"}]}], ")"}]}], " ", 
                  ")"}]}], ")"}], "&"}]}], "]"}]}], ";", " ", 
           "\[IndentingNewLine]", 
           RowBox[{"cH", "=", 
            RowBox[{"ConvexHullMesh", "[", "oneZScore", "]"}]}], ";", " ", 
           "\[IndentingNewLine]", 
           RowBox[{"convexHullPoints", "=", 
            RowBox[{
             RowBox[{"Cases", "[", 
              RowBox[{
               RowBox[{"Show", "[", "cH", "]"}], ",", 
               RowBox[{
                RowBox[{"GraphicsComplex", "[", 
                 RowBox[{"pts_", ",", "___"}], "]"}], "\[RuleDelayed]", 
                "pts"}]}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Abs", "[", "dsmear", "]"}], ">", 
              SuperscriptBox["10", 
               RowBox[{"-", "4"}]]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"zsmear", "=", 
               RowBox[{"1.0", "-", "dsmear"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"oneZScore", "=", " ", 
               RowBox[{"Select", "[", 
                RowBox[{"xy", ",", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ">", 
                    RowBox[{"(", 
                    RowBox[{"x0", "-", " ", 
                    RowBox[{"zsmear", " ", "z1x"}]}], ")"}]}], ")"}], " ", "&&",
                     " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<", 
                    RowBox[{"(", 
                    RowBox[{"x0", "+", 
                    RowBox[{"zsmear", " ", "z1x"}]}], ")"}]}], ")"}]}], ")"}],
                     " ", "&&", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ">", 
                    RowBox[{"(", 
                    RowBox[{"y0", "-", 
                    RowBox[{"zsmear", " ", "z1y"}]}], ")"}]}], ")"}], " ", "&&",
                     " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", 
                    RowBox[{"(", 
                    RowBox[{"y0", "+", 
                    RowBox[{"zsmear", " ", "z1y"}]}], ")"}]}], ")"}]}], " ", 
                    ")"}]}], ")"}], "&"}]}], "]"}]}], ";", " ", 
              "\[IndentingNewLine]", 
              RowBox[{"cH", "=", 
               RowBox[{"ConvexHullMesh", "[", "oneZScore", "]"}]}], ";", " ", 
              RowBox[{"(*", " ", 
               RowBox[{
               "finding", " ", "convex", " ", "hull", " ", "of", " ", 
                "points"}], " ", "*)"}], "\[IndentingNewLine]", 
              RowBox[{"convexHullPoints", "=", 
               RowBox[{"Join", "[", 
                RowBox[{"convexHullPoints", ",", 
                 RowBox[{
                  RowBox[{"Cases", "[", 
                   RowBox[{
                    RowBox[{"Show", "[", "cH", "]"}], ",", 
                    RowBox[{
                    RowBox[{"GraphicsComplex", "[", 
                    RowBox[{"pts_", ",", "___"}], "]"}], "\[RuleDelayed]", 
                    "pts"}]}], "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";"}]}], " ", 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"pointsToFit", "=", " ", 
            RowBox[{"convexHullPoints", "/.", " ", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x_", ",", " ", "y_"}], "}"}], " ", "\[RuleDelayed]", 
              " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "-", "x0"}], ",", 
                RowBox[{"y", "-", "y0"}]}], "}"}]}]}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"d1", ",", "d2"}], "}"}], "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"pointsToFit", "/.", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"x_", ",", "y_"}], "}"}], "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                  SuperscriptBox["x", "2"], ",", 
                  RowBox[{"x", " ", "y"}], ",", " ", 
                  SuperscriptBox["y", "2"]}], "}"}]}]}], ",", 
              RowBox[{"pointsToFit", "/.", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"x_", ",", "y_"}], "}"}], "\[RuleDelayed]", 
                RowBox[{"{", "1", "}"}]}]}]}], "}"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"s11", ",", "s12", ",", "s21", ",", "s22"}], "}"}], "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"Transpose", "[", "d1", "]"}], ".", "d1"}], ",", 
              RowBox[{
               RowBox[{"Transpose", "[", "d1", "]"}], ".", "d2"}], ",", 
              RowBox[{
               RowBox[{"Transpose", "[", "d2", "]"}], ".", "d1"}], ",", 
              RowBox[{
               RowBox[{"Transpose", "[", "d2", "]"}], ".", "d2"}]}], "}"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"sv11", ",", "sv12", ",", "sv21", ",", "sv22"}], "}"}], 
            "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"linv", ".", 
               RowBox[{"Transpose", "[", "u1", "]"}], ".", "s11", ".", "v1"}],
               ",", 
              RowBox[{"linv", ".", 
               RowBox[{"Transpose", "[", "u1", "]"}], ".", "s12"}], ",", 
              RowBox[{"s21", ".", "v1"}], ",", "s22"}], "}"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", " ", 
            RowBox[{
             RowBox[{
              RowBox[{"Det", "[", "sv22", "]"}], "==", "0"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Print", "[", "\"\<Error: Singular sv22\>\"", "]"}], ",",
              "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"ES", "=", 
               RowBox[{"Sort", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Eigensystem", "[", 
                   RowBox[{"sv11", "-", 
                    RowBox[{"sv12", ".", 
                    RowBox[{"Inverse", "[", "sv22", "]"}], ".", "sv21"}]}], 
                   "]"}], "//", "Transpose"}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"#1", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ">", 
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}]}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"NumPositive", "=", 
               RowBox[{
                RowBox[{"Select", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Transpose", "[", "ES", "]"}], "[", 
                   RowBox[{"[", "1", "]"}], "]"}], ",", 
                  RowBox[{
                   RowBox[{"#", ">", "0"}], "&"}]}], "]"}], "//", 
                "Length"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"NumPositive", "\[NotEqual]", "1"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Print", "[", 
                 RowBox[{
                 "\"\<Error: number of positive eigenvalues is \>\"", ",", 
                  "NumPositive"}], "]"}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"av1", "=", 
                  RowBox[{"Transpose", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"ES", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "}"}], "]"}]}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"av2", "=", 
                  RowBox[{"-", 
                   RowBox[{
                    RowBox[{"Inverse", "[", "sv22", "]"}], ".", "sv21", ".", 
                    "av1"}]}]}], ";", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"a1", ",", "a2"}], "}"}], "=", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    StyleBox["v1",
                    FontColor->RGBColor[1, 0, 0]], ".", "av1"}], ",", "av2"}],
                    "}"}]}], ";", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"X0", ",", " ", "Y0"}], "}"}], " ", "=", " ", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}]}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{"NormFac", " ", "=", " ", "1"}], ";"}]}], 
               "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}],
            ";", "\[IndentingNewLine]", 
           RowBox[{"a", "=", 
            RowBox[{
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{"Join", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Transpose", "[", "a1", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", 
                   RowBox[{
                    RowBox[{"a2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "}"}], 
              "]"}], "//", "Flatten"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"constant2", " ", "=", " ", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "[", 
                RowBox[{"[", "6", "]"}], "]"}], ")"}], 
              RowBox[{"-", "1"}]]}]}], ";", " ", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"aHull", "[", 
             RowBox[{"[", "id", "]"}], "]"}], " ", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"constant2", " ", 
                 RowBox[{"a", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
                RowBox[{
                 StyleBox[
                  FractionBox["1", "2"],
                  FontColor->GrayLevel[0],
                  Background->RGBColor[1, 1, 0]], "constant2", " ", 
                 RowBox[{"a", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 StyleBox[
                  FractionBox["1", "2"],
                  FontColor->GrayLevel[0],
                  Background->RGBColor[1, 1, 0]], "constant2", " ", 
                 RowBox[{"a", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ",", 
                RowBox[{"constant2", " ", 
                 RowBox[{"a", "[", 
                  RowBox[{"[", "3", "]"}], "]"}]}]}], "}"}]}], "}"}]}], ";", 
           " ", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{
            "Visualize", " ", "the", " ", "projections", " ", "and", " ", 
             "their", " ", "fitted", " ", "ellipses"}], " ", "*)"}], 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"parametricPlot1", " ", "=", " ", 
            RowBox[{"ParametricPlot", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x0", "+", " ", 
                 RowBox[{"z1x", " ", 
                  RowBox[{"Cos", "[", "u", "]"}]}]}], ",", 
                RowBox[{"y0", "+", " ", 
                 RowBox[{"z1y", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"u", "+", "phi"}], "]"}]}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"u", ",", "0", ",", 
                RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"parametricPlotA", "=", 
            RowBox[{"ContourPlot", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"1", "-", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", GridBox[{
                    {
                    RowBox[{"x", "-", "x0"}], 
                    RowBox[{"y", "-", "y0"}]}
                    }], ")"}], ".", 
                    RowBox[{"aHull", "[", 
                    RowBox[{"[", "id", "]"}], "]"}], ".", 
                    RowBox[{"(", GridBox[{
                    {
                    RowBox[{"x", "-", "x0"}]},
                    {
                    RowBox[{"y", "-", "y0"}]}
                    }], ")"}]}], ")"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "\[Equal]", "0"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", 
              RowBox[{"ContourStyle", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"RGBColor", "[", 
                  RowBox[{"0.0", ",", "0", ",", "0"}], "]"}], ",", 
                 RowBox[{"Dashing", "[", 
                  RowBox[{"{", 
                   RowBox[{"0.06", ",", "0.02"}], "}"}], "]"}], ",", 
                 RowBox[{"Thickness", "[", "0.006", "]"}]}], "}"}]}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "100"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"parametricPlotB", "=", 
            RowBox[{"ContourPlot", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["nsigma", "2"], "+", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", GridBox[{
                    {
                    RowBox[{"x", "-", "x0"}], 
                    RowBox[{"y", "-", "y0"}]}
                    }], ")"}], ".", 
                    RowBox[{"aCM", "[", 
                    RowBox[{"[", "id", "]"}], "]"}], ".", 
                    RowBox[{"(", GridBox[{
                    {
                    RowBox[{"x", "-", "x0"}]},
                    {
                    RowBox[{"y", "-", "y0"}]}
                    }], ")"}]}], ")"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "\[Equal]", "0"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "xmin", ",", "xmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"y", ",", "ymin", ",", "ymax"}], "}"}], ",", 
              RowBox[{"ContourStyle", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"RGBColor", "[", 
                  RowBox[{"0.0", ",", "0.5", ",", "0.5"}], "]"}], ",", 
                 RowBox[{"Dashing", "[", 
                  RowBox[{"{", 
                   RowBox[{"0.02", ",", "0.02"}], "}"}], "]"}], ",", 
                 RowBox[{"Thickness", "[", "0.01", "]"}]}], "}"}]}], ",", 
              RowBox[{"PlotPoints", "\[Rule]", "100"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"pp2", "=", 
            RowBox[{"ListPlot", "[", 
             RowBox[{
              RowBox[{"plist", "/.", 
               RowBox[{
                RowBox[{"LF", "[", "a__", "]"}], "\[RuleDelayed]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"{", "a", "}"}], "[", 
                   RowBox[{"[", "ix", "]"}], "]"}], ",", 
                  RowBox[{
                   RowBox[{"{", "a", "}"}], "[", 
                   RowBox[{"[", "iy", "]"}], "]"}]}], "}"}]}]}], ",", " ", 
              RowBox[{"PlotMarkers", " ", "\[Rule]", " ", 
               RowBox[{"{", 
                RowBox[{"\"\<\[FilledCircle]\>\"", ",", "4"}], "}"}]}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
              RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
              RowBox[{"ImageSize", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"500", ",", "Automatic"}], "}"}]}], ",", 
              RowBox[{"Frame", "\[Rule]", "True"}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}]}], ",", 
              RowBox[{"Axes", "\[Rule]", "True"}], ",", 
              RowBox[{"FrameLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"\"\<\[Sigma]\>\"", "<>", 
                  RowBox[{"ToString", "[", "ix", "]"}], "<>", 
                  "\"\</\[LeftAngleBracket]\[Sigma]\>\"", "<>", 
                  RowBox[{"ToString", "[", "ix", "]"}], "<>", 
                  "\"\<\[RightAngleBracket]\>\""}], ",", 
                 RowBox[{"\"\<\[Sigma]\>\"", "<>", 
                  RowBox[{"ToString", "[", "iy", "]"}], "<>", 
                  "\"\</\[LeftAngleBracket]\[Sigma]\>\"", "<>", 
                  RowBox[{"ToString", "[", "iy", "]"}], "<>", 
                  "\"\<\[RightAngleBracket]\>\""}]}], "}"}]}]}], "]"}]}], ";",
            "  ", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"Show", "[", 
             RowBox[{
             "pp2", ",", "parametricPlot1", ",", "parametricPlotA", ",", " ", 
              "\[IndentingNewLine]", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"RGBColor", "[", 
                  RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
                 RowBox[{"Text", "[", 
                  RowBox[{"\"\<\[FivePointedStar]\>\"", ",", 
                   RowBox[{"{", 
                    RowBox[{"x0", ",", "y0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Dashing", "[", 
                  RowBox[{"{", 
                   RowBox[{"0.02", ",", "0.02"}], "}"}], "]"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "z1x"}], ",", 
                    RowBox[{"y0", "-", "z1y"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "z1x"}], ",", 
                    RowBox[{"y0", "-", "z1y"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "+", "z1x"}], ",", 
                    RowBox[{"y0", "+", "z1y"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "z1x"}], ",", 
                    RowBox[{"y0", "+", "z1y"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x0", "-", "z1x"}], ",", 
                    RowBox[{"y0", "-", "z1y"}]}], "}"}]}], "}"}], "]"}], 
                 ","}], "\[IndentingNewLine]", "}"}], "]"}], ",", " ", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"x0", "-", 
                    RowBox[{"1.2", "z1x"}]}], ",", 
                   RowBox[{"x0", "+", 
                    RowBox[{"1.2", "z1x"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"y0", "-", 
                    RowBox[{"1.2", " ", "z1y"}]}], ",", 
                   RowBox[{"y0", "+", 
                    RowBox[{"1.2", "z1y"}]}]}], "}"}]}], "}"}]}], " ", ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"x0", ",", "y0"}], "}"}]}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", 
               RowBox[{"\"\<Approximate \>\"", "<>", 
                RowBox[{"ToString", "[", "nsigma", "]"}], "<>", 
                "\"\<\[Sigma] countours\>\""}]}]}], "]"}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}]}], 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"For", " ", "iy"}], " ", "\[Rule]"}], " ", "*)"}], 
       "\[IndentingNewLine]", "]"}]}]}], 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"For", " ", "ix"}], " ", "\[Rule]"}], " ", "*)"}], 
    "\[IndentingNewLine]", "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{"Module", " ", "\[Rule]"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7561269642063856`*^9, 3.756126965762692*^9}, {
  3.756127011510805*^9, 3.7561270617303333`*^9}, {3.756127096523732*^9, 
  3.756127126162305*^9}, {3.756127170819415*^9, 3.756127560067517*^9}, {
  3.7561279877024164`*^9, 3.756128136516728*^9}, {3.7561282043224936`*^9, 
  3.7561282155347214`*^9}, {3.7561282742347035`*^9, 3.7561284428154497`*^9}, {
  3.756128587805685*^9, 3.7561285892466335`*^9}, {3.7561360084191074`*^9, 
  3.7561360604764752`*^9}, {3.756165745432156*^9, 3.756165747099862*^9}, {
  3.75616617013361*^9, 3.756166175646409*^9}, {3.7561662056705666`*^9, 
  3.7561662101698556`*^9}, {3.756166266436325*^9, 3.75616628374739*^9}, {
  3.7561663314361534`*^9, 3.7561663992092023`*^9}, {3.756166470594425*^9, 
  3.756166502806822*^9}, {3.7561665597370787`*^9, 3.7561665672958403`*^9}, {
  3.7561669223634167`*^9, 3.7561669707497697`*^9}, {3.7562266905639386`*^9, 
  3.756226712228367*^9}},ExpressionUUID->"ea1259eb-63cc-4e1a-bbe1-\
24d9ef121c34"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Reconstruct the ellipsoid's projections:\\naCM (correlation \
ellipse, solid red); aHull (convex hull, black dashed)\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.75622685525253*^9},ExpressionUUID->"bbc8415a-59dd-42cf-aa35-\
d518d360cc2e"],

Cell[BoxData["\<\"Plotting plane x1x2\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268552853327`*^9},ExpressionUUID->"5df7a4fa-40b3-42e6-aba6-\
118f9ad58dd1"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268552894125`*^9},ExpressionUUID->"a0112528-5da8-4d8c-b64f-\
b39351530cfb"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226855292313*^9},ExpressionUUID->"e395f6cc-642a-4105-b0a8-\
4e9f18408590"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxle2k4Ve37NtJgKCJDoUyZKpWS2U0pmYVQmSIpMo8RZSqEyByh0IjMkVQq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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd2nc8Vu//B3ArlRUpkpVZJCVkd2RmlBUpUUpmIrMSMhKFSCqyCyVbSDJC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       "]]},
     Annotation[#, "Charting`Private`Tag$24899#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmGc8l20bx1EqJRRyR0tJVkZEMs7KyiyrzIQUlUKyKkQqkVAUFUqKkozM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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1FV4EAQUBeCNrtEwBoMxumGM2ghpAelWQqVBSSVFUEFpkJbu7lA6FKQ7
BekUpFNA4t/Hw3/u83k4N7xF57qdAgMCAj4QMTcWsYlDXOIRnwQkJBGJSUIQ
SUlGclKQklSkJg1pCSYdIaQnA6FkJBNhZCacLGQlG9nJQU5ykZs85CUf+SlA
QQoRQWEiKUJRilGcEkQRTUlKUZoyMd0pSznKU4GKVKIyH1KFqlTjI6pTg5rU
ojZ1qEs96tOAhjSiMR/zCU1oSjOa8ymf8TktaEkrWtOGtrSjPR34gi/pSCc6
04WudOMrvqY7PehJL3rTh2/oy7f0oz/f8T0/MICB/MhPDGIwQxjKMIYzgpGM
4mdGM4axjGM8E5jIL0xiMlOYyjSmM4OZzGI2c5jLPOazgIUsYjFLWMoylrOC
laxiNWtYy6/8xjrWs4GNbGIzW9jKNrbzO3+wg538yS52s4e97GM/BzjIIQ5z
hKMc4zgnOMkpTvMXZzjL35zjPBe4yCUuc4WrXOM6N7jJP9ziNv9yh7vc4z4P
eMgjHvOEpzzjOf/xgpe84n9e84a3xIw/kFjEJg5xiUd8EpCQRCQmCUEkJRnJ
SUFKUpGaNKQlmHSEkJ4MhJKRTISRmXCykJVsZCcHOclFbvKQl3zkpwAFKUQE
hYmkCEUpRnFKEEU0JSlFacoEvv997wDWSomU
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$24919"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"1696.1191714131126`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$24919"}], ")"}]}], "-", 
                 RowBox[{"114.42573996081897`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$24920"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "114.42573996081897`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$24919"}], ")"}]}], "+", 
                 RowBox[{"2032.4221416033413`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$24920"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$24920"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$24919) (
         1696.1191714131126` (-1. + Charting`Private`pvar$24919) - 
         114.42573996081897` (-1. + Charting`Private`pvar$24920)) - 
        1. ((-114.42573996081897`) (-1. + Charting`Private`pvar$24919) + 
         2032.4221416033413` (-1. + Charting`Private`pvar$24920)) (-1. + 
         Charting`Private`pvar$24920) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9789354813370248, 0.9804369600268885}, {1.0210645186629752`, 
      0.9804369600268885}, {1.0210645186629752`, 1.0195630399731115`}, {
      0.9789354813370248, 1.0195630399731115`}, {0.9789354813370248, 
      0.9804369600268885}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]2/\[LeftAngleBracket]\[Sigma]2\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]1/\[LeftAngleBracket]\[Sigma]1\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9747225776044298, 1.0252774223955703`}, {0.9765243520322663, 
   1.0234756479677338`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226856185212*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"d46fa057-808e-4f2f-b947-2f755b3af1f0"],

Cell[BoxData["\<\"Plotting plane x1x3\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268561911974`*^9},ExpressionUUID->"e3a0722f-453f-4fe9-83bc-\
fbf046b5ea57"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268561954784`*^9},ExpressionUUID->"da6e2ee5-900f-4a62-8dc3-\
8379ef54de67"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268562001944`*^9},ExpressionUUID->"56ba382c-2fbc-4ae0-9362-\
96392bb7b2be"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxlW3c4V/37FxFRlKxSKGWWVRnhTRnJ3iqj7JTskUiFSEZKkZKtYZQZSSEr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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd2Xc8V98fB/CSFRKlJMkoZCSyhYsiIiShjIxSFMnK3mVX1leJUEpWQsiW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       "]]},
     Annotation[#, "Charting`Private`Tag$25036#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmHc4lm/Yx/klNJRdpKJFCZkN40JRkozsRJkVFYXSsndKshpGFCJFQiVS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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1FV0EAQYBeANBgsYMbYxWMBolozcRrONZmxjKoiiAgooISXSSGMQBqFg
B9ikGICthBKKIKGgkoqKSknIt+PDd//3e879E/uPKBoeGBAQcIMouaUoTRBl
KEswIYQSRjnKE04FKlKJykRQhUiiiKYqMVSjOrHEEU8CNahJIrWoTR3qUo/6
NKAhSSSTQipppNOIDBrThKY0ozktyCSLbFrSita0oS3taE8Hcsglj450ojNd
6Eo3utODfHpSQCFF9KK4pFNu5CZ604eb6cst3Eo/buN27qA/AxjIndzFIAYz
hLu5h6EMYzgjuJeRjGI0YxjLfYzjfsYzgYlMYjJTmMo0HmA6M5jJLGYzh7nM
40Ee4mEeYT4LWMgiHuUxHucJFrOEpSzjSZ5iOSt4mmd4lud4nhd4kZd4mVdY
ySpe5TVe5w3e5C3eZjVrWMs61rOBd9jIu7zH+3zAJjazhQ/5iI/5hE/5jM/5
gi/Zyja2s4Ov+Jqd7GI3e/iGb9nLd+xjP99zgIMc4jA/8CNHOMpP/MwvHOM4
JzjJKU7zK79xht/5gz85y1/8zT+c4zwXuMgl/uUyV7jKNf6jZPyBlKI0QZSh
LMGEEEoY5ShPOBWoSCUqE0EVIokimqrEUI3qxBJHPAnUoCaJ1KI2dahLPerT
gIYkkUwKqaSRTiMyaEwTmtKM5rQgkyyyaUkrWtOGtrSjPR3IIZc8OtKJznSh
K93oTg/y6UkBhRTRi+LA/3/qdbYjkCc=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25056"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"4196.788700148599`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25056"}], ")"}]}], "-", 
                 RowBox[{"3205.616147635256`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25057"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "3205.616147635256`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25056"}], ")"}]}], "+", 
                 RowBox[{"5057.5682166443985`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25057"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25057"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25056) (
         4196.788700148599 (-1. + Charting`Private`pvar$25056) - 
         3205.616147635256 (-1. + Charting`Private`pvar$25057)) - 
        1. ((-3205.616147635256) (-1. + Charting`Private`pvar$25056) + 
         5057.5682166443985` (-1. + Charting`Private`pvar$25057)) (-1. + 
         Charting`Private`pvar$25057) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9789354813370248, 0.9805867047941716}, {1.0210645186629752`, 
      0.9805867047941716}, {1.0210645186629752`, 1.0194132952058284`}, {
      0.9789354813370248, 1.0194132952058284`}, {0.9789354813370248, 
      0.9805867047941716}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]3/\[LeftAngleBracket]\[Sigma]3\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]1/\[LeftAngleBracket]\[Sigma]1\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9747225776044298, 1.0252774223955703`}, {0.976704045753006, 
   1.0232959542469942`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268571401606`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"43444d9b-eeb1-443a-9d9e-2682eded2799"],

Cell[BoxData["\<\"Plotting plane x1x4\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226857144151*^9},ExpressionUUID->"755ee215-dcbc-47d1-a59f-\
774370b06b3c"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226857146146*^9},ExpressionUUID->"dd939b21-e76a-4006-805a-\
498bab76fc24"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226857149186*^9},ExpressionUUID->"876968c1-6d09-4faa-85c9-\
d14fa0a1586e"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxdW3k4Fu3bligiZE/KEiEtlgqRmyIkZJdslaVI9qWyFUpSKFuKsrdQlpJQ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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd2Xc8Vf8fB/BkRTKK7OwtkZlwZCSpiEg2SVEiQmWPREohTTNUZKaMSoSQ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       "]]},
     Annotation[#, "Charting`Private`Tag$25173#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmHk4lmsXxVEq4lA00aBUQqhTksImQ2QuGkwVkahUyNBRHUQqkgYqiVSG
VEgyNUgSGRpRSUqJyP2QIZ3kW/54ua7vL9eP1/Pcw1p77/XOdPRY7SzAx8en
zc/HN/hTy+9TiHMGI8eXuhO7XBi1a0VpskxGA93ab2growfZqovdbzOyv23d
UQDu/Cf4anE+o8QfGZvMtjHacTajZM4DRpbnlK/buzGSGhATbnvIaMym2jY5
d0Z9Zonad4sZ/f7zj9UAeKB94r2PTxjdWmZztHU7o7YfzyztKhiNi7rAue1k
lLRxitGKKkZrQlcaiHkwCmyNTkh4yci/MWnRpV2MfCW7TvvXMrKWlK5x2MPI
zYx7F/WW0fuiWlFFT0Zh54zfGjQwElaNy7HzZjTy3Opo/494rmOD5Htwc7KY
S+lXRtkd/bGXfBmd9zhQKP2NkXyWYneKH6PosS55Gu3Y7zeDwjP78HvXX/FR
nYwkZBWazgYw2jpChRvoYqQ8caRU6X6sq0H35IdfjM5ssz6X9i+jRSOemhT9
YTS5uFj4ZhCjH8pymtL8HOWVVVscPcSIS/8R6gt+VTj/PAe+miXbxCfAkXbH
F7OjIYxWTkpb4yLI0eygROPNRxj9XbckMHs0R8Lnb9dKhzNSUwwK1xHiSGCG
ZgkXwWi+oPyi1WM5kv0ZXHfgBO5DP8xGWJQj5X+DnsWdZLQ7zKDE8i+O2iOl
TPVOM/K03/7hgThH93ISFdxjGP1iBx/dleBo1ICsm1csI11zP21nSY4069zP
Wl9glL5krch3sGvRHgHJOEbl0hcSeidhfT2GH+0v4Ty75750luaoRbCo1zWJ
Uchsl7m+4MN9eiVBYNbobHkYnNp32CMW7BYhJzl7GkcaiT7FEqmM9Myjz32Z
zpHhvKBVpWk41yrTqB6wTViUVuMgn/A+IzuLo5JlLfP6oNPO1zfP6IDF11ws
VoROowTfWW0El4s4HrIHbz7vcyB8DkeRPr3NyXcY5UQFfU0Ba0UuLK8B79A6
9O7ePI50Ai10lO4yeubQtLsU7OYSGKwNDurdqfQSfFOCX2I1+M2J9s2l8hwp
rlwlLHKfkcmPBTE/FLHfUKPEbug8W1/Y/bEyR1FS8fEG0HWyjHvpWBXc1wT5
sCfgtNZTMjbgdY8XOm4uZXTITV1U4m+OnJ06Dt6pZBRnvv2b4WKOvGeS8nLo
PNdxY7CQKkcHCkytHr5i1Bpz2bkbbNzzxPt2NaNtuibmTI0jJwPvimbo/p50
jbibOkfr59Xnq9QzyuuXjni0jKOsFfJ3FKB7BYOs1EgNju56iias+sIoQC9m
U5gmR/5Wt+pC4YMppSHCqlocLVcJMJrdwqgmSr1JU5uj6PJGIT74YJTgbbN8
HZxnsPXx2x3wl21bStIKjqYvmVozGT7I8J56/B04+4mrTBx4248ipqjLUekr
YZO93YzUPfomb9TnSCogK3Trf6gLZcZRfgYcWR7MXLcWPrHtrzbJB/Nr5m8R
HWDkUX9+w/OVHBnNOVk+Fz5xLTRzjzPkSH1T8Wtd+CQ5/uXiEiOOfIpTRvKN
5GjCxCKvv1dhfwH5IslgPqOFsR7gzplKfXzwUWBcq/18Y462a5ZIyY/C5wKP
zfIy4UhaI9hWdwxHDmuL3uWbcrTlym/aJ8zRKpeFr2LMOFqREpbZA199NW30
c7TgiN35FLJYjKMEzTWm18DvQ0fPyQWL5F6+VgZ+Pa88pBs8aq5wvZQlR+5v
BLZFwGcblQuCj6/mSP50ZUcCfBZ96JOgxxqODNLOV3hM4OAX96np4JCljqqj
J+J9Hks+2VlxNCDbmn4BPstWeXE9epB3jOiYPxm6TLdYLW7N0fP6zl6LKRxV
/6pb/TfYsNq8LgUs/fLKjGRwjoq75DcpjsYX7NzxEzx6fdu9h/Dh1gqNFwfW
4r4Fgqq04EOfpbKHEsC7O16oJYHPl06SuQ0ubPmzoxE897/Oe/3g5Ly7JeXw
pX+ZqaPjOo4kp839Ji7DUWzT0Wn7wAq3ltluAe97L7HrElg7QLa5DfwxONRJ
dT1Hn7wu7Z8py5Fdke2RQLBbU7N+7Gzci8U86xfg80uEL9XDp7RB9aD8BvyU
j9p+TY6jNa8yH28GKywP9raHD52OZBxPBovkvWleDx+eWZZtUgOuzDCuuK3E
0fGiy+G1YM5zho43fHn2ZpnFJ/B+zRSVlws4WpjIN1APLtTmE1VayJHJKptf
xeA/8/bembmIIw8txexcsNqA+JpI8LEqzvca+NGHS82S8Km7c967fYPrSzno
kgBf3tg6Kct28H0PfPeaLuHoWe+3ogXgSzbbStXgU+9VIklCYK+1fG8GwGNO
67QVYr/JgQ1nheHbKUl6u3aBn0U+/KEJ3yoZT9ppAB7B36d2B9yV0De9Bee5
Wc/wbslyjqbG1gemg6+l2HXbagzfz+MMq+ft8PXRgNKOcrDUaQM3O/g6uyz8
RfYgj0pvCAaPkzrx8R+w4wyxXAYuy11v8gj6iPn8QkYLvo+qLNg6CfyiZNLI
FfD9yYVjdWKgvxqhjgCBFcN6de9ZdnUefK47bVGoEfiZdPyU1EG2Vq3sh96P
hh2QGwAvUZczFgLbXY3LF0Ad0BKPlK6FP+a0KnUsBu83eZCSBnZ1W5Rrrz/s
t9k/x+uEoi646tr8XgEOYvXKl8D2C6T3zALrGX9dVQCOcbyYnA+/RlbWPq1E
3chp/5J4BLxeT2ZpJ7hvVlmKGVhm/vk6KdQRQx/bGkn4/WlIp3UTOOf0f+E3
UA9CxFdfnI26YmbMRMeB+0XMd/oZDdcbsXWahxNQVxyKuypC8H8SaZu+DdYV
Xj2bnhIp1glOPzdy3XnsI7sy+8QSPOfF+wUW5TgHQ6ubR/LBvPo4/ta5C3Xg
pXorEmRxrny/ArLHYV1zJ+hYbMe9vNv/kHsA5tXv67/GPekGf+YXMzWDLqpz
jklPxL4EPom32y7lqMmOJi8G8/qFkE3fybngTX+9uJ8BHX+3uao4CVwQlLlv
P3S/4NpD9X48j9efNscumFcKruY/+zEfPrriKzkmAnwj0jwnHb57zndCagDr
5fXP5P4QhWfgBxsOWMkPctv7o5lgqZVxYzrnDO/fsuGpWDv6c0OnZUYEzofX
z6NndW1yAO+J7W3IRJ0IWvmpbiT46vEZwgx1J+TJzMalOG/e/PAzOi/DH/fQ
tCY3YCbqnMXGV2J5uAffMfHqUqib75Xi+bNx37x55f6I6d/0wSIqFdX+4ObG
4N9S4OVKe6qPSQzrx1mtJ1kAdbr4guBma9wbb1765fNZOl4P5yS4UigBfcCk
f+T4ANxbcIPRtT70Ddn5PV2muDfefDbFJrc0C37J961PcwDbthnVHAF7Oybp
VYwa9tNDjRtlWiNQN43/HfUPYS7McHhpxD/sT968WCn++e2gDhSjdbyc0Sdv
CwuV2MHf67K+VCX9ZEP1IGy3YqJXD6OLN7csVwLz5tPFiduFnkAnK2ncf0KM
DdWbH5mFVano68p2dw59h25WiSwRuNzGSGjk9nMWYN58bCjofLoS9SxSVLd8
EjilsXViNPhUokiMahMbqndfSsdkXf+AOVjLJ0MF9ZE3j1+xc0nfizln1fQU
VxfM6y2j8+pzoTvF8FPb3rxmQ/WYRAeSdJ4zShgrk6cKHfLygKRh5vUn0OH7
qmMLqIyRdlGVQ+J83NOW1woNj9lQ/S987FfoUMSobsG1rwIK3FAe4VcbXZIP
XWbtiZSKL2Bknm3hYYV+ovBd+JBULhvqNwNeGr8Fshmtb5EWj0E/4uWffiH6
pY9+pRF9WC70Jj6/Ze7nipmoI1LlCzZjLuX1u5C3Ux3mp+Dvpw0FB+fWXZ/3
3Mq5gvWZFVbZQsdt4RqOnZiTU0OlwsWnoj8+eW1xMp4N9WfB7Y96ajF3t1zr
OjUNuu4MWyMfiLlc3b5JgoOug+/P+/DhDKONcZzqNLDqnV6V05jjefNDVoTn
h1GY+9WaWw6LQdcPY4N8bI8ihwk7T/6NeWSTsf4xczBvPjH6O77VFDyNvy6q
C+ypsviiMTg9R9DyBzgyOyX5CHLI1K1bnJYiR2irR7SWIae4e3ZrFYlwtDhw
tk16MKODar6Cs8A73j4Z0Y7cw5ufivoEO7YdZBRqv/VZEHJK1yvJCROQkx7b
zBAVhW+udEzJUUCuiiy3cVoCX5j1fpltjdzFm9f4f0f2i+xl9HX0DYl3mPfq
FF0zUndjDo5rSc7GfOjjZNm/GMybF/f3OC+dAB5tNUGsAT7Z6999pB458bH4
7okR4I9BM1qdkDMrp3mFVfUycngobTUWOZU3vxrMyFSqRq7NEjkdmsAx+jmj
mi/ZidGsRH+jPMzDT7d43nIHuzaOMVoL3icmIGYO5s3Lib9vavU7Miqp/551
phl57qioh+1G5ASFR1oPMH9PlVQv2G7PhubznD2P80XAtd+W2bm/R96LK9bz
sQWPikwUhG/KjP/td97A6MK+1x434BP1rAcxDuvZUD7gW3fxz/t1jI4f0eBE
XjDyK87eu3sto6pq/8ueyBPLn1eNibVCDrD/U/MUeePuvk3vRMG8fKIo9y7o
z2rkvIaZ4W7I5QdzN5nnWjJSCrUuXV6I5/9ZeeeKBRvKPxFpmjPJHPm8J0jE
OofRhtR3de1m+Ny1lD+TkKdCHJ++mgrm5a/R6xU++Jsy+tQS6Vdzg5HRDKe4
chP4W2JFmAPy3sRZtqfiwby82PXXWEcvsKp2XUTBZUZzulLNNcBFzXusO5E3
F54z+rAazMunRcsrE8+DX/RmeyWdBU9bkDcO77PJK8y7cQr5zrMo7TKYl4dF
ZDyNKrG+fKFU54ZjjPT/etQ8F/vxueiq7QXdL5uctLAaXM6fJrM/jNGBv4wv
dGD/vDye+HmO6mmczzEV5+uT4YOynAOHduL83vbV1qgh379tV34lu4ZR41hx
w7fwgf4G3e2R4ModE8eMA6f/uv/sIM5f4rAFeR9g1B1nqb7EGueQduPzmv3D
91cfWtG6/x+ci0Du1lpwtLWOdBt8YuS223PyuuHvI44K+/3YCD3wbVAu+g3f
OL8K1POBXsxHGYnF+TKaHKs15T74ZbHTVVOwhOOblnLoq83Fx38qfNUp1TDT
3o5Rr9jAxyPew3q83cS/pc0LdWOu9U8Nx+HvW2a8uV7VB27wMHo8btewP8Z5
kFiCB3S1wSc1w4WRytNbWWk7GK0y/rNlmSv02ZtYXgPfqVV80deF3zyDt3H3
3Rl9eBZRmQk+8z7WJRgcn/n0fqD78PdFPP+OLbug0oLnyMXVXTrpyUjPL9S8
DT5dveJwwQ6sW0P4yPxN4Ntygs/8fBjJ3Px3WSnWITt2z1N5nGN03Zir152h
73XTYtMCoO+340evA/PqUaKY5m59sJnBd7lMMJs4z00RHL6wuHbwXi/22/t7
b2FD9W7t3n3ypuBxYndenYEuqjwrjKXAyx6u+CwF3cg5eefX4Vx49VSuMnrf
A3CVmfbTxHBGPUE3RheAM+t0PzdBl27uF96eBPtS8d6xqO9Vyj45l8C8+v/A
+qh5GZjd6Ha/cA71VT3mcDu4r6rrbCp8EueddqsC7+f1m1mNVSXd4LxZGwW8
rjIS00xaPx774U5eFPuZMnwe//993/8ADDEumg==
    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1Gl8CAQYBvDNNpttbDa7zQ7bHLvvzTaSJOWodaoko+jaSkWoHCGVSoUO
t3IURYdulcpRIkd034focKQoHf779eH/vJ+fD8+b0dBU3xgYEBBwkmi+LQgi
mBBaEkoYrQgngkha04YoomlLDLG0I454EkgkiWRSaE8qHUgjnQwy6UgW2eTQ
ic50oSu55JFPAYUUUUwJpZRRTgWVVFFNN2qopY7u9GjuT09Ophen0JtT6cNp
9OV0zqAf/RnAQM7kLOo5m3M4l/M4nwsYxIVcxMUM5hKGcClDaWAYw7mMyxnB
SK7gSq7iaq6hkSau5TpGcT03cCOjGcNNjGUc47mZW7iVCUxkEpO5jSlMZRq3
M507uJO7mMHd3MO9zOQ+7ucBZjGbOTzIQzzMI8xlHvNZwEIWsZglPMpjLGUZ
y1nB4zzBSlbxJE+xmjU8zTM8y3Os5Xle4EVe4mVe4VXW8Rqv8wbreZO3eJsN
bGQTm3mHd9nCe2xlG++znR3sZBcfsJs9fMhHfMwnfMpnfM4XfMlXfM03fMt3
fM8P7OVH9rGfn/iZX/iVAxzkEIf5jSP8zh8c5Rh/8hfH+Zt/+Jf/aB5/IC0I
IpgQWhJKGK0IJ4JIWtOGKKJpSwyxtCOOeBJIJIlkUmhPKh1II50MMulIFtnk
0InOdKErueSRTwGFFFFMCaWUUU4FlVRRTTdqqKWO7vQI/P//nQACzonW
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25193"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"3321.417029611852`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25193"}], ")"}]}], "-", 
                 RowBox[{"2337.7162995546364`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25194"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "2337.7162995546364`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25193"}], ")"}]}], "+", 
                 RowBox[{"4386.807064547499`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25194"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25194"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25193) (
         3321.417029611852 (-1. + Charting`Private`pvar$25193) - 
         2337.7162995546364` (-1. + Charting`Private`pvar$25194)) - 
        1. ((-2337.7162995546364`) (-1. + Charting`Private`pvar$25193) + 
         4386.807064547499 (-1. + Charting`Private`pvar$25194)) (-1. + 
         Charting`Private`pvar$25194) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9789354813370248, 0.9818820806959085}, {1.0210645186629752`, 
      0.9818820806959085}, {1.0210645186629752`, 1.0181179193040915`}, {
      0.9789354813370248, 1.0181179193040915`}, {0.9789354813370248, 
      0.9818820806959085}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]4/\[LeftAngleBracket]\[Sigma]4\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]1/\[LeftAngleBracket]\[Sigma]1\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9747225776044298, 1.0252774223955703`}, {0.9782584968350903, 
   1.0217415031649097`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226858080612*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"f0782792-d81b-4e77-8e5e-ec1a40961116"],

Cell[BoxData["\<\"Plotting plane x1x5\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226858097612*^9},ExpressionUUID->"331a92eb-f69a-432a-8597-\
1da83bc86337"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268581005597`*^9},ExpressionUUID->"f2f6af93-88f0-40c2-aeb7-\
4d39cfe12634"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268581045465`*^9},ExpressionUUID->"2c759a49-8dc4-4bc6-8b6f-\
73fa764914b4"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxlW3dYT23cTwppSBvRVCq0jNK4i5KmhoaUEpFS0aZpRKUplRTtgZDSQqGh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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd23c8Vv/7B3CERERCJYRskb07VqIyQ7JKGogKkWyR7BESFYqkMkMSklEZ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       "]]},
     Annotation[#, "Charting`Private`Tag$25310#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmGk4lt3bxUkpU0VUhhIhQ1Eyq7bMJUpKyjxkqMwl6QkZGggZolGlSPQg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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1GV7EAQUBeCN0d0dKzZGjBxdI8Y2YmN0DRgwNhiMBkFABQWDMMBOGgMU
DFBQMEAJJZVQGiWUUCkFfPf44T3nB9znnpC07JSxgQEBAVNFTuciiNzkIS/5
yE8BClKIwhShKMUoTglKUorSlKEs5ShPBSpSicpUoSrVCCaEUMIIpzoRRFKD
KGpSi9rUIZq61KM+DWhII2JoTBOa0ozmtKAlrWhNG9oSSzva04GOxNGJeBJI
pDNd6Eo3kkimOyn0oCe96E0f+tKP/gxgIINIZTBDGEoawxjOCNIZSQaZjGI0
WYxhLNmMYzwTmMgkJjMl57ZM4wGmM4MHmcksZvMQD/MIc5jLozzGPObzOE/w
JE+xgIUsYjFP8wzP8hxLWMrzvMCLvMTLvMKrvMbrvMGbvMUylrOClaxiNWtY
y9u8w7u8xzrW8z4fsIGNfMhHfMwnbGIzn/IZW9jK53zBNrbzJV/xNd+wg518
y3fsYjd72Mv3/MA+9nOAgxziMD/yE0c4yjGO8zO/cIKTnOI0ZzjLOc7zK79x
gYtc4jK/8wdXuMo1rvMnf/E3N7jJLW5zh3/4l7vc4z45zx9ILoLITR7yko/8
FKAghShMEYpSjOKUoCSlKE0ZylKO8lSgIpWoTBWqUo1gQggljHCqE0EkNYii
JrWoTR2iqUs96tOAhjQihsY0oSnNaE4LWtKK1rShLbG0oz0d6EgcnYgngUQ6
04WudCOJZLqTQg960ove9KEv/ejPAAYyiFQGM4ShpDGM4YwgnZFkkMkoRpPF
GHLGO5txjGcCE5nEZKYE/r/t/wGmUJ4I
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25330"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"1510.336535403797`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25330"}], ")"}]}], "+", 
                 RowBox[{"44.18499187191754`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25331"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"44.18499187191754`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25330"}], ")"}]}], "+", 
                 RowBox[{"2540.1635254563935`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25331"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25331"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25330) (
         1510.336535403797 (-1. + Charting`Private`pvar$25330) + 
         44.18499187191754 (-1. + Charting`Private`pvar$25331)) - 
        1. (44.18499187191754 (-1. + Charting`Private`pvar$25330) + 
         2540.1635254563935` (-1. + Charting`Private`pvar$25331)) (-1. + 
         Charting`Private`pvar$25331) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9789354813370248, 0.9828094614353261}, {1.0210645186629752`, 
      0.9828094614353261}, {1.0210645186629752`, 1.017190538564674}, {
      0.9789354813370248, 1.017190538564674}, {0.9789354813370248, 
      0.9828094614353261}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]5/\[LeftAngleBracket]\[Sigma]5\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]1/\[LeftAngleBracket]\[Sigma]1\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9747225776044298, 1.0252774223955703`}, {0.9793713537223914, 
   1.0206286462776086`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268587816715`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztvQuUXtV1Jnhd/6NKLySBhMVThSCiwDzESwhhTOEYkA22xVsG2wgby/hB
kI3j4PgBFWcZ03YaOraHTscVubsnTfd4zSKTNVOkV5NVThyHycpK12TGadxD
z8hpZ7rG05PFeBK32p3HP/fbZ+9z9zn3u3/d/1dBO5Nm8Zeqzn/vOWc/zj77
dfZ5630fe+B9D973sQ+8977pGz963+EHPvDeh6dveOijZVPnNUXxmj8vP381
XeD3QVHYj0H5/+CH+IGW7Pdt8nunGCwvF0tLS8Vy+ddJ1jZYLpbLtqXlQfE7
5J2l+UPFobkFeWeLti0vzBWHDs0XS+Vf33TvvDaOs1DMHTpUzC8Niq1xnKVi
Xtv8OxuzeWCcnh9Hxz6ZzOe3Qz9/Jf/0y8fnZdhD8pkr5heku0n5uvy5NB9n
PZDPcrEwF2bUzWY5t7CsbSt020m67RAE6CT/Uv6Z0sfLr8oRZBbLSzILhalP
ep3w6JhfilPNSdEZf4guwe5v+YmnX00QdA2bueBjyLts+LZjdBOczxULy0On
zhDXGzZ1GT50O9ESc23HqLgucCKIm03dL4EOgZR121HGxZTmjAfKj0xxfomt
rrZd9whk30hnHB4PXXQyGmI9NM94MuHwwLnVdLrH0T9b3hmiPQ3ybvH4sGmH
adYlC/piNG7bf5e0/ZaXeVOytqWL+SA6w/Cx2+ZZ24wYZ3uEr8IQAWiVg3/t
vlqanyvFwqHyL4irNSU3ltJ1fkH2IhNiwsA1nEzWmNuGSnA55hgdgo3fdntW
6L9X+L1T5lA+PyE9dpKdJukvF29u3LUr9juZ7WApr/l9NfTVjZTS91JpyURd
QMdG/noi0BUzftR1pPt8BWCRMgm5ccjUvHT14yVajGLkqPu+SSN6lX5/rxI0
gFmpEMmScwScUMldYT15p6vdCTbc1yDYntUdqjP8672Ee9konSGz6g757upV
6J8pC6sx70Qd0++6cdWHZ/DEzsAD77FNwgkTW9SH8q3WsB0JlAqhCSf8EkGg
+iYYYfdxjUfeW2FOVxGUTraYQ+N47m9GrjZ9sz2pua91Q/vK8XthIOt9Gdfg
K5NqqmjJX2t1IXlty5kHHTKry0fqOlXk+qRtDxmj3zhGPxnDfc+mwIjf3HX6
LtNuGJGa+5vMpjqIaxJ7zAUZoZxNxrYfI1SizFV8wHSCy0fqOt3Z+qRtKKFq
Y/STMQhP+a+HEmqF6Y9MqBX6ywUoCPo6RqxMya8NtTbbCfFdZa2tgJHLRxpq
cuhQEy2eWZm4fg791F1Rfc+muDJxm8Ebj7jN/aVtgbjnZ8RlFlxNem9SbNal
sC1wtA3ZCa8YabjNIwzX/MxQItfm0U83muHCZiiRVwBxZCKP1F8QweeNRuTU
EGHCIrSFpdWrhnKa2O7jHqufjNUoMf5WEbeXERcreGY08dzsq1kXu7UlFTCc
617h+yuOe7x+Ol4TFVoQ+P8/Itqe87Lz3NGUpZURbgSNNhVTAdsqUK2HG77K
rshYIvP7rJKqtXvcUdamo7i1kHVx5bgjpBNlAiHng7Y6vHMdJSgzi6clH6za
cPH7BHD9ejfdU1bVMLpyrCHSPvjW502F4wRhOB8rK7TxX6Q6cl09qjbyyaHy
vo3vYpSxhj2zJ3JU4uFcLdfFVeN33+WvDu1x08o+DFuCri26sOaXdId/L+Wr
8MaUftfemecxvVp9Zp4hZz5PDRmnO+S7q0fsi5nuo84nbk+RKodi6MCHNXQR
Ho8T+vX4ZzAo+/4N/HiNay26aLHB8Ls64X1zcULLtg2r/K6FQ1566aXYptME
v7/i47d5F3N7NcZlz61XHlo4VEgOyPHiZYMKmBIma/+bxTD/5d1Xh1GyNvk3
4ZL08UtJ2/6WbbeQtjcoOF4uMDa8BD9fU2PhV3Zy7LlWE/lOU9s4L34qpXix
96mXinesVmfFoYV2nf0OmcVm8tynCUEPtBngn5EBtpHZskFruD1d/nlVgrU9
Mp+7CCxvJ7CcQpDFFnMNvtPkn1cvENltASQA2k8Ael0bgE7NiLKKIbgOGf8A
meenR5rn6keg2DzfShjp86PP8xUNvrSZN3hjtHm/OnEF4esexr+ZcMRZBPvv
DG3TR48enV1cXMSn6MpPgSy29R579NFHw3Oxvz/Az+4Y0K6Gg53JqY82L+Gp
Y8eO7XvuuecEjAn52X1u3759i7Ozs/gcnZ6eXiv5ytLlwLKXe6FNcGDD9APc
+KJ7bGpqyvrAJ3TdOXjkyJGIu98cl5tXy1fNxN09hBksIdozjcr5bcvLyxEp
m0ZB1Eb5YnJp165dQNCRgwcPAkcPPP3003gYHRf//bhyaZWcvWzNdwiC7iAM
FmRvb+bFF180BnvmwIEDL+zZs6eYCEjZhcz2BClFB4wTkdfBzw7QU3Se3b9/
PzpxnNrz7ISPTHQyLNNNL7/8ctq5voRZeNZc3rZtm5Kui79tIMzuOgLsOtL2
rnE3ulXyxrYhFIhyJ+HkoBL3IAmAucNPPvnk0w888IBgfSqQYf+zzz6bE2rP
Cy+8gOdF9DFdXo4WTARigFAV8QJBgfdI6ckwEDqNHVxLAMiRj7athCDX5wRp
o0qtlk+UyZUuwfx5ZOKfCE8DEaAEmLWSwV38Cuw9/sgjj4A/TyUjTQcqgf+B
fEM9pPqLMzMzuvaS5dGrWAADPvL444/jVfwdI7Z+4utI2xZCmRoVTGFfTV8l
2/F2kcl8LGAWgvXAM888AxQClWuCmAZqbOVDXols2k66Prdi/3xJ4J3I0QHP
Xch3yHaQAUuFqaRvytHEDKdLyIsPBZAgY7FvGLNMVUNjJduW8hPNiMLs4sz7
Fa/ZzIG0X24zyyNhRuAuIBnvY52H5d3Dr+BDIDky2Hmkm2Did00eoRtAE7rp
glYADCNgpKfbzOyroQ1dgvToTqVORBT6A40uIq/vTrkHj2MaKrfQA3oVrvhy
m+n8/ao/IBikw9bXryB88vDhwxC8gJC5PC4k0kNTyAEEegXeQEbtFehHE3oF
6j9MejirzeS/EtowDMgjuNQxXt60aROAMX7f3WLmWJ0n1FkZXfUqdRKrE70C
Hx8gPbSa+S+GNgwDJnQz70AzgeQTGlq80aOmbJG+TLj4lbi54q7Yr6p+6DM+
9wB5d7rNxJ8MbeCXiHKHnCPX7yw1rlIF3f34H1yVzR3IsbnfmFJOdmLdERIb
5gtt5vTF0AaCgDBY2TqnSdAOrIa1IqvcTyZEXroeCej3LVV3kMDy1xrConNt
5vYQeVH9TGB/W29FsFdE7USbaDp2WMTm5/vYS8a6NTwPxsFqe+Tg7nIohXWs
yeJFPZkJJKb6cNEBooFwQWyOoQrBbJJ9AGn94YO/gW0mCza3mfthwtHh5Gcf
/do4YFgsbDDwBvLKVY1T7kAQgp88CgTP5cISM4lJg1Zz/zuhDSsBEkH+uok8
d1toA76Bd7FhdHUDf9G4ez8BbFObiTwW2qBACET46w7y3J2V+MIOBKwYBwPB
mJw88QgdVPr6TFh8YHSsfrwMRN5JRjuQgi3rW0fDVoLXRI38WOx8CIifrDoD
H4CARkx0JryMJ24n795TgY31IAs3vNvH70CFSC/HvB9pg/ZPVEIVUtujE3SN
Op5lg/vFsY/0dz15bmsl1TCGWJs6BoT2tDFsqwnfRgY4qwICK8UhpwOA0CbI
2ZC9W+26aX9XtgDMCSjjDiGoAVYSKRr3D40DGAbY3gwYsIhVK+xnQVAPRLkC
N5IuGWw3kEV7SrVTYF15yQM1JML2YBvYbicDnN4MGxAZFzIDYjPpj6lZ91dA
QGLlO0hccR9qA8RHWk74RDK5N5P+wm89iE4TQ/gAuzF84Qn6QJtJzkSWHJQd
y0fcQdoWnxN7bSp8sWtpKftCVKGqg354rmS19h3s/Nf/+gdfv/32L/+o379B
0DQr2veBz//MzzyHt0o0DoK9C0OyGqsXukRb3iVeyeeEtvw5TCd9bipKoFoH
AHRoBx39+fmbS0WxmJ193Yf/RA1184Mn/ZUSutYf2vLnEmpo8tSuwdLSDcf+
+W8dXnxy6eOLT/xe72uL9x4pOr+6ePc/+L0Xd7+77GC26MvPzmODRx/98osf
+lJ4Qn72PrX42W/iVXzuX/zll4ReU6tCaDFEB6W8WSqFweH7f/mXX5pI0bKn
2P+7hpa2dDoeuidkaxWqnqk6K5ebfIpJ+UkmNxW+KNd5bTblOq866Ifn6ohl
HXSr7QL74J+vW3ebrIzFovNn69f//h+df/735a2J8O4+qI7Z4OWeXA3eC8+h
LX8O7+aTZP1hfulzU9USyDsA5EM76OjPi04ttcGi/Jz6p36p5P2V2lOtP7Rl
/fV+b3b3D5dmd7384uzM8heXH/7C44NHHimRhHXQe3lQasUDqSUTPsul4TE1
mAVSB48Xj1h7aeKKJ13aym/lib78XDNYKnbh26OD6Wn0emRw8CDW18HBkSPl
TBa3oQTNcXOE8trilVf+h0ixydGodTzUT4jXq4gcATqvzSJSGwnqqzmvzXjG
Hhi95HeTPXCS9Be0r/7U4NgxYBoYB+afHezfD2oo0Y4NpqZAmEr0Fb0Dg2ee
wSv2mRmU1ktIKejtGbzwgv/u8ODJJ4sJea/z9OCBB9DPi4OZGWWK3tJg167n
Bvv24Qn0K31VO+mxOF0WJ9XT/BBLgunWuLybdKYaKvAIB5jHL/ANvMsTh0h/
wQzugVv3DZ57zuOx1ErRyaQhEu0GbOTw4NadNFrgOzzzzODAAbyDd8sRBWHW
z5ODw4fx3PSg1K7Pjiv4ccxdTMIcYVDeVg1h6CxkiU1CE/Y2PdR+TESo9waC
6HNJ/+pi3zR4+WUgwBC4PCjtlQB43wCHCAJXGfLCIY0e8OBfFSYLr3bRDdrw
Gjb6MwPrwzDxET9YXVAxp8kKOnFczCkvY18/DEThL+bDW6cYKG0KW96wLMUg
nyXYP5lgNizpST8+0IKlDcHqUBLZCOjaP3j2WWGjzaTPcCq6C9bEc3ge7ylm
sQeASzEEujg17vTL5juyRWR8IU+c3bwAx0Yx9JJSEoa2a6M4fi46V95I0J6H
74BaNenAXBgHqMNKVpBfGOzZg8UHkCGtckKghxAu6UIYPjJ4/HEIOCB8IshU
0AE9gBXN2IO1H409xVhcykz+VRNdJYzNE+wEDWIdliXkGpYeBDa6lTwDaFC6
JPE9mERjnWk/el4HzwBwkYuKDKxNbAz4znykkLXR5zZRWfUxbJh7E8A+m8i4
61cTQb+qbSWbQ5CAqLqaOkAKkCB93J0+h+8MWCwXsBMEla1gAAWjNt9w4oae
ZeN678TqAKYSFGsFA+/68m2Z5VuaUSWjg5MdMHHtYxfCWpkgw93TjAswAbqU
DXBrtQqit2Ci8hZEtySL/Z65mri4LIhQEMU7v5d2nFQh/33hPSxfiEMRqw4o
cLhwc5+M+e4KIQDerwTgUt7DEyGg3YfA9FsUVgW8Ha2yXRl8GstDH7kWiRDi
1Le//W154j0V3fMVC3gBt6hqa8i44TDgJJgczA7JN1AdH0wAaWKaCGTzUILf
MS6gu6qdCB36ASBno3dVTy6CCzE5T8wE0PVkXMt+9WLoHNJ2uTJVCbgRHSNg
AQG5sgJOaiY4FqbmydCQYM3LzvBxcegfUsVEKz4YC2PqqT2sZWhKA7XdMFUI
NlEPWJ5NjgKsjxwFle+zj/6xY1j/4Hmg98RmdsAyjJbASQS7e8hwE+19ddHt
cWElj3PdBXOKasS9AVWYNjYubGAYBmwOdpclfCIZs09kF9vImL9/krwb4O5D
DHmS4fcKpTWGglIB5s8xCazZicEsNDoEj3dVcjs3miBO4nPvUnyXCsIDg6ef
hg5lqwy/Q5cSsbCFjMEUrBxHaHtTABisCjoYPvA72jY3TzUJkpsSPH+gQv/V
baTQHZGnjgH2XJOLEudcQl/ddjBP8JS5VvAv/hYJ9FoyplXQ9XyxlrRdz3Fj
0mdTNfWc9eEfj9J4E0F7K9wwff+ias3nmi8sn7jmZ8igl6g0Ky0S6GEGD3gJ
IoZlpv1UhQJIHVuykG5gS/Vf5PJRchRYWGHvOGBj6kHM9LED+3WJ3RiC/gIy
Vnhl0laP7R8mcUQ4n06GD9Fx8ckAMybQgSElpaQAQbphKqDE2VEIDqIfrZUy
dQ6Z9/kVW4GinsIItUR1PmjMk+BEkMO4H5IV+6/sj2eSMUNqufijTAqDG2S1
bKzGjitPgRtdU9yvvHP06FFjVds8YavcU61erCjjRugPkGxiFk2Tbh8O3eJ7
sR6UptAR0HbZuNN9u66OjJfhJgQu7q42Di8MgDpsXmc39piu3/BcD9g27gLE
4DZTM0ef+tvC3EyA2gcqHNglyNh+rgbZHqhbCqASJnCMSdMZfTenZW1YqyFp
sQfF0JjS5IUpmKtjdpwVl93LWBmNm1OAP0abp6ffIZ4dB7cIAzy0kwy9K33d
4DydrF0FHWvPJCyoKz4LlYdY0/CZiaQ+dfXR0fOuRTCyOEMOVHL8yA9uvdW4
12C3HdGTlimutSTdA1/V/LQu1izIjbUoBkt9NhCZIr5OWU2wd4Q2cADEjCRO
3OXAJVrNKTkYJdc2nm3NSHxjfQFjEYkiptEBbAkQG16ESJ7QKwA28Bk3/f0Z
XCCjHqDE/LAKza40hZdxMTuNnB/4RNfTpC24ELsm0bHDQLYpZjBbnzuAvQD7
92vHxcwZZApTBFs/LT/X5AmWUAxsEwQ1RQxf3AJ8vJ+Dj7bgdO5CxTLZh8Wg
GGV7ekzDwGdLNfUY/xoLD5gLw8PHAx1AbngazC9pCs4lpGt2FDbPcan86Olz
AR0SZrDFAjVStoLwfA+S2m9act7kujYwn0kGnGykfR/cbkIZtDGFgSVqv46g
U1NG8QqsC3QD9ImepbAgddarp6B1wME4K1wRD8mRCzasZq80YUKYyOWka6Yb
h9ytLljTyA/06CrFivQqEEQrWPcNI0CCFIUY6g2rp+f7hUwUCylszom2ACrJ
lslSpHYS1rs7XXX4YCVPkkf1vhEg1YNo2VXXUBBlBiEQ0stNEKHx7QpgqQhi
vx/ovi9ejT0tgAB/vZHMNljxkmcDMQXhDSD75PXgUxJt2+89BtjeCMcQ2l1X
geiXpChTgWVEtTFLEHiWUDVLXjaD3bNdfjavyknsQkQY6qBKML+Pggi28QaF
gdjKplaJBAPEgyhSWEHEpmCsCI3BBZtXrrLwYTJvBRGL1gQuLDS3J+bgoK2V
rRy2WznS7PdUCCITWNTUyM+xNdVvYG61n63AMXk6BBz8jrar2oATIt892yO9
imDgPPKd3UW5exTHftSbNBEe5fVK5RqYB4yd5A/9Sfx2BBDXR4E9YpbKNQE0
n+gP4SQmuPqwQTVjnrK1mJm585dq6rgLCCf9swDQzQQVF4wFtvY+uvIW2no+
ZCShNKTqqvPAW/lR3JRg5LaoC+wmQ5xKMMQq2zjIzdMO5mqAHCosJM7acSG/
lEyrX8cGBLls+wEbPewDJiRBIJFMlxNwWNwlR0U8gJXN4y11aQWBPERaARVr
xkUFS/XIN+5qfxuGni4ohi0SH0yZ+U+3kymw4DtT7m+qYwa78QqYmTpOzCQ6
4RSZamcIZnYQFLATBEHXTBwX2DPEH8QiUwyN15K5sdDTFRUaoXiCWrBF9Dgh
0GihBuwDx8tYCfo2DEEVczvnqEKbKbOlbldzb+0kKGA+WFZ9QY+rQhGCroe+
K508Hv+Tv1YVJ+u5FBac5CfEm+w81hayE8ReMh8M4JIsDna8gBU6UJxA7oFN
wC5gm1X1H2kOmVehsPnKLsQSnZgmOKVkyTys2LRNXkNpFifRW8i8WEycnaP8
OGnTohGQRBhHck6Z2raqaT1aNdIb7xFpLLzGDJ4plfWuzSQ4mB8S3LSUFaPn
7Ehljiy0aUq7qRSwoem7e8ZFjCa1ehMKGqyociyVTksoTH/3G98wJT0K3reS
MZldtIa0fZy0KfAm4MEx9N0rxwVegUEIxRtXor4HYLpY/uYmBhXeTroOJ76T
DSLG5ifiaf9xJhgUC8kX9db/wXPufsImCBY0WQW5w0oNfik8ikkBFizxKhra
xSKABIUyAAXgwhFmm+RWTCnKFkuUresXjyhz3qRAOPsLi16ECyuswoT4DjKF
7eQ5rUOFtThQc9iCoN5agYeoFZiqrIrnx1juJxrnJ4LfArewRPI4BZYqq2Li
9FoZnnmr8VyIJXZsfxKRs7HiEdND8JHMjAvawPjOxgl14WM1+Yblx3yrW0jb
dAaPh9E/F8glZgyYEsNAn1CQEJfwbC/Jkq+jIAlEU0WdMLeSUQPjRJ8/RsbS
YKeh/6vQho3RkqntEIQ/em6B9bAsVnJb5fMEdj5aLRIz6GKYhh2cDscU5KwG
noUPqKiHsDb9H6ee+hYJYbXaOZlwDekFib9LTjaQ15l1FjhWtCrYIMf+qlPM
zBQ+YtdVTQ5BlkUYIa2mql5iIF2cR/grbL6SkG0iG0x7OpkW8wCy5OuPVesa
U4cnA+1M/1FZDQn60jnn3C9SrtD4wEwbkNSJA3KZRxQpwzfVlyKmwyIoDCqz
qIi5nUxf811N0xCGYpqL7pkl0pf/otv9pq0AidqeOwKY+ZFcNeNtOwOvgee2
k+mzQg7MwZIH+wHmjZXEgaDGrgkjskeGCQSV85D/ywUX/HtvbGA/2NkG2Cy6
IELZJajGSOiN1TIx4R73yHeSfi8l82UOEy0hAOMPfSLuYsEwU6zBYz4PLPZ3
TnsA4cYffP/kk3+YI2lfXawBPjE+30W6Y2VfFQZLf5RIixrfBgPwiGi9ghEN
T3zObg9G7/Xf/Ob3/mpi4o8Trt5XSUBzo4BL7yXd2KUBnuMUTHAZ1q+cKAjT
n/K2jT+nhH+hlbWiwLmV3PmXl1xyywDhMZM7+yrxZfEYyJHLyDTPbwFOVXSR
mnS2oYqinsd8qmBWLzHpyo8EM1wSZVwVO9rD31V7GGLzKNhYQTe3h8XYLicg
MdA17zaZvvv9IgJdbmij604lbkAA8A9+Z4JVrZ0klh6SIbqWLWRbQiuW3hmR
vajvTv9lp/NvRZVVKQhCmZ8C7M1M+PPJimT11HKEAST3e44wfD1DulZWskiv
+M+ZDanbkN8s44JtxTaW+lSiw5WJnC5/P+ZThAaDEG4GeljRCEbJPFThcruT
KZBMbPzODg5emPIRPvg9hMCkLJT3D4rGd9YIWPCb8VMPPfSkGKA3hDFtRwbv
Qo6zop+MQjeR5xgWfiW0mT9IKB5yz7o+QRBaYiuQgvu37/1jAM/s6utVXKji
bFAxBYBVVQmQhgsvHH0VCPRmtNH4pAhmb5iJd6FWkG2V68x3hn/NClpqpif2
HduHbBc3VjCkYQ8DiIcIMkoyKzKw00SKasZJzeMIP5M7DxdF/5k5go6vUP3o
N1izCqs7Kor6yInYpQ0oen/WDXjpE0Q+aNACokZOJ+EvVk5JdwQfccaOwPwo
kzkKRyuNv/IV0qwksDpC/OqD46UBOw+QHljaLjPhWDYfk03npDuKKCeqf+WX
CIGw4ELst+B75k5vxuoq3ffMsHrWkLV5PUftB0g3zGxlbcwSzknQlFHIqhBr
qMprQRZpS4oEn0ze7Q/H9yt/RTOjxzQX7eKJyOgBswWAM6XgtBY0qmLJaRuz
61lyLKtzoDpdoq+7ujTNySCjXaqwOrcnS/9ys0KITCZaAWRLwwJgN0cwhDdn
bqVtT4U2s+NAV0NaYtCI3r26dzOMdCEx49ftlfzILXQ9UdeFw8ej7+0EBezE
1dsIX+sVSObJkODQJEFVM3+9Olf7NqOq6/d3aGyKJTMJzJC7gEDPNibGeDfr
JmTPnb+3YlT3LssKfZMu1tKux2ykYNMYCH7F79ZlCNZV7A9aYBXrMkwCSsH/
0DVF0nR1dj1CHgxq2p7aEALP5YV5yzaW5cM8qZoFnNgC/ZGI8+pceMuIE7zK
YhWbooEIjAgKhSEJUGqdZXhZIBSNQqyaBduIWBsTMm8iaGZye4K0sVPV7I4H
JZvJQTk/yci2IaLhaDxzeEpOytW+C2LYM8xS0SQeKCSxrhU7a3BVSj/zdLD8
GObvzOnia4d6WrGyLXqNO5ZH3E8ZvgMvde2Iu1mJNZSv7sUPzVcdqaSpX/6S
oVavErbQoaGWmTIhSFlzKrBkOBYPYQe2NWMJWTwYXQIJvWbsep0KmK5ht23G
QigBIR5nc7sCahatYlCX7SyKy+LolxFMnEneVbeshUB8YItgomc2oPnhRfRt
GxcdLknO0AHUMCqyW4/ySuF4nqX/bCP9sXrHOkVsSxLKxl8hft/1JwzgURgb
ZJIuiTXA7MycXFXSKk+D9+AxDzwry8LiEKw6vLKJHZVyBYuiLmhhmdeOi5oQ
fOhaMByvgi3zKbqE1WSKLBOPhWhYAiwbQ0tVI8UprgwF2adEwRtynCDHHC4Z
gyUFf4j093ryHKtAwDSBKwmnZ+TEB+Q8uQ1smvmSnH5ULSdJBb8sZSOpifkz
pD+2HH6lmQVdFEfo0WrOQSp0oQTgPatPoqeazCGGLSJU82/hiWCuyx2pgJWk
JD0I5gNXQPXWNtMOwr4miCXBV8+r2lhIPcRqYmfRLiNdM05hwdC8Pxe7SJ5T
uZvoMHYGztnaQMMIoCe2EWSxQm35exCrYA52Cp4dlGKY2E3eZd7Tnxyy3vxz
p1TrHFOUvxqYYEsbTJzMmUB242tDv36HwabKzjyz6CU7QMvseGbvMe8mu/DT
ahyqMSFJ5BOVuIhVVzbXlzcIPgKKGpilY+kW4tw7lUyR+dlZHvYZLdDljm8n
YzwY2qD+RGk4EUEeoJC1jbM5Fc5G7JPaYMJS9xmzXNXM6Ob/RIST3qrMjt8x
dFxIQNczcvHdmb3V+GHxTVk9bHsnQUk5lqLE78Ug8AgoqTHHXgKR8qUFYEWI
3UIgYloYK0jE7hy8LsNGMVONz3woWivZKguKD8UwBIUdczhxCNVPpDiSeQZ9
N6nBG32hQZua9CBC6GIKiMqJFcVud2ZSN8+ex78soscUVK1dbN5GER8O/C2c
uMIvKxXFI+/KNSfh0eQYvDtVCugtr50dQGX32TEVh0UtWIou0z2soLMXJjWk
JOwA15VElFtd1XRSvYMYklb0JKqtHuK1vDQRtLk3HPNugxs89xjBAysdqKF0
Lz3iutBl78+5wLAbAf4aZ2wmoOu2aiqkHEthqXsXkmGYDsbOl7Jq5Ao6UG5a
Rg66d11iM2kFeoMoqXgng1/Xu1lOQoa50Efs18OSb0KA5Z5Gcvcs5QarLcKn
270/9wa1odXlX5pPk9v4JxLQZhSNA1w7vW2b6ZpN0Lm04wQSlgkZtIaeKe9S
2N6y3ZjXJ3hpE00akYJRIM7VCQYxKw6ztRJ9sDHMicGOpgTLtZuMXmLiFvJo
fnKkOsPewdYSlxLTO9RRZ4VTDaCNbZAxTJFYARkYWtMgLDVc8nlYagTTKNl1
WLeSd3cSHlLUgAUlaxZ/MSVE+cSfYUP+ySioydHKUMOc2Ppcojux84TstmCG
mtvIu6wmgL7rBaGZ+ybEABIo3goN7iiYN1q3EDQEJo4uTTvjehOZua+HYzM/
3IwJYzBxfKhBmbjZRwHFqq1bAFcfNbNIqoqwy/SuyeZc2MV5HDaLTUrpHH42
KZufnnoBYH6f0kcti0G0G2bgM9PLz9nmyC7l0JwgCxuLM26UOeeqwdVVf5CQ
UvCXWeHMPmICn5XzyuFAfx8gMnMUOCxj2PRDjWLGQ0qq6LLTblc2y71kpGvJ
uzptu6hE/jq/zbT1tEMuv69Ol42YsXeQcXeRLtlZLWa43VMtm+8snXuXpAaN
Mmcry44PPHiqK2D5DdSBVzzRYn7s5CTmdyJ5jnnqfpK0aRQYRuafLa6/WbSs
EWCT0phYwnJqxvGQN5ZYuO+DpEtmGLHq3SeR55g/LocXbeuciFksZr81u/dH
5s6ItyHjs7b9UhL5HK91viqVYaIosMjfLEEKuzDoKgIsy3FjTkpVFMQDVwL7
B7OX/kCj8l1/8wgOEK5rAy878Lw9ZWYxA1jgJi9eX52FSfHCcMAYl7np9FyO
aCIlvH80e/73DV5/UhWKEYdXhmUhnDPrnM1Cuu5YJU1eJOUVSOpJ2h+rccKU
4+3k3d2OOCVCcLmdIQQy3xgAatKaCP+I0a0zCcOzoObVBAfMNmaLhUW8mBbM
pB47a654ETdKiZf/bXbHH+uiSmxLLOpWgoDhReEw35kk/LJcn1x6Y86sSJip
3nPqNtxwy/O0AC4rsWk8+c5NioOzPhetl2ElP3xxshJP35s9PTyrPGRRNXOx
HC+uTDGV441XELoxEyLHSzEzR/HC3Eg3kXfzKvx4ju1CDi/Ls9te9HjB2jK9
Fhvj2HhRQW8Ktih5pn0x04plxDz//POxjVUJZv5YtmNfSPpjx/1yod6UbKAu
7z9++cyLvrW094MO3qRMBTbXNW3wpzt7vMIBH6ZgbyR4NrplR8tYXu81ZGiW
KpYfvHZ5HXQfG5YG40iC3SfGSxRd3qWFJdkKXWHcuC8i4LLnwsNfZ3UZmjEW
w0eSKbiPgMe2eLYS2U7ATKa3kP7YTd2nVRJFJK9DF6S6oQvSfhR0+d1hprjz
l1i1iBMIutR/YVanuHLeTEBhigJLJGXo+iR596IKDXKzlRO25haUG+Vb4WBN
Jd1Mc3hxx44diuokBUThNb+hZL+/hcyPFU65gAzNXKmsvLn6joDfDN7EGQIf
z9QIIOfao8pgk8viqGBBViZ/2H2WzHpmWU3MscAMCZX9Fjr0aPAGNPwXo6Ah
4f7SaNjNxSY7I8zOnDNZ03zJJM1ATcZgEX6WFXgtGcNhbCAgVhjzXiopq90e
Y524TmZmZmznNk1ZZCYT9VeQObPMAnZUjPkHTmmBP4z7COlvI8GLGkN2YNqi
RLVTgc11f5JkDywoVciTAhFMFl5DwLuYgMJAZrFYxh5PNIPsj3QijWwUkP27
AF9Btkw30XlzZyxbJT6IwvL+id66Ytg1V1bw7udC279cvOQjcoW5Q4MXh5Ah
o6Ah5xpldtsZpVrZjQQ8lol0PmljILNwK6sUoyD/yeJp9+QgQwh4paEVyJN1
AQJfoFIe/k8wu7j6WQIAS9xi9+0x65idFlE38m8vXvPpCB5zo+gYdqoTikL9
yO8QeP3iBnsoiS1SLFYMW4y/QLr8ECHTkMNlzy3u+3wjbHhXY6J+JwN5+iOA
5xUJ7IKqTyVpI2pcmyddSMwWHgP5OgIeKxPCRDhDA6skriE/Hy6EYjACGjoW
QBD9UZ0Oic4btqJJiwuKax4tHq4OmdsXyZhMuWL4ZBG4UwlOAu4SUwBkbQV/
v/4u2ImhIAijKXMbxqNwHg3ltFmJWLaDsRQKJtveX0H8o9n+t+Sv6ZRqsqg5
uDJmv84g+J2pF+xMlUrhpIQNo/VPE4gY5EFk1kpnSF/ssJUWnFpa3HX42OzU
Cw4DiXMBG1AnwrwyzXPnIPMtMnSo1MlLIOX7F2bOMgGZi5Bdn8CqhLNyM3ni
sw+qsJglMdR/f+ny+39w+IR5t9LT59RkyDWmXvsVFjcgkTCNdREoqtNSF+xq
IGZVs0Da60kbwylzmTHtkgWvmNs6P/gW6TEBo5qlngSMr/UGnpx5zGVu+fcK
+A+StabzbCfo1sWXlLVgfpv1pI3dNsoSPdgCZ5tavwVZgCg9lVi1FclRw4b0
m+wIDTPP1sL5iH0EojJGBP3QrXHvqYjehuDeWF0OnfwUgTfHn4sj08gLORKW
4N7EzFcP5Dilno4EeTsV926MdgjJta4hCEm22ocIUMxhyOwGdpQyD5E4B+mK
SRKKkIHZOfirVaVXVXXMdoJXwU60JDXDWFUAdlyJ3bPDYnbsQqg3k7atFWCi
3Y8KmLlJ4F4xwJLaAeywOruqlQUkXDqfjF0FJPjJBObNZxqa5UP7XOxWqRPB
J94FFxtH4+yxJgBbaqj0xwInLL+a2QcnZHA3pYV0Mlz4cwmPk7EUbov4i9gZ
BW4fNYSYU7gTc/heAg8recvSPvLzSfiXmcOstL/VhVVTVbSHUWDzZ8ixAajr
0rwbsjjYFncDaWM36bFCDixliS3m/Ih8dSYlZIgcLaY/e+RT/2YUeHF6fBEw
w61RMEIyN0sOrIvIr+jjZXvZdoIUdpKcnRpXBFg+0Auze461Q8CedPXLCVKW
l3MDaWOJZ+wmN2bhM6WJHXZmYVhmgbECC8GL0BcPaIkUSQpz36spCbpDcMtu
1B0BZxY0FJfnEy3nvnbIamDhlZX064vJc8wZn6cDVF6WPrzUy4vbDiT4Kb9X
Q9PXJ4Qq3WmDIpZipbozNkJkG4uO/YWW02doC+hdl6AjF/6+zfnXhppQfgP2
82KbEzvxpcVCoS/CcI9VKfBeWDKJOQn52gqnTOCqQkFuVUpNxy+Qd9kB2DUt
8KwGgLzn2/zvTIQwXymj9T2kTcWKBFUW931ecMo2As0Y9/4eePnHwq/Ls2T4
TRS7HL9uo6JRi3rEo1Y7mJ0wYSRjh4+Y5NHABWLYwMDXFu89AjSyijOKRe8A
hwneCounkemsJVhUzJr6JXXPLtHJZxbtAdIlS41i1xGyw/Es0mYBPdWYfm7x
078J7DATSzPPveMU63kUucgwYYE6bMUUE+U0WbrxgwQalkilbn87x/7Bxa/8
ESAMeZk1J8nY0CitrY6ChEDFFJrAbFhZF5ZHw3QmFjNirj2WmcAijVowy7bx
7S9/9//BYX6dog+VFxwbMhVdvUjFgKNP6tWXEmdHM2qMAo219fdnbSzZiKXK
Or2KIKm2rJjzjblANeFF1IRS3slfenLI3PB22YT3P+t1ZMXy8lKxMD9fzM/N
FXPlvwtLy/QcrSIy9xhNp5Ofvuwz3wVC1xEhzKyoGwlAzPpgFipTyJl+q4ch
4xg7Lq3GZ3oc81EzXVp9NIAvHppTRrZDbuJTrnFnALAUaSXq5+eqOmhzIMGh
8PfcwjLLvlIq+ONB8HfnVCjesQgqKEcnxStZigczldgVcxfknHpIyjdeRLpk
lhHbwRVhsOLiFBWxdqBFNP8aEjVWUsTSi/MLxdJyWqdVyy+yVC9FpPf3Qcae
VYESM80UiyaIJMuMBdLZjYTMSc2SlNi2rJIuKaemqPERoibUKA5oJctQerQZ
L+kAF1eMHj2suRbIzl43BYbeR4DNSiWJ0bazTiO4vidyeKti9KjmmRWoR/nG
Ffkg+jxxnNPEX4J4dnUbC5QyeP8hwYvOz/Jy3B2xNetjCLwVLbsJDkKl0mYB
kmZdKLxJBUNmdZlLkLjLVoyQMM/9IYI/gW0C+4beNuMLLMCX2QobEyry4Rta
WpgPUlW5YAhWzEEsfiZ9LtGU2DbPclvyioDutEUyLgvNMic0U0Pe3Sx1bc7i
/mdZVxo29XYYrIkVcBt2pk78OVfMLywJThsVBr1wAuIkfqFxUktrlQRF5g1n
jjRWapEF7li1HKZ4MkcfCyKyLJD7pW2t7a4SGhm4Mhn41o3Fovgj00GkWcnj
S7hKAz9LKR+v2RiopO4lYA/CjVd294dcjJaRwnypIoXYVsQOyzPLtA3am9yL
LEn7vQHFya7QhOKy3+aYaZJMiNBAM4qX5kV44q/LOTr9VSrJBWi6nCFAgU7x
1n6OzOk0giZWy+DvBnHaVJuJ1WAOSnHiGwB3Dd0z7d0GcOXSFQU33gDpwLXa
SXIw/78moP1jsvD0Vh1amKsE7ZyWYHSjpPC37+RVoMN22LA4/J1ocqmVfae6
YJJx1ycLhoGcHyDZW1WSIHIquekaLeYFcmXc0hK6Z7fEj+4Ihp6uIGMyaoXV
p6pvfhFHE/ZhQ5Nc5p2hKTGllbtsH5KFwE4bskRr5jfcTlDM+mPVi1mI/Awl
pls5xsUw+xnGN2WUstww//f6tlSZqmHd/z2/NDB1zpsxF3LCyPWDSpiYDbIC
YXxhIHrcMScMi+w5H8dQwvgjJSx3gdj05mwTVbQNNczpXd/Hx6dGVfg9vaMh
qJgbSRu7Pszi3uMVRF8VasPIiIr9JQTrbMmxtHBWl4f5sm17H7w0KPYeGhQv
RdxUxZsWyvanFgankNeZJpCfT8dz6qKQSI6dvmPMohGfpD988PeGV3TJMiaZ
VNYddmFB41VqtUtsVoVBEsue3TTA2jTruHhqbznY3kDkskXmA+ICmQuDGoHx
KitekHtFQGDV5yz6LXkNauIktye13g27OREnCNGqVRxpGzm/fu0Vu0Skn1wi
4r5nd4x0OB3FZBI6nkMIp8xm4RmxPVgOwJtIG0vf6irDvfSUIhAEfSkQE3/v
fSoW5o7vXfqp52nh8LzMM6irlPSbrGaUjEO1/AKi6iOUMaOOEqvxyqfwXOOV
T/7KuPGIZdWDJIJ0JyECq4VthBFRWhieKsI89VKdMHjvYUIY5pNVw9tMDNki
lDDwh4I4+FC/25kr4pldZ+TxTK4zOn48Yy+Ix3JzPAM3rIhNV+c4N5PhOEg2
dujzEdK1ohMJFFGgXpzjbb2NuLwk3inEAEp+O2EYOlfhdigB6DfcPKZUggcv
2YKEgGIsYn5BQkGlQHyl51VM5mQ2b6yET9zOP1XOec+Fh79nlLasVEkOZBVs
WP5CfnyhaX+LecoL1crryM9eXH32KRUZGsq+l7RpAMbO54pPY1fOIl0jTbl3
LC+VpJh3oaE5ROmW4Pg5cRhpVmMFtiZNJrB68WqF33xnBTrLfWfZYswbyHYy
c1UNQKK94TNRQoA2/G6LWNompKlTzrHSAPM0a18qwwOV09GdmE2KHtToGC8P
LpEd/RMl/cRxujw4KdvIRK2siLCqm9ZwUrLTnSqEo37tof8qwVxH5Vpoe8nQ
z6wLpoOwszLsAAbLl38DeU6xZ944cYZfwgkUlLglremi12Jk6sUroPQNJ0nY
htck2i9aDEZmcfm2u0gbO8uckm2hiWyeHMxd7odheSTMha7h/6S0Z41EFgeQ
cDkyFcptabNtodHvJ+RZXduqDXlSlZbtN+y4V06aphP4rJJXFJjP/6kYUpgj
y4NiS4fRL4yxptGx5XM1WYLbRl0t9rw/5KC52okDW/kg1qPGX7VTHJYigb3P
UiSq9IgYeIr2tbvV2W6gY7fTdYd81+M0h0kCm1oc/Upz29xEW2Y4YfGNu0gb
Kzdgua2lXR3nwmKM7BgmOyK0nYzhcxpd+8kZKf0ZDfUbWXqwuHRVGA6/azPg
dX1JyvmShErKkKwRJWWM0YrmKaTV0FQ9m0KCw+waIlYcnVXvWU96ZrFGpiiy
GCITgMPqbQ0rroJ/sxM6otwyTKv2ZakayDkqarkglfsxw3Dk+H4RlMyUOiUF
ziN4ymqoYyFQs5XRJ8exFyhkQ0nGZfhkWiJLmmN6BUtqZLxyWSrAZMEzWjQn
O3fsUiaexmQrcaD3oKtgM3hN/kHzG0KP2f8RyUclr/z83U9Q85ZtLux8NlsH
LCl6HZkLw8FZ5F0WX2c0YmWoLq2kUEzKYNcxN6dNr5Cb15xHO5n4GsrP4X91
lSB9167bvhxzY2KNx71fpQGONUTy7rU7mYbjEzDMki5ZbEWltSlWIkMYnpoT
qDtJ8ugIeOrneJJg6V9PTrJ7n4Zca5t0vZmjTQubJJlLDEwVlUl+Tw2kUTNi
G8C1kDa7pYUZsewcAtMZv5iyvmzAU02whgBAL8m7KT8yyPhZqKYaEsh9hfgD
2exdrMbapDuWrqEnNUyrlgAlgzK4EuQOGnPDIE9wtdJELZ5IIDWnE/7NIW3K
0Wbi93UEI6y6Fotza70iiL+oV9tOEucSnmV34SnykMdiyIN6e5yJpDVvrZQ6
nwjyg6QMJFj1F/G8g/AFS8pmlf2YR0eNbfSXTNG/x4LW+REf56O3EnLiVOgQ
zJfvawJjfhC5huXR0lcbsEzScwKWex7L8RYTds8GywxvPuVUm4fXXVc8N8oW
hG6XluwlV7HJWHI0RW9LyjPfh2CzTXJsDQrJAFJsJlfQEmyiAoRcq8Cu42EY
7hBRzzCRF6VGG7sig5mPisUkCBJ2r1oidSvcrZxKW8Mh0nQNh5I2lOHQMqog
tgZmReQ4ZBog8MDOobPUWiYcWLFv5vjMqgVKFpYmwfsrVuvHkUfKlw3zlVfy
w2q1kJ6zn5J8U7beWBIUuzaRJR8zDmXVh1nxUHbGW20MOzshh/UVk3U9fIJh
cryMV6nPrSwIth+KHAUwyWN8KwEw34MAYNtCS8wLw5DNqg7+JHlXCZAYQroM
TMuVjbeZRWt5rjQlPjlnx6Kgus6SG6XeSybMLlxg7s2JFkjxlgM5WWMn+ER5
DAySKIo4Mj9k6eYJsSsfoGAp9oEJelDTZcf1372HzJ2VRQqyqU+VlrIfdgdD
7gBxwyWH8RQtXgWEqK6hZfQE25XP17BT/oIuce1lX/wsAYhFgIJHYk2jguef
ZVXUWHr+faHNsmxkH1BPRWKMaNmAvM5lDZnFuNm49OyaP6OFEoMscV/NH3Bg
vAir/F5v94zAnu989g8QRLBCLwzh2n0N+YwrmeuPWYTBgI02vggYlsnC3HJK
GF8vB8pJnTDHkZBLaZOf4VIHhFnJcsxxU0YE721nxSTCXl8z8NgRVhYOZNv4
kPItCVQsxsEWDHMVMrcgs6yuDm1mWYl/g/FIM51TV2utBuR4eb5DiOxvxIDd
oEROLv3LHWz4l8k/pvCdTAhePsvqTDJfISMkK/zBVCImIdn5bSVakszCmKBH
iMZiKapN2NXAosK0JuTYq9UfDoIQV/8IfCbzT77nfx6oLsHKNjAntSBUjFZ2
/JclUTOlp9l7zGN+td00e1dPaloNTTFcT2hBlqq/WiHjOmXGTrAdss/5q1Kh
o+yIkxn839Mn/b8D9RoxkcnKL72LjMQuJmYGKaOdeoSSshEMr+yAl27PvqgC
XDgt8LpCCmyzKiYXq3hN2KHz5elNsj1hm2KH9Z9sgToXpUlAvT20mRIqfzE0
aSkDv2WDAVpV9FWJZ7q5RERdpY8/m17/7wWbTAr+XdIfI7fWKkwKYm5shsP7
C4D5Ghx+MSzA0F2u0jQsNL7QEP1TeJNtz8H7w+m13xcf0H9L3mXSdy602X06
Ek5R2JJ8++kUz3LtSJ8D1iviYRhNfUOW1aR9B6fS/FxiVTQDmjAFDDp3pOE/
Tk/+OxFpHyRwzbaAH3zLDpncrfD72oqqifmiPKj3XUNBTDeRiNJcRAEiSp0h
37HcB0WB9yZj23Io+Ivp7vck6Zgl17H6BSyrhN0NyYrWMmnGikmzk/CBM6as
7dnfuvD6qNm755gb5dy40hbj4ZbakgpSdU2Nu+YXqmQi40SmFSiq/b4Dt7ND
9WC6OCquf5ZQ9S6CGhZXZx4RhuprSH/sYneH1tKKLiK3otU9x5zGtRT1mETl
knMsaYftLYqyfG9RlF109A9/AJTJdFj4n+VOM22LOUlYzGwDmeJHyHPbm/t7
9s+vr7iSnbRmOhZzgba69KybSlTZuRR55x77zncHLxR7xPvAru65g7S1QYCT
eES6ERdpSyBsO4Lr0IBIDjQz44JRkaWLs1u3WcJQXkTObQOMYkk12cvIc62u
49LyvL5kCYSIbpdWvE6SMVjF+BwHaPskgYMl37CiefcT4l5L4ZC+SOFkWLhs
9sPWoW/LnXcuh5juJnXrN+2P7Vh3EgpeE4FamVreqIHMyuAVff4+Mm6INPeT
Nvc70x1ZmVRmfbNzFcr45osUYqoLZngq7ZCC6GBUbKUQ26bUWRREwq853FWE
vZ+0ud/PIMOxDKWzSZvaCFBiIikVxkS3tkuPX3zxRaiEErNtJaFmCIzMGb9T
GcS3lb+fSbr8cmhL7h/a2jjnJH4N/a2VXGHT/nLjkglnrF17vkE4b1sSExgy
bS/TwS1jT/taMhemzDBQynbmsGSV6kMucDdaaYfDswxCva/V36aM/LBR+Olj
R7/wdeg3FEKvBdf9p+Ldi8lV5ffsmMTbyeuhoFbP3DlH/8OGotxuC+9GZ2Dm
l+oFQmK0cWBlO+oHKgBiKhXTlZ7QBeHrIJffn9w8d1/qGlL7+ObOqtWxRA52
FfPfC23mq5aw1bbGicdUSjGUW13TzZLINrcAwmXqD43/u/6ScT9DnssuLRUf
LwM2uLWTCyfgJGwFr/p9EY6MOUzMZmI4YHn/rF4nqyHK6q4zvLDj2m0qwrAz
BOZRUbVMAh3q/k92csVnfqPnmtZcr6suuc+FnQrSetKHjv7SPxekzobJv4vM
3dRMS3PecMvzdHGzpFZ2ToIdYmG5+XlaX+WMHV4Dhh2I0THNyyVaBguYqWPU
bDKgD5vEqPhPCAhzQLfUA0efeQHoPngwzDUvm9AU6GbovigjSzEzZyHEoSRo
OubC6hyymvsWwmSVVVSfTC7nay6tW7vocF0bsaEYzrMYVD+MGP7+E0/QqqvD
LiNiIZbnn38+Ds3uD2QShp1SYc+F1dYFNyJaj9xC7O2sFo66lr2ZiW29FcZU
0FqOkDgaFF2vX/7mS4MDxTNCKZbgxfJN2MJk9j2z0VlWAKsTqrqqbUCSn6W3
q1kSmS3OEXBQu2ZRp53ctPQYAZmFb9uAh+dy8JrOlOn+Zdae7BF76gsFXuf1
I4DsbXuwj4KcpCUwW5clqQb/XO1IBrNxmSm/h7QxjJ2hC90NgXUBlQvrRKQ3
O268ub5IAP0o2PI3KmMT1XUS877x10EyZZZ6ypQyhqoPErQEKiUWt6XLY60y
dz/zKmxOl4yZcq0woseWrCQ3PsCO6beD6elYAv0+AgFLLWeFyNj9JkyVY/6i
myt+xBI2vXzYybL6qadEe4WA2DACdnw+CHhNsRPTxPHX18jMGdRhivxUNcuK
YUzAFGjNa4WLZWDK/JBtKwn7hTklaeRQSDmKBJw1dZEFpJ5eTSLmqOeIcYm5
wYws/ClNnjXFMk9YOQ9rmz9QIUvvdLYwvohCDQ+QML64CyxLBebd+gjzED7R
cZEzivckGVJxYZub/MU05fyK8r2uzAJZahFnPrnIJyExxYIxDEvVYkFCzS6A
PIY/wvSXISj0WQ/QkU9os9QCChOdGv2cknLF4//oTe9HD7I7MAnALnz3cS3D
yjXab57U6MMTK8X01DGOPRxzwp5uyjFDi88YwMIZBS0+ZIl+HFo2lRL7n+w+
59k4Bbbq2YELdo6RyV921ys7yMLij8wZzOZi5XTcc+ZdhEP8LIJVdST6/G/s
5RvbYDUI1a6t12PlZ9Pux//gFJVq3/jGd78/ffIP8TbSw5gvIc9GcAcEqeXg
gWVnr9hGymq1WmxDN0JbjUMQ5BUl5MA1IKgxGV11Ju/ffqB4/YcNV+UG8CfT
p/2ngbrIzyNwMB9L2zt0mcG6k7zLdO0hd/SZj0C2yR0EeUFj7fndwEyRYiQM
lhOeqjjVtE7oag6D353e/tfoCAemfm5lWS0DsTgUM9C2k/7UZrbsToltnN2I
hUSgQ0nYxBHATw6qBINF46Xftgp6HLuzRPZgl3UTCMpeWK4xs12mCKJYBJUd
UNHwOGQoWEMybs5pRgrIid0K7IHfG5DC/DQ1cy1DBlRu6E8fr6S8/Oez+Vk4
gV16wGwWlzEeZ8cWy00Ew3qfNoQOpgi6QRjtHwF6H5GBCGbB3yCh46nM5DqV
n87Q4jXFPgGDyRomb5m6ztwW1xGU2gbmnjPNDxvZLW3QoyWLfTQEDjCmvGXo
MeVWxNnHM9Dw70UZytTqkOFZfi1TdxiZrlDE5X5CfWb//hs+PTA3x60j4MDr
OzAsWJmYtSkOzKUih8Oe4SxC4fUOw3pqe3MYwIUjt/3vv/u7UI7xgc+lFajB
EquUkHJFwPQ+Oe48coWrr78QL1haSWdXR6JnAQzNzjky04opKCwLRINUZnNK
0Oa2EUD3djX0CzVnkrsj7idzYdx5NhmGyUN2pxnDiyoZtkWK0/D2EWDLhZzC
Fg/q4683k3HZcXCWlbODDM2qkzEzjzk69TnLjhH839EG3o2V1IK9DJoCdtXy
ffmHGrwY992kS1ZGnN1i21xPPpqr+OB31aWhycB+ksySre3BQ5mNl2NbfmDG
BVOTCxjY0mTl95mP5+1kLleTd4ecpEr6u6Raq9BuZK2eH2GrSohsrkslaDdb
2uCKnZlRvNg9gCLG2PplDnSGA2ahMqOD6UeaeWqH1iUeoinZpMhUEn0C07Ti
F7Z+FQcw1uJ9BmxNszPi7GQQO/H3tha4ajrCoTLRikrJgdILmvFijmaLe7bC
i/aXVFicJfNj2s7dQ3jNwxE81HLVshnHGIeBolLLWzYg8ckUFBlZe0nKgjI3
CCMOa3sHASokhXYxaWyCAALAXNgMgK1To8WWON/R655ZgExcpKykBiv+11w7
ITHiMH5uiVanMMScgNVjmL2IQHwCJ9lr23AfuzFZNZrklhEWHWXqPot351CX
bQxqx9C2GAThbKEzmzxTG43wrdCgGyZQiIiPeDM2N6Mmua3nZwlqWJGMrE3G
Z+Y2S8liWSPan6UbSDiK+f4ZrjZwltnWBldKTu8+g446BF1J1XqmqrPjSixH
kmVusNCBHs6wccHFWEgsFYj5uDaknIStHpw0AnZ63qcFR4hw1KZmFCVF7kKC
Lk+0LkFmqTvsAFXunm3yDbH+mBuAJXaw40AaGDF/EeQItJxLKuhjxhc78aSv
+9oS8K2d0n4dJwE78CZDvDo8ofdFuyPsk70EGrQA4pMyouA/F6OcaUGAJrcT
K36oW5FHNrYhqO2YrpgNAQNr8ul636ypqcUI6OPMu7EZh+ZlEd2Z2W4sHUId
ycVXDxgym9e5OwNCIitxZ7GsYmZKMIZmZqFdBVNKdqhJYGCYLm/QkdyjYDJ2
J2YrMbGVM+oQJJsSIrXDmMGYOyrxLzurzJYsQ2TZzpJyg12aKCaQ60EZ6CGb
wFgHVq+wzqntMSK8Z7lakfeUH5KLKe0AWUmkeLya2XcsY/s60sY2B5d5GOfK
qoDsI+Pq9myqgvhJgp6YBDyxBZ/WBj8atfLhJhwF0Qwic8fIEmR1K9jy+Rxp
6zeKhZULrrBzdOG5SXN3xDQi/54uLq+NwJQ6vT1aernMk7OydlrI3yfBkkmZ
1pTjxrkPkvFZnbm8XkmTOzFsOlNmOWErshtv62EyhmoB29J1TeEtWuGNpCRE
Uz6EAeMpGUb+zzl56ObVJSOxPZ7pveymDp2lOY+gyEEys8LyLMqux9a9qopw
2xltEKShJ29OIOdUkZEUv/gVMnQbTLAjkGwdNbn0mLhbX2HMK18sLTxYdogT
HPW7vagLo6DIxySALp1qcik009I/QNoYrzPPkS/1k76bqEzyqSqUz1MRxRiU
2bGaHIFYElQwoBaiRZ39SeKY7qc+exChzTNzrLIL5ar6GO3uVO2TPnqEWhpW
zzcfpVZSbYypCCwrkVVqZsosU3q3ZxRkthza2NlktsE1p3eJ3wsUwwfUUzd6
YvP1+R60vQ3F2lzC0xuJSj2/pqIepUxpoQhx07LiAqx6JAsTMPuEeS6Y7uxP
hlo7S7Bi92WGdyVXx7x5IMvVhCx6KXC+vcs+14o2cXXUrq9K76dildAYfUKQ
NIlFI9lBuQ/gQCOVv5gVw+KpLFLBPPdvINO5hYyxrY5ebAfsJOkVjShPSs/g
9+mRsF27vy29oG00bPcQZKppd+oXRJDmMHTiSu52kiOWzGnEMqWYhnwPmRMr
nXWtyhA/hvt+C6cIC8WwA1DsRLhSCZiBRDdTaQwq+QsT0+faUknP7XmPDebE
GE43t8TAVaLZ2VJxZDJ9hV2zyw5CMM87O8jOjGOmjl2tCM9TYp1vO6csszJY
cI9R1tCxvFzV5R1N1NXuG+2Qu94IWSVPTQWcj2XFIv4cWQkxda+wUKJc/Tss
o7oeol45oKD8lodR1NRsyrlpXF5sKps5XZlYtl3Z01DkS/eVphctdSmqQ817
Z9XzMtwY6bJK62Ips6gU4wJWl5ppEScrf/j+MvIAHFZniy2dXZxCs4QazKho
pYqvtqDUg7De64etdZKsI6VIUuRFCRzhMPezszeHKhbsVAVJYZIps9NqeqsC
1GmP8utaoDyuPY/y05QpR74Mdm16Gexg0NRFMxESlRIfJDUYwRklkrXR7KBO
wpzAHrNpLiSvmzPfIzwTcPHZm8n76iox6xQfGApvI3SsGffGWKPd/5oq0BND
+mBkCOut5w2uaOj0CBnUSQfPFGATzxRLgmcG0QYi/RzuWCli1jXR8rz5yhRD
ZjWfrPuU90tkM1IrOqEmfn8op9wZcaGPfC1sl7/KaBW2guT8MIyeIWSy0Ku4
vVngkJ1Ez+ngQ0ErpQPlKY2VQ6ibyDWSM8/UDBZxqo4uDy/BoLoD4p+edjdE
bB2FciV3xpzbuAu1vN+1T54fQkGsLqwy7DqxOGtGQQUbvta487AkeOaWY5dK
sWRTfxDY0M1Ub+bhZAm3zOnEBIHd95qriPhbyeY9p1Auwo3NySFiaFg7c8ox
B6kyqsg0a1OUJ2brunTRyBaT34Hi0l6otVM/2ls9d+mnnk+q0BmKWP095ltj
OWVXDUWXV3Fw+qzG6AxdWgDcLnlrrFPCDr2w5PW12WLNNc4mdyVL8/boMzSw
MAQ7ZxFSWSQdxQ5pV6jq+QJV0f8+Cr5MM5HYGoOHCbzTyDzXtBBuba//Yf2z
4/8hGth95DuoiFoUS//raechcKC4AS68kibpyTNtcKP6q51BlQMgLN7PToud
O0RKsH2LHdxk9UiZs0JrXFjGWwlesWnTwa+zq6rUGQZpYhWObCduVwRRcWKO
Fjmi/zCBn6XHtoEHz+3WSZbq2TP/7myh6TP/4tKbp/7Nt79di4uy0AAAdZnz
CuSm37/88vvPbwPjuUTkqji0GLl4BX+BwN22ZAvzc4eTg5PgXTv28eSTeMFd
Jv868h6LCeplNd6fVi6CA9/au/dHRSskqHsTkgWrR1YNO6VkRYy1pJ5FfFmK
Hksv14iSDO3a2abNdKmww02ZOQlg5MCljymXz+1upFTfuzrw7we/8pU/ggna
CklByvd8/QsgSw40sGRrtaYtGVw2aWbIXabSg1npbGUxLJbtbB9mKk2wvqO2
iYWNKbK9KSB8LSC0An34gM+i8e4gaaxQvBJmd2QY0H1XrqXTjCm5kNieZ/El
xbalGIn8voCg5DJ9OrO6mXK6LZsqvmNDB5O5CywCm8AqsMuUryAB1/qYqt1A
XMNoOTOmb42AUZrpp4optshnZCvQwwi+JAwW9QUEUhZbZVfAhVt/u+bUNQWG
yf+ApbU+eoQZmjxOnETlsMxtdVYbjJytGMn2aCgM/9fWrVeUbx0117Xt8Zaz
ITbpzxNqsr1okozNirerV8nLf/juJEOcRZuCY6DnT/oh7U0iW8omCa5abfAh
7tg78MwzLxgCYqeKBDvnJAvqs4SAZjTHtsIL9aF4wOunV+LIhDrwHU5MJ7ou
BLY43TqtwZXh3Q3Vf3riiT+w7pAGBS7bmLK/FYL4LKGB0TumoEbzp7How+Wk
m6CXTYG9TF6IipG9qiot9ixLcLS8EJN2CQrOjRC3P78hl1aqiEWmU3xO3SiW
aiYHK+zEZ02+Z21XEZh7Q9BUojEcUBMt0DRbExrU6Ay+EVH3/c4k8sz5KEar
+a0XKBtusO2BSRQ9kFA5er412Lt3YJkVTI1hEo9VxenzRcTKULDjLWGf52Uj
FLVAJVCK6cLIEX8ok6ZvUlKUS8Pnsgl3XDqCUPE+IuhMUlxVcQkpFp/X0xMX
Df7wD/9y0OlYzToW7P4JMl92B0KPoLN8P48DajNT3phqH+r8dOElN80Jazg4
1/tAmM/fsnNBI+Csnx8kgyIOsadok4vMU7RJck+sssGcCczLLEEvuX+tdsvC
ga/SzGZ2J0HgrK6ZSbAGIMZZ5lC4laPnHcJgLtGdL2uDIL3oNVcRDWGa7+bL
gcS0H0WA5XiIHs706nsJ2LkKiE8oECc7N3Zs9Anki/eJKeG6oLyHCzJLNtnL
28POchB7vsoXjBHpVAG2ycnewqKkVxNCseKurNyz1hL02zYQy85nvlHxpeLU
lAyhzRVt4GerPsA/RRnKzV1jbBB2djoDisztBKMsIMCSCRg2mEOHZbAyC+n0
dBWZNqBFxQAQnDeCrd1tsBVc71O51we/T/3aeyMcmveLbcGSU8HBrIYJu2eR
uQhZRiUrc81Ot7OoJ9v41aeFacMdBSTgX1l8zAPOXI2slFgrD0CIVvRBE781
iqT/9re/rQdKLfkc8wLjsSjVTQRVO8mIzCxlegaz3lncQ1P9oNaB6gN1obBL
k5ijiQU5W2HukkoGeMyJ+qniyk58yKF5do/6uwncJ5KxWBbDaWTialGBRHbo
BjJCSv/lB+rRB1OWWN6WImnXr//6v4353a30Tz2jkSu14iBQJNlERR9ndwe1
QUhldqUTDzG/HhAARAw0RCAmKTu7ra7t0c1O9Xhhs6pp7wqo+XHE9mYnppkY
Zmdmrq6obO6IaHCpKyyhsvMxEOLLhTTmKt48LvzBKKxZdqIVW9Ubd1wOOPgY
mdPJpGvdbCGDjIboRuRjXnWApXmjTb285k42RTa/Er2cQgS9lRBQ29MKMslf
WtQOdj0UNtvD1SgH65nRAv3tYTJbhoVZFTfl67ZiQHSpJcP2YHbmTzPJc4cR
sFKOhjdTfXx9hp5ybmOhh8XWYQfEwjlM/k/W8QUZz4I1W8nQ14a5+20BNiK9
Sb4gNWaqIGvioDJnsbkYbR6Gl1Zo2U7GYmlX7JzlFEfL3yHDaB1bBBfMHweD
RkrpM7PqSjJc4NpEKY8oYFmfrYRFDr+LubNjvyQwxpxYCU5gxd5HXv8JMp0g
T/uQT9ixoVEPdENC2xvJiGFDnPRowVrf99k3V0OdOC562MlAlqXC2Pi0OioA
B6tYz1ARjgUl+yV0PlEgwn1WiX0iMENiuH4Z2MwQaVUZiAkQprSsj3L4WNbW
9e5oSM6D5PVzyNBBIPTxuvnvXv5P/aJUUmT+tyrTlCP60IdhhGmqLKeCY8E5
eWlqObMHzFkjupVubBKC1vA/9kzxkLHiKuwemtMIUoKImMSuA1Fi/W77zXdW
IN2iiMsUY9jyUA9YEObECPSIvMBybNWP4J0TsaANkygqPbBMBuqkxS7B8rjY
8QuGJlbcjalgJ1TLzUw/WK2iyTEOYpWMQwSin2ue5o9507jLjPk9NDIAMvqx
YIiD3My6tWsSNPAE8LAhsYt+WSiOXWjEUuGZQaARchDTFgFkO2Q8FgK7jfWK
CkCvxpoOd/0IyEyy207iRILzCG2M1oo4Sy7DB3zxc2TEYSfq6l3GjS7Xi9ji
YNZ6oFMfYs4yD8zyxSJjeTutSq+wjPKLlIalAcmEiZoWPn8CpgUL4byTjKjH
v6FAmTjDViHbHTMjQli85w/T44MsHRqZHwvsIhYyERnqHfBAN8K5KjewN5lF
Ff217OQrcxnd6qaSYrsHPjN0Qg0QecTSBG6qth6r4V2wejBM5reqEcO0vYur
QS09ig6qQRhzwpjqy7Qr5uNmBa67Gc7w3AUVzkzjwlAQeMVd1bL33GtkfEsb
FAQXYM8XPYk8pzald1ljG2NHtJjNwZYJUyo92NZnWOV9xGps64I8weoDWyrk
sPK8IIXww7rdXsnIWF20lW4cIg99YM/LHiwSLBa3MCxWgNk1VphlgUsmOTtk
KjMVBky/9BgIgec+jEc/U9srlQ1Htw6CY1O2KJ8Wiq0EbcoSFonHB26GNxOg
WJiR1TlnBwZ7w4EPBSwTHQwfSX9i5eZaQX5DtZr80UxgF1EyNVVBa+9Hp2lT
1Rlxtt0MB7/yJ035RR/B/xcHY3/MLR8oEcv82+xZicJWWLmxWRzi72gS6dIw
Cxcfs3Bp3RkW0mDo2a7C1nER9lMzHz1XyPcrOd/fEtpgWsv5EPw1NnJUF0uq
ZgV69oF0vzDBUlAzHBvZ3hq9JqyqGjsYcGEjniQ7FjQwfQP/4m/BDxM9LNOW
BcDfdZw4SpT/7ZWQ8fqqZdKqYyw3AyW35WEyxBm6csvvYUubhwVLB7zCCkix
XF22Yln5hrHBVqFsEUq/lh7HT9x8W60l8Q2Y2QiY4I1H20fIcHrQE2xkxoih
DW1MQ2JJHGxVjowCA4W5ZbYQtASJ3fcJjbJiijWnQxgHbuhjxdimi1VvdtZD
BBvbqsWAncqUF7tlUfbrqwlK2GLrxjW+DDVAQi6sKvKKKMEFuuykFkPJ2UpO
TS/3+g0kbugm0Y6wULATAyUPEpTosTrockCBrRGgBpgU3Z45qcNMJFPeNK2Y
J3JBNfN2eWN22S07JnISQUNwnHUN9xi8KqjUz3ViA/9tBAxm6OuIAB0okGsD
J9BZONQiIhlPsDsBzqqWss3MlnI8eogn7hpXVrgDBvG5EIjoQy4aS+Nfg5tV
o81Px1YZAekUNOsA3aB7qSimuEhY5A2Ects5s4JNYMre3QYFLPfjFIKWEHfq
Q6z7VQ2xD/G/k4DL9FB203KQupNYVFgh5r4woSHscF8lDMxRTcnOYZbxWN4G
g5RR87UV45vyMFAPC6bH0n6uIZBajKyEFIiT4p5KbEhYIFf0tlAluePXfuFy
O6Pu944I3BAKM0WDHT3Mc2YrfViUUBiqrlTXJGQ5gDByJdyaJzGwY4wuhyuZ
71QjkroQOof/1VVF2SLvvyeS7ygTBpKCjSfe1WYlMJuRHQ7WIs4WI4KBhoGC
bJyyrc/0ZCsTiMUN2rKNnh3wZJhR1xW40BaKYmZSMFOKI1HV8BSDglAbFIWs
gMww1Jn8kCfubYM6duXjpdUApmraAFjBMUa8pVr9VqhvoJoGgJSqr8w/zk5h
Bik0mScXg1WBHCm/1AnrDdZtRBjLxmDL4cJqb7D8QH/qJ0qhg22QppdBABG5
gYdFHxOPt1Y7BASEAKFCw5Ak2QIsAzC4VeQAFp7Bs1inupw8b4Jv9xI0nF8J
XouH+VlKwBhPvKcNyPeENiwX85v59Sq6DZ5QekOUYC1JnpWbM1BgtGOHXFn2
v/MgYf1ApRcVBtNTbEKjg9ovbmLmtD5QsTRWv6yZTmWSR5a+stpVRkvrZ3eL
6N6CBcn2gjioFkkBgGAT0BXsoWiDOII0Band3UhDYy3uGCVWEHpFF0Bbp+rV
eAsDMy2bRR9uqdZRLhsSua3HM0Y3AtlNJjuHc3L0Mas0BheAG+QoscKLtQPO
AVPie3bogcklK1FVPlequnJFHnwndmAp9N4HYtG70QgvASqWrMpCcnp1ElZR
buVCPYwC5epxscqOq57bTEr8LYfU8IQmMECKQWMyzHYDYoEJNAF0OPaaD5Ou
8cgGlrBBQBgAc4ZQpVcPugOEBZCN50S5YjVEmP2pt6v7vAiDTC5EtYX3eoLO
cI4fUx0n04zVnnWaWC57kiVjJaBKSAExIIf4FBurW/EZMIXvsKjxHDDJ7szU
3RmSFo/hceny/5yW8/zHjnX62m0PwgBSx5AtLMzqIlxFwNNoi0+5iLnk164G
ghMVn+UA9CrxELdjRbDcH2M1C4MvqW8IhsoLqWis1wt7CZCBpmDPSWqouNXw
in1E9QiaeM8QbB85LS7vTchxmY4ZXWG9BIwv/cfzzssJSdPYc4xX8S2RFtiL
5SD9deNKBofkUpYOHoNqjOSywVT1Bf6UL/ryU0aJHWikDttl9hyCpdVzjmdU
BOLrxx588E9916XUQfxpSY5iByJ2sWKwbkFIfD8VHk16dwVs8tnilWy2awEB
vv35Rz/5F1979N6jv/bo25e+8ei1i0uP7vq1o49Of2350W1/f3C0mBaFtjN4
tHis6PzFo92fx3f4FBPys/vikZnPg474QGQpDw0Wi1m8JC925eeUvf7C0T0H
wHYgvdQGVOmmYgIJChGCXoAgJi04fCNIh2+FmAppDNy559r2dxx0DjM32dMb
rT9QJ3tuTULZjHfwt3w/1Uhd1mdrbolqn+vPuMU/B/jy5/BNuemMno6bTOQV
XX3VeX8CfM8jE2IF4sVEKVbhr7/1rfNffPjhPysmj3sJDkWqRAgnRCj2bOOy
D5ZpMSnLr+OXXzAMO0Fgf23x3iN4EGsbn68++t7vFd1myv1YrDp97rF7Lnts
tihmfSphnb4jMshKywzaiT+59eO7zCZIB62KL7HcCna/5saI8iO5XgxrAzqc
aJDvJ2MwZ6oexDBPHBR6sVgwJjMb3zAOMNV5dTn3bE5lmzg0svju+0h/5xJE
sArJVX3zl4EIf946lvXFE5eT+bUCjDmkbqhj0OIalApvJ4NX5WyPQpeQiXcI
VZmldE2bif9UaMMko73GJrefDFBVWliMBm6nwqrcFofJPdJmInOEbLeT5+6o
+Dy6dDqV/Re9xj/bZtB7yaB6ORTIhA4xkCvvmFCHze/WitXgQgEiSl0qsnO0
Tz81zvyqQz19nwcGVoANATZhof/bmgkKrRUWp9h33cpdGl1jn6HzlL5YBvyW
ip/AsL5bmI2GzeLOCjKZVlNJxkrVeBn8KVt7t1oAGEMOdj8mQnYFdH4i7Qzk
9Z0BheJSvT2bXFWMh3p4sAByHMJda9eUh9owK9H6U6ENjo2YA6mdAWp0Jqvp
VvIuEz8qawEQ/HYeWEwUExYj/nNtJveZSg6hM+HqXugMk5XCK06GJe/qjW7+
xLUJX8OSAPb5EcQEBsyxhEmBhMK6LHmYeQZZiDRMOB7Xsn4FW19oM8nPVnwG
hpdtrFfJKHQm4V52CoNlk7NcSjbxa6txY5tqKWqFBtnzC22A+FxFcggykEqB
6GKxGNkxGEuaZzcBsKPYLEAbpiPl5DA02B8sK3A93WbuT1TCDRLCzV0W69AJ
sathKr/wIvrzaykGJPD5SpvJfbGCDruVpSDKmrqRPB+0rS6eB0tiqwU2epXg
Ai0ErlbICV7nDeCIBBmeC93vYHvoGcL+TPNj17OFs0GSzwEmAccDaX2yCP5B
mzl/SX6m5VTd75KrM6HMWf54ZsulNwO3mHN+TClPRLYhQqwNJY6OYsrGN5NV
uA28KMKFFTmfawPGl3VJen7T3yEkwlhd/Aopi/WK6bBANgtDseRiVmtSU3tB
fIBkd95MVpsNgBfisCMyrSD9Ahl3fbWKAN4L2MslbbLoYXxLusLAsqfn9UKb
jjQz5/36ap+IkVNFL7gPux++A4OeRVDJar3c2QZuVvz8p8n8NDsU6gHwAbgB
vyj4awJOwAZYJaBRPOXM6M6OLbMAg2aD+MJx5qyEEALRgRPgntkiY8GPF/O0
qqZCaCdVgg7zAI8AB2vDFMEitjKwCtlZS+UOw6qItwkRDrKowAkQnfheT/dZ
6R2IUEgMeeUOMrk7cuhX475Be95/15WfneSugQkCK4vSMb97fiYF2NcSgkAj
hIxxn+yTk2SfDH10sf0YXoFDVgJK4tgT8rZoUOgbXAz8i/YeuLsTDQx8Pkrm
+MY2CJ80xh5yOYP8rfee4MYNdjThFoJMZvGF59YBPGz8xqJm28eEjIZIWlx2
ojwE/0YPrAcs2UdSYdYLBuNBZJmsu6fMPy+svbkyMaMOnBfGAACtsGosU7+n
ZDK5pwQfY13cKDNFMHt301oKh/Gi68VN0m7pxm1EhrDgF5K2DB+i7sbnNsjP
Kaxy4MIEBvAETgdWMSwre/9W0sZuW79uJBSucHtfLgGAalYndYFMJLwrR8dn
P39zcbCc82Nn7HvQVvOEsFdnefPamGldbCJolKmqZg8JYHiTPkR4drSs8SLV
fsBWOe7QVkuNPJ5rodK2gCedePlnXu6nqZQVu+2E3VjdVQHg2wahIm7RCysT
O5StQHH7PloZXhVagxyNTM7yNpnGwMqKyfb7ytyDFlY0y1O4n0yOqWXsAA47
QMrqJzKPFSthxGr0fGkkHlsBKb0MKeAxZinkSHF66YonbtipUVZA4yfJc7+4
mgvKnhN5ni6yZCLvIxM5TJ77Tj45Pagy+o1kqYAcQrxk/G8QTnV1b6KTMXfx
OycjCxkkbR/KYRzvsq9+uolWCGDwt4HVVxj0PksWzmAXFbMDQjVYh16PtWll
DcxUYtcW1d75JbbOvkRIwO592ELeZXYvq5w3Q9pYxQqWwN5sErS8cSquy4ib
Q+WmHtR/WS6DZsOeXabxSULHN7ZADp47RNpqAAaLr5bvnEyC5WTeRSbLTmtc
RybLLNlDpO32USfragLWN1qOneESj9nDrCLHh0gbcwXfPe6gjA/G7uxTLVcD
864PuSI2GYPVRf6f2kyOrYJPEOiZB52dx24zOZeYn4z7tXEmjM5YDUfmmWbl
WRgCmCztk3dZpZFWQDBl5zdIZ2wiLFJ9pM2gLFs8T1xA2z9qxubozM8iGyxb
4p+OOwA7CbKTtD0z7gDsbO7vkOfYhVr/HR1A3mNSvk23eO7Z2MuQeTPJ/BSZ
4y7yLjOzfq0Nsn6VzJYN0Arz/4TM4uJxO/vOuC9eStr2t2y7peVzl/CJdP1D
+H2avHsCaWMXpLHn/ia+e+aP0RgtnpN/h1N14485xv+2vfufYX7/hUv+xr37
48Al0vIbbt/4H8ILiVNqirRJ95f++L8TVIAGn8lU4vRHS9XNcrEwPxddAfML
xbKiVA+D80enkkfDRz0Lc9Ie1Nly+OUlvJU4JObml4plF5MMI3jH3LpswknX
GQDVTLPnJmwK5HVMa37OfCAnlN/NlcMva7felxSek6ln75dgdRzelvQVczyb
GwZQ9VbCxiDejhmnFp+Zm0ffbRAanllfIm9eHH2CQKFTjgGCqA0cUcMREJ1I
qzAN76Na0ldj90ofPBFK0ZidkoQF+8ruzAVopJ2bOxQC35PVQhrUHin4MykA
ccbqWMUb4b0tdS6qFqUiUN/hyMiZfCiP98nbMmI/TqkauMTXhDWnjuEeyQew
mJXn5kDfNQ4sH/5eUswL11bvOxSFVdPPUJRNo1f/upxCV6UPFsX8ShzN0LIy
/Mc1sHGEibSKIzpJLPtDKQ9H7JSP9EnbhGI8dhtkQmTKpfno3tZnT2j1LGHq
TjaUiafmoTYlsb2KbwOzsHUzCm9vq7/tRsvleS6m6vK8Egzz5dYShynlyNJ8
xDeT4Xkgs4qy1GY+lTdLF8vVSM2UXRndG6pno+O+GqZJnEzkkpEj6dWdTjdh
8uXlihOiFJFZfdivFo9WYR9zbHmuS1ULHwOZyl/PUdD8GOFOp3D55VObY3i6
V81xfj7D4zDSrLxKiJbjWLejG3I213yEZF8qqWmOMbYK/K4bV4YLsJq+Gocs
AZ0chrIhCPfwTxEgWiszNVizrlZ3Jpr3V6BYAJb8vFNIlKP/aYZh2xdF8Ui0
sHTypgwGKuQ6zrBn2DLsJElrtpz8e8a+1Y6fa9/Hx75bydvVSHPlYplfWCqW
SgVwebk9C09GbaP6bk3RzNP1ttp0JwnCWFuvNfIZ4giG1rdj6GoKqziDuOad
6WGWj5/NhzKmdiQ0pvax5h8Ppk536VJM1YTA6ohjR52gZ64ZjYfds0N5mADt
+/5bycBptkugtDdcIVzwmlqW/yzBWxOzyKQ75NHV0jNyPhtFz4juk6h9jqgC
NvRc4/cwj40F8hWRsrlQymobtA2hoRdE3nW57M0aeG0KqUoSaBBZehXUD8/F
Q1jNo2lDPgjHwajqxxgz6RfeShc/1ZKo2odTXvdrPxegFY2cBQpEL1UK/1AL
dMizg2TiMv7oFuh0kXhYlom3pZHnQ5sZyNE0q7XPZyztx6tIUmJsCNVr1tUC
hwzM3uxGTInVzP1rcsRW4zjlPSfWMGwTTDar28mm6r0vGfHS/WlVpjNsbQgm
GoSqdwUYzpI9YUWh3s1Amp/3nsTUrVR/Zn1BfRVzcwlPLlfiM2gSWzJWJw6Y
zEHTuBzKvxfmD5nHCh5Xw1pQ+LqJBlcSs69fej+9PdrkXnR+MOZe7CtxzCGj
LJCeXwhoilYm9S6mOElmMdyv2+w+lL9HhrnNaEw/aqZ/SSzmrVWz8r8pVAl1
WM03G9tMfXhnyUWCnNeQRYLioxuTRxP4QLeocbln1Iyo/PuTSQAlZ9iwH5yY
MXUzAy+HQFXceua9X8rHuirJYoJZWM7HXpxymFK6l7Axi4bYe1NGDCGA688R
p9LANfQx59zGCH0oeiaNMbMY0VzYqiojIMfwVB3DTHBuHMKE5d/LC27UDLFz
buURzJRTGWkmJzTPhLJV2BniKCkDP+iXhdOI0FNFhdvIdnRiJB4G10HLnhcW
KuJZPV08A/0Bo15M+vrFMIuvF0FF9+LfHmFT2KLPJ6qJDj270jDdRDSWAuuK
uPMl2LXSriFkFzra6jfJyo6YJY/mY6bht4Yxrf6E1oOVz9aIy0AiAHkdee7v
hQHljx+2/714zf8HmbcdsQ==\
\>"],ExpressionUUID->"e0b0cefc-905a-49c0-87bc-2168854c2849"],

Cell[BoxData["\<\"Plotting plane x2x3\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268587996244`*^9},ExpressionUUID->"4ed2a5c3-4a03-443d-a2e0-\
dff2b10de70d"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268588037443`*^9},ExpressionUUID->"483effec-ec59-4958-afd1-\
88a8a3a3a769"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268588078766`*^9},ExpressionUUID->"a68aaf1e-840f-4838-82dd-\
f994aaf3ddf5"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxdW3c8Vv37l5AVCiEUGkYiIiP1aZCMEGVUpCShYZOZ1bApK4oSlRWKSJQy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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd2nc8V98fB3CyI4QUKTKShopKKNfISkZGKSqUmVVZSZRZIbJCEYmMvjIy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       "]]},
     Annotation[#, "Charting`Private`Tag$25447#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmGk4ld3bxqVUhkKD0BPpIRkikrEsRChjRElCipRQERJJKkqFBpUopCTK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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1FV4EAQUBeANGDBqxGCM2kaXNIIKSCMISEnnaGlQUFq6Q0pauqQb6e5G
QpFOFQGVrn8fD/+5r+fl3KjoTjU6BgYEBGQWMTcWsYlDEHGJR3yCSUBCEpGY
JISQlGQkJwWhpCQVYaQmnDSkJR3pyUAEkUSRkUwxfchCVrKRnRzkJBe5+YA8
5CUf+SlAQQpRmA8pQlE+4mM+oRjFKcGnlKQUpSlDWcpRngp8RkUq8TmVqUJV
vqAa1alBTWrxJbWpQ13qUZ8GNKQRjWlCU5oRTXNa0JJWtKYNbfmKdrSnAx3p
RGe60JVufM03dKcH3/IdPelFb/rQl37053sGMJBBDGYIQxnGcEYwklGMZgxj
Gcd4fmACE5nEZKbwI1OZxnRmMJNZzOYn5jCXecxnAQtZxGKWsJRl/MxyVrCS
VaxmDWtZx3o2sJFNbGYLv7CVbWxnBzvZxW72sJd97OcABznEYY5wlGMc5wQn
OcVpznCWc/zKeS5wkUv8xu9c5g+ucJVrXOcGN7nFbe5wl3vc50/+4m8e8A8P
ecRj/uU//ucJT3nGc17wkle85g1viRl/ILGITRyCiEs84hNMAhKSiMQkIYSk
JCM5KQglJakIIzXhpCEt6UhPBiKIJIqMZAp8/4/eAX5OhBg=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25467"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"2407.9574944322044`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25467"}], ")"}]}], "-", 
                 RowBox[{"793.4799408216041`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25468"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "793.4799408216041`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25467"}], ")"}]}], "+", 
                 RowBox[{"2723.62223280806`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25468"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25468"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25467) (
         2407.9574944322044` (-1. + Charting`Private`pvar$25467) - 
         793.4799408216041 (-1. + Charting`Private`pvar$25468)) - 
        1. ((-793.4799408216041) (-1. + Charting`Private`pvar$25467) + 
         2723.62223280806 (-1. + Charting`Private`pvar$25468)) (-1. + 
         Charting`Private`pvar$25468) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9804369600268885, 0.9805867047941716}, {1.0195630399731115`, 
      0.9805867047941716}, {1.0195630399731115`, 1.0194132952058284`}, {
      0.9804369600268885, 1.0194132952058284`}, {0.9804369600268885, 
      0.9805867047941716}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]3/\[LeftAngleBracket]\[Sigma]3\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]2/\[LeftAngleBracket]\[Sigma]2\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9765243520322663, 1.0234756479677338`}, {0.976704045753006, 
   1.0232959542469942`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226859704563*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"5eb1095d-850b-4d51-9572-48da5b0f1770"],

Cell[BoxData["\<\"Plotting plane x2x4\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226859723151*^9},ExpressionUUID->"d47762e0-ae77-4b44-aaa7-\
4572ebfec43e"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268597265053`*^9},ExpressionUUID->"4581f486-7222-4b6c-9555-\
4f9cebf2667a"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268597314906`*^9},ExpressionUUID->"aa240a45-7873-443c-8678-\
f79d8cff2483"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxlu3k0Vu0bNiyJDJHMQ4UQMpSSDHURDYYQEopECMkUlXmuDJkyhNCkiUIl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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd2nc81e/7B3Ayssomo0hWS0PDyrtSRnYkiazMJA2yExmVla0iO7SMj+xK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       "]]},
     Annotation[#, "Charting`Private`Tag$25584#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmHk0lV0bxpEGEqmUkowNlCGhJLaSscxDqVfii0azlLFBGiilyRiRIglN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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTsbism0vrGVv2daWbdstt2xzyy1t2bb5nqeL9/tv
v5vvD27crlrbwICAgPQi5IYiNGEISzjCE4GIRCIyUYhKNKITg5jEIjZxiEs8
4pOAhCQiMUlISjKCSE4wKUhJKlKThrSkC+lIBjLyA5nITBayko3s/EgOcpKL
3OQhL/nITwEKUojCFKEoxShOCUpSitKUoSzlKE8FKlKJylShKtX4ierUoCa1
+Jna/EId6lKP+jSgIY1oTBOa0ozmtOBXfqMlrWhNG9rSjvZ0oCOd6EwXutKN
7vSgJ73oTR/60o/+/M4fDGAggxjMEIYyjOGMYCSjGM0YxjKO8UxgIpOYzBSm
Mo3pzGAms5jNHOYyj/ksYCGLWMwSlvIny1jOClayitWsYS1/sY71bGAjm9jM
Frayje3sYCe72M0e9rKP/RzgIIc4zBGO8jf/cIzjnOAkpzjNGc7yL+c4zwUu
con/+J/LXOEq17jODW5yi9vc4S73uM8DHvKIxzzhKc94zgte8orXvOEt73jP
Bz7yic984Ssh4w8kFKEJQ1jCEZ4IRCQSkYlCVKIRnRjEJBaxiUNc4hGfBCQk
EYlJQlKSEURygklBSlKRmjSkJV3g9x/1DfE/hOU=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25604"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"2358.6528981097636`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25604"}], ")"}]}], "-", 
                 RowBox[{"869.0075622376135`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25605"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "869.0075622376135`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25604"}], ")"}]}], "+", 
                 RowBox[{"3154.9978328284997`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25605"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25605"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25604) (
         2358.6528981097636` (-1. + Charting`Private`pvar$25604) - 
         869.0075622376135 (-1. + Charting`Private`pvar$25605)) - 
        1. ((-869.0075622376135) (-1. + Charting`Private`pvar$25604) + 
         3154.9978328284997` (-1. + Charting`Private`pvar$25605)) (-1. + 
         Charting`Private`pvar$25605) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9804369600268885, 0.9818820806959085}, {1.0195630399731115`, 
      0.9818820806959085}, {1.0195630399731115`, 1.0181179193040915`}, {
      0.9804369600268885, 1.0181179193040915`}, {0.9804369600268885, 
      0.9818820806959085}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]4/\[LeftAngleBracket]\[Sigma]4\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]2/\[LeftAngleBracket]\[Sigma]2\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9765243520322663, 1.0234756479677338`}, {0.9782584968350903, 
   1.0217415031649097`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226860524848*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"74045acf-63e6-44f1-a89f-ae459629338c"],

Cell[BoxData["\<\"Plotting plane x2x5\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268605515738`*^9},ExpressionUUID->"ad69351b-baee-4c5c-ac07-\
75133423c909"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268605575385`*^9},ExpressionUUID->"39f563ef-c774-4308-aa7a-\
d96a449e9046"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268605625215`*^9},ExpressionUUID->"1dcc9103-5a82-4a18-8428-\
5954ae36457a"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxle3k4Fm3YvoRCtsgSFZIkS5Rd3USJJFLWRCQhJWuRNQnZSrbIkkilQhGJ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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd23c8Vv/7B3AKUWaohMxQISJZOdmjSEgysjKTUUhZfSohe0WFyEjSoBKi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       "]]},
     Annotation[#, "Charting`Private`Tag$25721#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmHc8l+37xo0GGkZGkjRQngYaUuKKjIySKCMhyUiKiEd2yywjTaWozCgz
ZRWyEnpINI3MxnWXmdbv8Hp9b3/8/vq83nzGfV/neR7Hcd6LbI/sPMDFwcHh
z8nBMfG6M36vF28BJYGVD45wOVIi09jKJZJPycqhpMQk8GIHjdb4bEoe7RaN
qnWi5HDw9Km/syixTx9aNuUgJYObbj9pzaREqyb7nZwzJd/ll25Ym0HJRhv/
7zXgJo8oy45kSmRPeym8c6Hkqcp+F3uw66fFbwUPUxLzhBm3SqRkXFjTW9OV
kiu3LKhyAiW+o5ppVWD3Zr0V52/g//2Pp19woyRIwWF141VK4nPlb7x3p2S1
8aOi0EuUdDyd43jhGCWvjrUX3Y6lJP2Ek81CL/AJs6ql0ZRELjvbI+NNSeWL
zwvyzlESwMf7Jfw4Jf99POmfG0GJdMeW3zU+lDRzzR/6G0KJqK6kwUJ/StRD
murXn8b/Hcyf5gdS8qt4pPPkSUqyZlpHvA2i5Kjnts0f8Dr7xPnX/Ph7gPP5
awSfG+XrKS/F5xbUF1uJ43sL7sjc1sH3OlTIv1XEdShad/DXhFIixCPGxYfr
LJawz0kIp4SHv8He3IOSCg3j2NGzlLx3rRtVP0qJwcdvJ1ojKels/Gl7A+fA
V5fw7EgUJclFb/nyjuC1ucFHL4aS7Cvt5WsP4dy4P+yuu0CJxKqmG1tQB/0q
tdHHFykxytUPS0PdOhaX7HPCueXqzJRpdaDkbG2c2jGcq3zWl6XTwPN2jz/a
E0dJor1c/Z/9lHjuC9s8Hk+Jj/+en9zgnZ+X9kndxOvytNPW+ygxfWBAlFHH
mCId7jXWlPQv6z467Q7u081kvpQVrvfmbqnwJEp27OqXidlDiVOI3cXZaZT8
ntm7udcCffFwvIM/HfW4ayXWa4b6vl/8RwJ9ZVRbZyMP7hmcOVfjHvqryF0n
bDfu6+ZLZQ70Za3prdy/JpQoF8TrXsml5HWvU5gzeI0kfXs3D3XZW28paozv
z69eI4o+f1pdXD9tJyVS2sFFoo8oqbm7MeHMDkqq9xQWqhZTcvdJ4TV9Q0p6
4wJ0SkspORY2mnN3G+ow7dfLw+WUiHf3NM4DW14Nvlpfgb5Q61SpNsDfY9bV
n3uK+9+uypunT0moZ3yDbTUlXlZOvaf0KLHmsBYIf0aJ35tfLWpgptXY27oO
5zmwKKpaF309z/fQg+eUbL0aPH5yKyXaido5eS/wvsElDW06lJwWW2jGNOFc
txi0D2lTwpXH90j9FX43aE7KY/DmzmOWM1rR37+3hnNqT9Tvs1LQG0pozIsB
fS2ct0BF76X3lORlSr75o0mJTvWYkmI7zou7V8wXnBlbICLURUnwX7lL0mCm
evCkRTclt1s/jeRsoUTDRFI+tY+SKr/KeYET3HRqKHGAEu7IltBt4ILucoVd
nymR9NU5OKxBScuBscWlzMT77Avegl8JGjWt+U5JnLiweQM4rsrny9lBStY6
/eTJBg/19AkEjFHyTKxNKQ98aIdkdsUP/H1sU3sOeL2z+7UZP3E+LsOmb8BS
ezhEB/9S8lX6+MgAOLDKozqNgyEeKav9p+F6ZNbsEnPmZEiVwa4ZB8Bx9fs+
RnMzxNDYKykOXNvzer37FIZM5Su0bQYPifQd8pnKEKnpL25q4v5f9Alsnjmd
IWP9CTUJYOFp6skqPAwRv7icrsB5PurrWlnEyxCNYW9+N/DYyZKnznwM4Tcu
1lqF87eSSRadMpMhabJqK/vBbiuC3t2fxRDvM/czVqGesdpuU5RnM6R1ncgP
HtQ7RXPWmTp+hsg9SOlKA6um/lR/K8AQ57MJlX/RH29/FG75JcSQ+A0npjqi
f77vdx+OncOQpns3eJPAY1KdlwbBbP81qhUH24ow5HHr2HA7+nOJeGDKkChD
6jY8MFZG/2462Wa3V4wh56Q/NTSA5UIrQ8XnMiQ9W7pzN/q/o7BsQYc4Ax00
kQrHfJxJJM0yEgzJcrwYyIH5iRY4E1w4nyFDe645j4LXuYvWZkri8zmvduhj
/hqf3NnydQFDeFKTh7vAV+vzi4OkmMn5pbOzMkcWMqQvdGrkmCl85d+qWqXF
DPmX+slfxrzP65iRkw/mCwnjk4Q+uDmOLBlZwhBVsaByVejHieYb719LM4TD
SXCW315K7DiOLg6QZUiLo3TVQ+iN4YzseuelzKQ+8fUuNyZyDFlrWJ1nbUuJ
bZKLxFdwsNeDE1/AmVKt0Tr/MGSh6fWMCjv43/yHIl7LGaJ78tkGJXvM48Hv
rtYrGDJT+ZW0BHxwTE2NU2AVzv+z3PXN0NM/5zakloBZ/e0pElJokmeIf98i
A0/4nPsgT/lsRYaMLtmlzg1f07C67doKfpR+QbkV+h7L9DkZrmEm/YBHroMa
r2OIiZv/Hgcw1+w+7UDwP3kJC7LAEX587TfB6fm6saPwkyXydglJSrieNZfu
LfXFHH/VHrmxniH5vOsHPeBbLddcDZ02MOSnjy6POPxKK/ZScCaY9S+zs4eC
f4FvhiZ9UT5DSXjzmVd3VRgSdVZdzjmMkoVFLSWKqgw5I6e7PwQ+Nf7fofCr
YNY/2+577OZUY0jkPTsPHvitfcq4lhdBvXf9/twCHzr4ZtOq8c0MsYqbufYR
fGip1aJkDXVm0r9XGu3bEgj+4BJQHH+NkuV1o/q/NNDPOrlvEuD/3F99qp5v
YSbzQuMDDYMwTYaE92rVPwI3FzyISATzmN4dUr0FXxtPvF4GHo/bWSSYSknZ
6xVkrTYzmU/cnGvuyeowxF3I1iYBvmLv2bokG1wRNvy3IAf1FOedFb4V8xt7
ScQZecjDL+iJhC766X95aVbJuYfO4G5rNQ1X+IZ5FG+cqx5D9Lefdw0AL/0Q
peIOzp4Zm/e+DD6pWHHEUp8hKgL3RKrgG1JXV3xLASsku5Zp10DXNhzxNTZg
CD16NGHCF3g/SpvUgoV8agdz4AvLK2q8x8FZF34+Sm3E9Wz3krDcBj2pLmvf
2kzJio6UkAbw0X6O1aHwgbkN2qpbtzNkw8ev7WFvKbk53l2SBw4qdn5lD93P
Kl6XJmSI+pmud7WC7n8e+TPbBDzWcJBzFXQ/bLYF33FwteOFv4pfKcmYv2+X
xA7Uq9Ilcw3Y3f/hkQlmtv34sBYsGLk4aIIHOR9xq4FjzF5+muAy5xLfylHo
958HpyLAMWtvf+aBrpefSu64BNb/uKXu3Dj8lMdE8Db4pcEzj+/QceIoZFkH
9jZyEaHQ8dq/b2WbwYalPcY/uBgifSjh/UuwRfP2ItNpDHEKWy/WCE4NCck1
h25/5M92rgHrmi66pQ3d3r71vwNPwE9GShuWQpdd7tSohILbSm8ZV4Ddi4Uu
+4GbmPBUD+gue/2lN5qHhgTR16NqzoM4D97Rku+roMOhKzKbP4HL69cOnwIf
5Gtt+wAOUEqps4fOZowrpGuBN6x6HX0FOjtwNb98FniWfnBaBnRVSE/LIAX1
+DX3RHfSPIYE5rxZcQzsdGBYYQp0lDd59bVe1LP2mVJZFnRU4o1bYAB4dZnx
TmHoYlx69r0Y9MOVawKNh8HT5h5o+hescd/WJRbcHpL5xAXcFRxV2g9m+0tR
OV5KWga6cT5i3w30X1xtlsFW6OZZ76kmKuCapuVH2qCbyRs0nLPQv9b1Z36E
L2PILbkizSPgb8aVW9ugm/kJ6SEM+p/XuUFt7Ur0ieUrsYuYlx98OrM1wdvO
aMVEgkM2RCptB7Pz5LqgZnqUAnzo+Xx+AcybnIZtRuZqhoxUVIlyYz59A8K+
FUAHj0o6xPpq4XufW6nNgM6x85zbeSGyHDrnwsXxrQl6YO7tZyCujD74ZJHE
B65Qabx4Hzp2dqvaLVHoh57y8bn20DFWf4o9QvMDNzHk9N0YGS1w6P3Ln05C
x1Se3ZaIhl6FLsq5vBavEgKZX62hZ5Y7S4dL8T5W/zjzhDvroFOnmTtuDvie
h705YV/xO7MDyhx98DvW5n6r9XCd3kpiCyw3Io/Y+Bw1x32w+psXPiidgfsU
9tSxUcN19y9okDPHuWz/amo9od9KlzsNR8AWOZoJs8Hz7gvLW+OcWb03m6Ot
JYs6/Sjh1nmOc9I5rqrqCfZ3fCrvAX6gILSlY6IP/ucv88S2JCujb4R/1Wp6
gcV3D1SXg8VGHn+oRx0GDO4RRfRlW8d3wg+/ksorUxyf0IH/+VvWN6+53hNz
RhMuO6COXSKR/oJG4MQTGy7CD68zB8fW7WTI8Lo04WH4Z7ydiNRdMOunidvT
alvAelIdNnxg3bNTHVcZM8S+LeffQPTRrqJ0a38T3EelWZUT+s4/8YT2lF3M
pJ8rkm/+s3ejT+abPCuA39+OyPqyGWz5esELc7BnlmuZiCkzmRfcV1jv8wPL
18VfZhahDhULp18xg28qNnNdQP4o4D8c3QS+ZrtVVgw8tzEurxvM5hWD7dzf
ppgzpOTgnu5E8HD6M4HpFgxRq4jwlkHeOW//ZIctmM1D9rIKVlx7MEeht9I9
Mdd1uXYfpMB/NAuWLQIL2mTu3g4OOj9DOQb5yv7jP2X3wGz++tT8UG+OJfrY
XqGQC7qxXOqU6mFwau1clB46lFpgmw1m816kvrxFN/h6gj7nc+hOnoVe79G9
DHHY+/C6InRLXuqW3Wkwmye/WZilx4Iv/QnkDgCn/lRJ4raCbudKtudD9w5L
60fOB1svOO4rAp7f1hO9AMzmV8UbRSqLwJ//Xe9CZzDE6/W9EU/wKucihQjo
qqvQ6gEfMJuPjaUvhp8AZ7yYMb0LOmycJ815G/yYc69SF/K2b+T5NxPM5m8R
zmqSDJZ5vX6YA+ymMpIZDzZfc4VfDLpfd4dmXwGz+V64iMPsIvj1xwMmmuBD
mkR1H9gxMe+QDnwk51RskQWY3R+u/9Gv3QVOr4gYNgKz9+9f8Pg/7iFKooQd
w/txPpeFhfTMsJ+02vXf6QGz+0ryNj3bLvCK1KtPpoH33nnYZQQ2bdykHvcJ
uakuQ3E9mN2Hjh3WrROZeL9v3YPd/ZSknRDquoh6VR3bfJkfvjpT0FnWDMzu
WybKL0e+ox9+P3O8Kg9ffhe7ZF4ReM4XVZP72NeWn9g8qgRm9zmLj5nvS9B/
7bGrVgXB57nktK1swHJd6jaHWuDrK92ff0L/svuie9iKiETwkZdhx/z+o6hH
xJyV4I1jD/uWIkew83G/XT7JCTljzGYs5RA43jrv6HXkkA9rtNStwey+6l7Y
W7wFLNsjZtaHfdaxQq9/Yv4KDO7s/lSJXDJ41Dh0Yj7/tx93Wv7dmop55iy/
W2P6BHuWXaSjNbhEUX7PtsfIyWO/On0x/+z+fVV54eEFYDHlZZ5fC+mkXrRJ
OdS0I3e1qt3p9YWehFRpP7+NXHbl0piGHJjd92UUx0/qQZ/OrAgd5EGOS1ld
EVMO/ZKyWn/ANwvnmcjhehr6xj5fyLK+1/8Vvjun5Zbc8bt0Uh8TU+yqvZEb
xQr/mT8VfGPxNs8LydhLdkwdOQ99ZZ9ntBj9zJ4K/eULL/lWP5FD9zUt6YNP
loctlD4L1kkZe6wF/WafnwQOZUQOQN/X609fJg9m9f/Y/XdtnNcp8XlTrPMQ
/tDpdtAg8wolQkpXokPgH+zzGutLDnlu8JfRR8nnDZCrWf8JeCToFB2D84wS
t5wDHttfms6HHB6WQ8Ys4Ffs86PSNXGF1+FvVZnPdPqR21n/808sVb8WSslx
pwFDAXCAuOLC/hBKXpeNWN+Ez7HPr3jDxKIPwtd0ixu/852mk/77cz7Pjk7s
ERIZUoPp2Dv4vm06aQhWy7t4XRHMPj9z1n7a3bQW/rydufrAj076f9+7Rf8o
+lCSP2zf3DGxF20M5tU8TsmcVT0hr+BT7PO7W27NMi/hSzvm/Lo97Ekn84Zw
4dw4m2OYT/dFmzKwtzXL9ug+d8e8+z/tUYfPsM8PBYI9PZyQZ6KvF755hj2M
zTs2IkdW7gAvP/ujPAr5aO5JB3M77G0yhjF/poOHPcc6B13oZN46Juzc8dsZ
9Y8afBEEn4kXilttCLZc1pBxEb7CPh8tNvAzeIs8t8/tnH6LI53Md/ud9DoN
wSmOHeLvkP/cPbr3cTmgXlrps4TBUQIO3Wexd243u+bkBx+ZH3HuoQqYzZPP
M4VlNh7AXj7TlUjBN8xDXIpPYm9NivXJ8oUvbDNq6fyAvZbNq5+89ZaUgqMT
vFqmgGV8TedngsflJI2tkG//O7RMzx38zvmWRe4s+I7jLm5p7M1sPlb3YUba
bNBfVw0eGMEHFEaMr7mAt/wz1K3Ay5Cwm0aSHdZ0Mn8LCjo6+YHf2+a1d0LX
1/BOW8wFVtKuvXwUHKtd6cRgT2fzffVAfG8SWIU//3HTH0rU50amOoDTnkZI
zgBfWLjp0z4wuz80eCs4moLFXw0MiEDHH3pa75jgzPTS6SsHKal02lGyB8zu
K4HnRD9GglsS9gpwQJc3ElmtF2CHoSSd033Yv9TtFV+D2X3I8vb93Ua43tF3
t6RcP1CS3aDplQse8Heqa4ION8zofi6L+2f3LQPdZ8XXwB0m7yz3QofNFfNF
KVhEVs44F7pq9DFi+sT5svuczc1k8Qne73yveILVUqykJ3jDnneiE8zWg90f
tSqq2gdRX9GZlceuQCcXqvk17UI/JKfNWD8XzLP3VZcP+P8/z/8/BK0rnA==

    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1GV7EAQUBeCNGN3djO7O0Wx0j24YnaMbQbo7lFBQujuVDqVDCYNQQkml
JcR3jx/ec37Afe4JjogM7x0YEBDwiYjqaEQnBjEJIhaxiUNc4hGfBCQkEYlJ
QlKSkZwUpCQVqUlDWtKRngxkJBOZCSYLWclGdnKQk1zkJg95yUd+ClCQQhSm
CEUpRnFKUJJSlCaEMpSlHOWpQEUqUZlQwqhCVapRnRrUpBa1qUNd6lGfBoTT
kEY0pglNaUZzWtCSVrSmDW1pR3si6EBHOtGZLnSlG93pQU960ZtI+tCXfvRn
AAMZxGCGMJRhDGcEI6PuzihG8yljGMs4xjOBiUxiMlOYyjSmM4OZzGI2c5jL
POazgIV8xucsYjFLWMoXfMkylvMVX7OClaxiNWtYyzrWs4GNbGIzW9jKNraz
g53sYjd72Ms+9vMN33KAgxziMEc4yjGOc4KTfMf3nOI0ZzjLOc5zgYtc4jI/
8CNXuMo1rvMTP/MLv3KDm9ziNr/xO3e4yz3u8wd/8oCHPOIxT3jKX/zNM57z
gpe84jVv+Ie3vOM9H/iXj0Q9fyDRiE4MYhJELGITh7jEIz4JSEgiEpOEpCQj
OSlISSpSk4a0pCM9GchIJjITTBayko3s5CAnuchNHvKSj/wUoCCFKEwRilKM
4pSgJKUoTQhlKEs5ylOBilSiMqGEUYWqVKM6NahJLWpTh7rUoz4NCKchjWhM
E5rSjOa0oCWtaE0b2tKO9kTQgY50ojNd6Eo3utODnvQiarwj6UNf+tGfAQxk
EIMZwlCGMZwRjAz8f/f/A0/roXM=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25741"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"1875.2803822813673`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25741"}], ")"}]}], "-", 
                 RowBox[{"91.577438035666`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25742"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "91.577438035666`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25741"}], ")"}]}], "+", 
                 RowBox[{"2570.938352625879`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25742"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25742"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25741) (
         1875.2803822813673` (-1. + Charting`Private`pvar$25741) - 
         91.577438035666 (-1. + Charting`Private`pvar$25742)) - 
        1. ((-91.577438035666) (-1. + Charting`Private`pvar$25741) + 
         2570.938352625879 (-1. + Charting`Private`pvar$25742)) (-1. + 
         Charting`Private`pvar$25742) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9804369600268885, 0.9828094614353261}, {1.0195630399731115`, 
      0.9828094614353261}, {1.0195630399731115`, 1.017190538564674}, {
      0.9804369600268885, 1.017190538564674}, {0.9804369600268885, 
      0.9828094614353261}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]5/\[LeftAngleBracket]\[Sigma]5\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]2/\[LeftAngleBracket]\[Sigma]2\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9765243520322663, 1.0234756479677338`}, {0.9793713537223914, 
   1.0206286462776086`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226861399729*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"cbc4c294-ebf0-4eee-8c04-17fabf6fb5de"],

Cell[BoxData["\<\"Plotting plane x3x4\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226861413266*^9},ExpressionUUID->"0edfcd3a-687d-4fbe-a98e-\
4233184cac2f"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226861416425*^9},ExpressionUUID->"c238fa4a-7381-4aa5-b5f7-\
6282664504be"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268614196377`*^9},ExpressionUUID->"e0abe8e6-a0f6-437f-8ec1-\
93e586694038"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxlW3dcj1/YzmhpUpFEQ2nSEClxioakoV1ItCVNSUPRQEODppKKjERDCRmJ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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd2Hc8V98fB3A7ZaRkFNkroyQRjStZJRJCQ0WyQ5GKksgqO6RCoVK+skqi
QmSF7EQlhMw+HyRk9Hudf39/3cfTdT/3vt/n3HPP+y1u6256momBgeEwIwMD
Oa7TKTO5foBOLXf70PdyL51yoXj1iaXSHO7nwy+3cMoTG1ry7cuGueX+mwuE
z99r63sKb5OjFxDP+j92egTn6Hw5ThwsEt79AH4c6/o7AFaOCt6dBDMpPvQm
tplMiL0N22wKGLgG97iUNMfCfGVsu4lbJJeWImBpNpUwf7hAz3JdGGy0kaXk
KnyKtU7yOszofOW7H8wbf0ToKuxESx6/ApttWsboA5+cOz10GV65uqXNC/6X
PJ7uQ64vqdZzhkcqn9ldgmPXTvfbwb/C+VdfhO17dM+egGP0fqichxlZLM3N
4aVbnuFusMYXa52dsG9pQL4r7Pis3kwd5kjdWelM8sfkfHAzvM/lVa49rLBK
TUAabjzddN8adqnd2cABRzgbKhyFH8TvM2aFHZy8063gRp7Yt0sGdKquqfuw
GRx9ucN+Am7O4viuD7/549TfDhuoXzRUgmvZ5SPuwbc59NM2wL6TmZO3YJmh
5gFpOFw8QC8cLrMR3SICi9drFl2GS6eeD3LBf56uqDsGd3dk5A8b0ykx02+p
a2GjeT7Xfvjq13ObeWD3I1Pc3+H5Zy5ZbLDeNOOqNtiZJ9ZuSp9OdcrdY3sL
TwX++1YHn1ihXnQDfv7n28xF+GSIyl4++NCmH18r9OjUBmaF2J/76dSRid9y
63UR56W/s7XIQ2Thm29bd2Pelan7pODvcZaP60/vwLgNDCWOUnTKeP2cvZwa
xntu6lG8BsZlWX7rxU2Yd5PeEUWb6dRPC0NPR1k6JakSNC2xgU6JCHvU1ovQ
qTtSq6N8xOhUg18Vz15+OsV6Qcj2Bo4KguEKzzjpVD118ssAjqHlTW1XmTGP
tA6u0MKxOMRs+eBvGsXQPDLqPUGjXprY3fDqxfHUx7/c3TRKOXTFl9pGGpV4
JLcnuRb/ZxrP4/OWRqV3HLvg95JGtRnrqzzJolF2MRUc9Y/gb2V/tVNoVFXw
i0GNeBq1wUzG0iSaRl0ZGojyCqFRSWk8XKuDaNRwZMfmNB8aJaI6JLjMl0ax
rUzVP+VBo5pbJSf9PWlUsXB99m5YsD/KzQl+2Ny9TQwu8RblMoUbn3wp+OZO
oxKaSnMl4U7vNeZH4PQ9abE152jU3amzckfcaNR33eJKQXgbc4K9lyuNenCs
l6sVv1Ob+lHDEv5tKNxZCm8171PWhGMoseos+LZo4Q0GWDwvniMEnonrHI90
QZymL9V2wmLu/y7kO9OoOqectbm4r+PN8do1ToizvXZTLu67V3CR968jjTrL
4SfyADYOkgv7DrtZ56lFw892T/zOhN+fy/jhAXOeEGrdA3+8baSsCo9dU8m9
4kCjLl3dkVh+hkYN7TiXcxo+YDosVgBn6u3uMoIHzK1aM2Bdjyf5InATV3hB
BLw7xMK93J5G8eXnuR+Fz6j0r18Nh+ctL1lCXNM0pc6F08g7T0j/FMy/cKbs
J1xbtag6DK9cMby6BI62+2HWBn8J8KhxhZPae8OyYIWP1T4tdjSKvVWg0w5+
Eac0Wwof8/N7cAy+uL4/9Rkcl7M81hzut7LyCYODPiRM6cAPh8aoPbCzSW2u
LLn/MUGJ0lM0qjTUjG8aebaWyPDIhVu1/L7R4K+sQoOpcFm+/4cReOFWmW4Q
PFq9ircXvlV8+rMRrNoUdLwRVknyP64FL+ZEGdXBK/ySOLbAWbY+NtVwqm9/
lyD8S+TPTCms3LjSeNCWRoWwPPieDxs4RHB2wVsaaqdz4IvnpScb4GC1L8rP
4P1/clVewvHphXxP4OcHMyMy4ZixwNJHxL9rV96Hi05qRqbDPRdCwkJhFrrD
3fvEk/LXrsDjbD0dybDI6L/75+BwLR3NJPgh3/JBB/gjc/y7u3DR+r1m1rBr
dsuZO/CPh+U/TeHJuMVdifBP7YvpBnAxE//W2/D7INfgXTBNQ9gkAS6YSI1W
hW968kTHw1sYhcrlYYvvk7/j4AmprnXi8Gh6hR9xV0XvXQE4rztAiZh/u6o2
N9ybrsxIzNzdysMKByzVz92CNf+Usy3Y0CgnuqUAOX+jgllqCqbONR8m/uub
6DgCX/DUeEdcYxjY1gtbdkUZkedxOlTl0An/DmxbIg7OOyXRDG/WWdZOnn/J
zZqlFi4fkG0i8fXHFnC9gzfIq9FJ/AGCbruK4KLazVtJvkwnQhPy4HjPdffv
wUys7PyZcE4DTYnk23vz+Js0uNYrrzcFLtunefMe7LVwvPgBLCM04R8H89Jm
CtNg0VO8KRFwZ4Nv10PYrDOtLxiu5hkRz4Dvyqca+8O5MtqRT0m+e+hJnvAn
q2ft2bCsm+7VM3CdVGluHjwquzLMAVaWfJX7Aq4KO1BsA4/G3W4vhDNZ2XmP
wYV5x0Rfk/Fn1rxlAQs/YYssgbX6BjUPwpeS48TL4ZbQlwz6cPqYVWEtmf91
rOra8KNbHI8a4NpSw1s7yfhYbXrZDD8OCOPTgKd2V4y0k/hlyt6qknwYV2l3
wfMF9JvK8LyXekk3LL1Z2F8RFk3js/4B871z6JKCtyavYR2HOTPDtMThP0Jb
uCdhC9nM+vXwPuZizRkyHpwf/NbBLvxPbizAxpIjFgKwCM/CIiPe/ytKHIfW
kPFJexG3DP7Xp3RpFfm9C03GXPAik+8WTviZg6LSWnhP7uPa5bDPf04HReEz
kZ+ClpF8XWe5Iw3LyHE4ssLj5+aZFcnvLel4MJN8j++PVYG9bl5PYSTx2M7s
0XAl6+uHyX8n8R6pzwlqwY8u8Z9ZgnfVm6zSh7tTnLgWYWevBUVjOIfhfes8
vP3KX5dD8LoR6bK/MI/C3o9k/WNPjmqZgzuKBs3I+rjflJGDmMO6ecGFfIc0
fJ1m4RfUslpPsh5eWhyfgd2uB7/yhfs2hSYSn9A1qguEazyEnIh3xx1mDCf3
1y88QWzt8/RIHPzp5dHLxJGzmh1JsG0heykxtYzzwiP4lEaJLLmfe8I6zWy4
XvLyS+JnEXZihfBlc20X8nzC9T83lMFqD3j0SDxecmkWtXBGy6AeifefR8zj
Ftgm+/2ZBTjZ5fnar3Dv2NNikp937ay5A3DorgQlkk9vu2AnGpy+L6yKAfk+
9l5Fb448T05AEBP85A67HjO+T/2MAc4ssII/qxMXvO529GN2+F+ls6AEHPEp
ZXEFPKjy8aEivGsx14eLjGe9sbk63BTfPbgaztZOFjaCC17PtvOR+TdyeqsV
/E15zaggLGC2++wpmJFrf4go/OGBtKkPvO+7PbckvMi5YSYIdu+4+loGXjBQ
LY2Bf//3JGQj+f8+i1dPye9zvP5JwY1PfY2/wMXr29l04aMKr8WH4T7rJNN9
sA7LWpEZOO20oschOHNCNJYX3/d1JdIVZD2IezpsbwzfyRuvegwbi5SU1sH6
Bpy52eT9c5uQ+ApXHyiufGlD1sWl7DH41o3X3tVw7Im43dzYfwT2raSR9bVE
UtbEDD5yp0xNE+vztw93uQfg8oqnP3XIer5DenEGVhOYfX8AfvRaYw0H9jPe
E4Us9rCb5ejrzbDGO5fEOPhZZQfdHzbZX8D1l3xvRAdHZc4inq0f+Qbx/WSL
WbEYjf2VTEzH1mlYpfaxRQZsc1zsMgu+7zbGQy1v4bp9Nr6ScKyC7pZR2NZg
q84peLSmNlYf+zdPjuz5YTgm+F81mxfydkaznxf7lWXqzr0p52nUKv0V0Z+x
P0pdq+mgegnrzwTnUBOei7vS0K0ogEbN3r42K4V9ZHTe0CftSBoldddE9ksw
3n8T+q6GuzTqzfZAuWTsR6d0HY+IZGI/07/UJoj9qmxA1fO6Ihq1UTItL70A
4y6c16b+AfuQVw/d22ow3ypFmn99xfsmL+Kc9AX7shBVzt+/ML/jY3cm0HH9
P50BW0Y6dcluJ5s6E51qe9dFS1lBpybYfRqHOOhUYPhAUSAvnbJ+mjmvjv24
7cmpzFZhOjX9NjLpiiid0l1lJsAjTad2aNHnFuRQV7lfumiphPrD9L5WIvb7
2vLLu7NU6VTQs83HO7ehDlv183qeJp26sMgc8Bb1gouh1V01LTplJeylIYt6
Ym9Z1DULHdS902+uuKDeaEtniTiC+qT03pk0XzjZY/7gadjQ3if/Jnz3fD+T
B5x5MiHuP7hO/ppcELyX5ejJEdg8OjYgG5aga6+224d6ZU+s+yI8/F20XN+Q
TvmV868j9VeyPvu+QzBrJd0yDo6pqX5jC9/qc7iWBEswvLW9Ag8ZSN3OghNn
BXLzYN+/CQ11cJWajRE/6qXpIH87NtzXLJbFpxFe88tb0ZXUl4yvkjphyxC7
S2fh/W33s37AQU1HX3jDfR+Z4mZgicO2v/1JfWve4i9ihDyEZCXFwXkxoU2O
MHufUsQrUp9O21WehfkTZYrfwNlBJhk+sHsCf3sZ3Oq3XyUcNnf93FYDD0kl
2WWT671r5jtgk6W6bTRYRT96cBL+k/Rg8Q+cmB05OQ1PtJzKWYILTniPzZK6
LyC7kwv1oWjx0tMl+MJp8b0K8CJLj+Fy5FWeV/28CmxtwlfNAf+qV4zUgJ9E
blTmhtsv5AXrw4XhK+pXw67q9BhbeFjysLwQrJn3ScoJbricsmY9rNwR9dAd
1omoGBOBM5o8nS/DXhz/2UvAHtfv5QbAofdd2aXg8YdRP0LhAXXORGl4h1jH
ynj4z+QPfzl4wF92+T3Y74RQ1wZ4+vAu2gP476lN4gpw7ouia1mw1tzoRSW4
xUZoYz6JZ+ZW2EZYr3tndSG8ylEgdBPc2VhaWk7q56wc483w/lvNb2vg/Kgv
iipw6I2e9I8w833n38SHhkfOknq8LfnYoy3wx5Ffsl2wmkUepQofbx6pJPW7
5B3HCuKqwa+GAyTeXQHKW2GByxVFI/CI1FIwcdFw0ko6vEHlaxWxY5SD0TRc
bCpMJ97SJu75F+bwKWFSg6/JfPD/B7ullS+R89wLx71ZDtCpdQ1y/cSjzd1m
y0k/hGkinzhQ0WAtN3zfRMiFOP72narVsPXHDE7i7Y+bjwrAiokJt8nz9k/+
+iwEv27+yUF8WJS+UwxOenTPicRb0tZ6QwrW083PJfmIrEgslSP9oWGFXpK/
lPSdXxVh7Sb2eWVYVPVdjzLpX2ntXSL5vrddokEV3h46PkLGYzbkROo2cn5u
uoyMl/evC9Y74CW6rb8i/NzQmVELZmhU3UDGNyNwa8QeOGHB5TUZ/yfXPjOQ
fo3mMLs6mR8O20yP7SP9NA7OJBl4KjX1vhHpv/WcHyHzK+ju22+k38NedHWP
OHxZO/SzBbm+S8xYFJZplHp9mNz/p7w2mb+OJ2KDjsGsASmiZH4HrW1SPwH3
Gl8eFITFFb4125DzC+8T+OFdta/M7OCanZeU18A96Z+5neCxc7JiK2EDdyED
F9Kfm5Dw5iTx929wOgPfWxdRQN6/luPM59xhq0r7bjZ47a4M27OwamMunRl2
H12z3RPOEnYdY4C/fjKc94JF7txpXsT7XHHBMN0brlTTfPAXHt/Pu4X0297+
MraagQO+pmWSfhzTu89zUzDXi7nlvrD7i8/X6bCPo8BB0s8r/nRgbgwWSJi/
Svp9Pjsoy2E4rudRAukHSjM+SRmAWaf44km/kFP/ZmMv/PWqoS/pJ1qrjwx/
gye19PaSfqM0U9V4J+w/w/qP2LBb9Es7LOZ6I4n0K+OXz+U1k/XOrVWc9DdT
a0zPNcCzn3oiicfsNwqTvpV5YP4P4jq1iJz3MOcRAzHSP3WL8VAk62WmQZoO
cd+nztjX8P/3X/8H3SX96A==
       "]]},
     Annotation[#, "Charting`Private`Tag$25858#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxd2HlUjV+4B/AGklIkIkqjDE38GkRqFw2KkgyRotKgWTRJg1DSaEpSipSK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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1GeYCAQcBvAbbrvpcPsct9zhttvLncOdUpdKWyJad4k0FCrae1AaaJcW
WhQNTaUymrSTUWkPDfW7pw+/9//9fZ73nzWpu7MrMCAgYKzouUEE04sQQgkj
nAgiiaI30cQQSxzxJNCHRPrSj/4kkUwKqaSRTgaZDCCLgQwimxxyySOfwRRQ
yBCGMowiiimhlDLKqWA4lVRRTQ211FFPA4000cwIWmhlJG2MYjRjaKejpy8O
4EDGcRAH08khjOdQDuNwJnAER3IUR3MMx3IcEzmeSZzAZKZwIlOZxkmczCmc
yml00c3pTOcMZjCTM5nFWZzNOZzLbM7jfOYwl3lcwIVcxHwWcDGXcCmXcTlX
cCVXcTXXcC3XcT03cCM3sZBF3MwtLOZWbuN27mAJS1nGndzF3dzDvdzH/TzA
gyznIR7mER7lMVawklU8zhM8yVM8zWrW8AzPspZ1PMfzvMCLrOclXuYVXuU1
XmcDb/AmG3mLt3mHTWxmC1t5l/d4nw/4kI/YxnY+5hM+5TM+5wu+5Ct28DU7
2cVu9vAN3/Ide/meH/iRn/iZX/iV3/idP9jHn/zF3/zDfv6lZ/yBBBFML0II
JYxwIogkit5EE0MsccSTQB8S6Us/+pNEMimkkkY6GWQygCwGMohscsglj3wG
U0AhQxjKMIoopoRSyiinguFUUkU1NdRSRz0NNNJEMyNooZWRtDGK0YyhnY7A
///lf2/AjTw=
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25878"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"5034.210522435271`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25878"}], ")"}]}], "-", 
                 RowBox[{"3446.544714456562`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25879"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{
                   RowBox[{"-", "3446.544714456562`"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25878"}], ")"}]}], "+", 
                 RowBox[{"5247.184565513749`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$25879"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$25879"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$25878) (
         5034.210522435271 (-1. + Charting`Private`pvar$25878) - 
         3446.544714456562 (-1. + Charting`Private`pvar$25879)) - 
        1. ((-3446.544714456562) (-1. + Charting`Private`pvar$25878) + 
         5247.184565513749 (-1. + Charting`Private`pvar$25879)) (-1. + 
         Charting`Private`pvar$25879) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9805867047941716, 0.9818820806959085}, {1.0194132952058284`, 
      0.9818820806959085}, {1.0194132952058284`, 1.0181179193040915`}, {
      0.9805867047941716, 1.0181179193040915`}, {0.9805867047941716, 
      0.9818820806959085}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]4/\[LeftAngleBracket]\[Sigma]4\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]3/\[LeftAngleBracket]\[Sigma]3\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.976704045753006, 1.0232959542469942`}, {0.9782584968350903, 
   1.0217415031649097`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.75622686224778*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztfQmYXUd15qXf0q9bq4VtyRuWjTGyHINs8CZvjcFGXgAZYyODwTLCsjCL
hWGCv5CJ3Wwik8VOWJzwqSNgAGVCEjNfQhuCiTAEPFmczmIwRJNR8oXQJF9m
lIQkwiTOm/ufOqfqVNW5t+97/eSQBH9+re776lbVOXXq7HXqRTe/dcctb7z5
ra/bdvPaF95x884dr9v2lrWX335H+aj1lKJ4yj+UnyfWFvi9XxTyo1/+3/9H
/MCT5Pc19Hur6M/PF3Nzc8V8+ddT5Vl/vpgvn83N94vfMt6Zm9lebJ+epXeO
5Gfzs9PF9u0zxVz515fUO6v9OLPF9PbtxcxcvzjKjzNXzPAz/c6KZB4Yp6PH
4bGPNubzRdfPE/RPt2w+Q8Nup890MTNL3bneJtyb28MHM+kT4uaL2Wn3dzuZ
7fTsPD9boPuO2X3LQAhP+l/on17Rn5txzcuRaDbzczQbhtH1MBmBrSc9za8R
qmbm2sYKtQYZabx2pJaxCA9peOKvxgxsjhkoaTGG3QzdrOl714/VTXvRw7Wi
4eJ208XsfC1kLQPP4wKFGspNhbobM0a1oKjuOoYiQOvWp1z9dMZ6/7QMAMcj
vLtneILplMgb07Mre++rGTfruhV1bUH2hXjGVnPNObpMpB5oRai8BcylbA/U
fzvt36KsBNd6GdKeA8G2/S7c7p7LrnOTZdJXuw7dtRc3RAy7G+IhzTl7xAqo
l5k5te99z91o4Rz2YvJLnikst0c1hIObuee/qq/mZqZLTrG9/AsAlz/L2czM
zJJEq0bduFA5zyRmdJ1F9G9h4YtK4onACJLXYFfWUqO/lNWpNZ1csN/xqN+U
zLRU7nF7vVWpvbV/FOlaG2UZPVtS21dfOD7/recywXC594P8nTXwr9m7Hm9Z
TR8Rm2P86vEjTYnnfkB9X6V1PUm/X9cAtJw8u36Jknfa3F2qzmAlLxntUK36
r59n0Hj1/qijD/u7S0fQf9foYxTzlvb6u7bwH7VnnJZevEy2d7ql1N+BpTG2
K1iVsApHAGq7su4BQrhoUeMZ7y0wpykDpeMN5lA5nvrbWq4mfXcaLv04s7+6
vlL8nuiW9dqEajIVnLn4JG8krZQpVdHSdy8YqOtY3+sazy4xxuhWjtGNxlDf
W1OwFr+6a1tdXWiRqvsbT6ba93sSsuZpyUIZVoYWQ7JQkbYX6CBeKEcaFwzU
dSyNu8az2oUybLJIauc0pb+uXagFpj/wQi3QX8pAsaAnWIuV6DLZUJOJJMR3
3qZbCCMXDDTUeO1QYw3aLLy4eg6GwW3RYdPFrQZvuMWt7i9+5hb3+GRxLUU1
494rGZs5F9YOohpJeOFAwx0xwHDVbWoXOZtHYt3XM5vaRV4AxIEXeaD+HAs+
brBFbkf0ZDEL7UrpRIaz9HHRosfqRmNVcoz/VIvbSRYXO/jYwdhztUtnie9W
tpT2KgTdy31/4aLH68bjVa1CgwX+j8OipZ3mnccMpiwtjHBZUG9TWSpgUwWq
8XD1u+zChCTIwxQQMyJV66JhR5mscMNkXVw87AjxRC2GkNJBUx1e+ZQilHkf
cDM6GNlw/vsIcP76IlOmjNQwunioIeI+bNGnTYVFglBPx0wKTfwXsY6cq0dB
kI/X8vsmvotBxqprc4mnKPFwEdijcl1MDd992361tseVC/swZAuqZ96FNTPH
El48lpa61ePvmjvzNKZH1WfiGVLmc69mnHbNd5cO2Jdlug86Hy+e/KpsL8nK
ORF14IM34WKc0CT1+v2y78/gx1PU06KFJwV/XUi8f//+/f7ZqrgdfVb84Bk2
3PfNXBo8o39rlv6If/8g/mDpB156+oi9N7u9oP823rufPTZxu5c3fLalYbun
4+dTqlmSObli++z3z+REEDC/pE87mTCw+b+Md79uDkBtlhkwX2d0u9Po9mu+
l5p5Lzfm/TJjUGsAe95Jo+3GALcP29kKA/SvjKozgDl0ZysNML88bGctA8w/
GlVnAHPoztoGmJPGbH9r2AGOMGY7dGerjNl+adjOvv4f7EXHOp+UhISOMR9J
19BU88Um83bO5ScviN5uMHlQaaPJH5sgdoSh4pYxvmQC6w3w0EDzHH2k1Jpn
I4KN53RYA4L0rIOxv2bM7Kv42bZm9uREsyyKnDC205HGs08PhOknIXBj8QYB
Znodb6+NMxkw2HKDAfMkBSqarA4mv4J5j14dPJG/z3z7g8XsKPfqiBz11v4V
FUDzmSX8jYZPw69hLf8eS1CE5v9zlCx1RP5pC/w1TN8peEBHi5dZoyYBvRmc
TeTeqJyvFg0fY6zxhPHsU02AEeVjlL5Fi5OcwgtsEWH5+682maulYaX9YhXV
70P3+wwmVY3Q8vf7h+3vWcau2juqzgD00J2dYMwscTpG21a3e7r7Zu2BAwem
9u3bh8/WPXv2jN191113Fa29W7Zs2Tc1NYVP0XI/8WwDzlThxTeOas5AwFJj
fuNGO6b48x5++OEd9913364777wTU5tfs2ZNsYIOh7W27N2714/FW/nA2rVr
H1u3bh3a3rdjxw6ACHjXPfbYY8VNwwJyjDFp4QtAfsV2MQHrGYvGJ8yA8Tt3
7dpFa+CAbB9cuXKlrM7D55133piDHTAlsLcO9Xo9fOtepJ8dPMOr9+zcuRN4
BD6LV4wKD4BHZELF1hbuJOBq9DB9YJ2wrjTjroNP5r1n69athSPUDlAj9IvP
yoMHD/IeaPcOHTokaEJfkw4J+BOks/n+++9H8+uGhfxYY9VaNvNZYiDJQTqB
BZQVwgdQPrBp0ybAhylih3LyZUd2aUT5PQcWKBxYE7CuGRasp1cSdqfEaP+9
+972wNy+DTs/vu8VH/rRfe/8EtFd2X7qYx/7Jn5DGyHoqfdeXVJtMTV1+hu+
SbN3BB0kOO/QEsY+vsXnwzfdtGf/Kae89uOveMWHbvvAB75ajLn3SpiS93qV
HbbWzM/7Dosu/ZzEM2kH0gAyQT73b968GTuKF+C8TvmjZHdfXb/+tg/dcsvH
X/XRj/6JwGN029LdyvCYUtyOOwAQaQcAvnEHWKm0g5KPZR3gWdqOVkbasaTH
s2H7G2hF9BIv2EHJkZosqYl7vOvbdQbrL1qKM4fZLNjYrIa/dP5XvtyfKvbh
U4zRz9bjU90v75865S8emrr4iWKs3MIVQOx71rElLy/Kz7H/t+i4diW7ztqV
zKCPb6lF17XLsd+r7mDTAw9kHeBZQidtiKHffe5z9//V0Ud/teRQD2OT7COB
shdMCCwZe6rTsFceHTOK2/UC/acdANbGHWCR0g7KzZ51gGdpu2hBOoFahu1v
oAUZaEVLlWzwFeV2eNe36wzWX7QUnbBkHqDTzL1Dq+LU/mWpMbe1X/YJzlvK
izUvesdX8Pdj/XXr8Gy+v2YN/vYnLKt0K3xb9tvzqNwD6QrC5M3bhs6H51Bm
wfRbTrWA8PSzudLY57/MAq1kE4QC/PVMD1MNg1jH4/ZLBlo22bXLMQkWqJv7
999/oL92Lb56uA9NoFTFxEtcrz0BEq077DzpmrdLmgw0OugIcxs2bMC/VzeE
yF625EVqVCyf62/YMP8vRx3V65fYxROeYm/qJx69s79r16F+qXmWXdzT37lz
Zb/UynhxxEmh1z8Io0OQyFCBClZqD5U/7i6e80pqcZVrByXfWyLPGyVsJybs
HETl9sFyCKuP3PPq38erO/v33KNhFm/Fmv78/AP9TZuEaDf1H3hg0m+POVAZ
QcWwQc1b85WvuICZW6OOKL0wWqCgE5yXjBJGy81pOeOVblZOpo/1Pvi9blFq
nO4dLCD7ErA5D/ZLFYrXm2iCj9xjsbQVgl2HHfhiP/993kDh3QjYof6S6muB
MDLYAafl4HcE2RXYS+63D13ed597x6Gmg+W+v795M74Cr6Ldy69i7bRaDy2z
FCLzmwPYYuMUnUAO3n49f5RgW77F42IQ8dee/tatxINLcB2XaeuVxa5m3gQD
AwaINlp23nPPPWnoEXTyvBhiLC5boi1AD/5EC33uKCFeFxOvbE6AgpUiAnUg
dvWmLZW1qVMPfuMbYJxjYY5kIaOxFVq1Is0XB0aFVVXWdwuqEsGLFs89zDDj
I5L1vv6OHb4Ohprs3f277uofLIrvbeh0HMxtgL92zw2+ieVAEpNW01TqgAZ6
OFUfIGOpsf0FFaCgUr14gFqcZUDUyF5d5wcIYLN4lc25+ZHLw8TF/6lFail4
9m845RRmzCUTLoqV5+x6JAIkRQKeHWEggekdfYLPAZcCMH7HM2qx4TAADEEL
wTP/3UnHqDHJTjxJEKQA+p0zyi/LtX/ggROeQ0IabboGUJzUg9XyBK24NfY+
uV6eNSxQxxskNmEAyrtNOPK+fzr3XCbqCZCXMCRgGhPa9f9uvbXP0pjYc5oN
hHFe6p5Bo8LuJPWDgQO5gpWDdRc/NCrgsCoTnkz63jxlEqMdWXaFf3n1loCV
CHBgScRCuL9Nd9w6A84GlYtUE4sldY05cJYSgIO81XsTyPTzP21YwMXbq0mJ
03zAajFhWhU34VXgs6Ir4F/v0VSTXts/cACqMobc29+yxeuWqk0KK+C/3j0D
UYBaSfAyi8ffi4fV7edxiBNQG9R6/I6n4AVkYvC2g9fVv4cP8MPOY4gmsOo+
KxUb+qzooo3lPL7BPQNfwdYka+f0YYE40/ER2V5ANCZE1MDYgunk2/PW29Lf
u1cokCw1meC6jSnjjYnhPYubaBsD7dxJVeGKT8697GVKaNOWVSwjogb3rAez
TKzM+/58fVFufEzaI3eHexUEAmFF9HiyMZtf9sTV98Z6I5mtwMB/e/c+/ZL+
Bm8gbHnb89MptwyZ1MUSYS/Qkh3asIHorkTzDv66JAmxK/ABmcCuWFsNyeDa
h5PfPQx78cMPPSRjfX7LpZfqKVtEwD4msC70jp0Dqt/h2f8B0TWFLYNN+/U9
YVFg0HtOD+tcOffpT3930/j4X80ffTT4DM3SpXe2sSWExEHur3MjAI9+dmKz
lqwLO4YkopVea82OpPrYAkg+O8wF85DtyQEPTFmoGWbYba4HCO3U9AQ5eLZ3
7CjpwNJOWFeUBQapshggjUXUNGjhxM554mCTPgg0Fjw1Xmdcc7gnzpFJ4cck
XJ3O1xYhDYSDjfCcsdcgS7USAfrw/oqjnxxkk34Ldvbwo+VmYqNOjNMqB5qT
m214pUDq+OD317tRsOFgwVVuxCOfHND89KHhzv/N8qMwT9C+pBp5dsNcsipl
JnBV8s+JIw6rbDlJtrpnUBNhzac7Hp4ravHUJ4cqu8XMFprbeedt/mlwA3ho
sH0y/+EpAQblgMvlyDjehl4mm7T3mW3h1bTbJBnpNa5bqHDilhTsQBlPTWgL
OwDSu5aHxs4ynidLGDF/wVzAKx0Y7ShGXyuXOmCl6KHcwMXatYwxycez8pVu
cX1BI5PAoqAC+4fEAlpYp02GtgD5mCMGBc/EQNiYzsnRE25FTgDDZe6EXGfL
Lx9blOpjMT8/VpJVtPAxam4NLAH6YCpavJG7/DCAKAYoNh1w6fZqTxSgO79+
Tr71SzgkycKIa+NZaaUXBw50CPytW6feXLzJtbekJxg6ZY8oGTE0iAgt+cAL
syOAJYYQwHUOvB7oV/bnln2sWq/f6MGtY+/l1y2GtlxIaIhz3z3tNPS0q18q
9wyt6YIvf6dsi8CCh858ams7FlTCLB2cB5L00BMtR3hYvHKe3Zptxt9p5ZeY
Fnx7DpwO6FN4NT7Eo4deMAYBMk86xACuvx4kEEnNJ5YvJ+UxETUWh6k2TdpY
FeI6fafP3x7IEeRHZt4iISHXjXhLeKsugT0OaYLVIGWsTnpaTgVhRCXfRT+i
zVugvm3Y+Z/hxoBpICuBVXEMlaJqffbmEjUE8zpOiB43loSnr9V99GdJzcVO
X+8FSttxTeFnF2I2rT5D3YfOYvHpN7tn2GlEMfhrzJgRS+AGQVwbFO17w6qw
lBfFmTxZLWN+vGJa8cA7tGpvYULaA5WgVLRLJgwtomb6g6tXbvotseDIA+b0
t47EBLb+4VSgWMt9yGwVylIp9QqhPNo8d9B34yJA5AN0YT1oLr/aePI0d56y
aBaUGPjUgEbwC3DRqSmmFuv8I7s/5NnOnedv74st89D1HjTmOZBGEs/SdpjH
5K8YEDSyZ9fxvA8e7JfWqPeHkUXBA2Fg335VoHz42MBqwVvkBObuLemq+KRx
7GHsZYQwPWrc7hgHT9X+EUxRVmixmnsnDceQIsywRX5At4ZtwCPGF+C0lq8b
mgINh/51fBzslokNy+VlVDkjvXmKT44YHNL0rARUZwy2EQIXMQAxJuBoJsDg
kE5SUm+f3Rdu/3exOgKGqH2Q4780Yki0j9Mrd/gcxdy6X3JrFsjgT5aJaB3+
ltzJ8pX7v72W2MPez511NbE4q/1tYco+1MLTgmHlp7Z3xPC7tFo3kJcV+DiP
hXfPiSHF4VMzTaWEw4G9pFJ9KNVWhNP77GUmbmmF2Bw62gKBGFU8UckmoEaf
WBxGssipoJ+kAjvJRC1DrJyXb5llUEWwikdZfz8Ws2Bps/Nnrnm7sGJsf0tr
dK7HjgYBHJMCe+yXgVHm7cw/WAQORDJS2N7lDLQkT4AMh/YC6yypIrn4Ceea
zvrRB/X32GnEq0sWCHU0zZ5GlzcbILCHAvSgM04wdfC+xaBBNGXsQEZDG5tA
lARsDrk9RS9Vdjpr0sx6N8wb9lMAfq2HWqF4S0e08MPtwEGg8WvO4p1X+Dyy
CESJWkLEeJQx2XZAnjB7rLeliou9Wm38ZX676iBJS9xl2pcXQcTtwPtSbQfL
7t2cv9ccPe0ovNuHQkT97bns1DAXK/mKQyLgigAPqw+LJN0JOOBonfpzr/dE
H+yzRE03pVUOxMKMQzZJYpUpT3wRdksjhLiQZBdY9Frw9Rv8uNVZWB2v7ZWq
G7w0OjfASrw2VCWKkEmYAVLYBfq2z1pkd5Mxe26H2afRHtCKl5e/3RwVHW29
kn8Fk3AnPZwWWMJ74AB8jjfssZQNy55y82yL3YVgIIjgdcYs+LIJjKxNE9q4
v9McjHYKhosqOsWvVEzFj5C636wFCwvbFiMY1A8C2GFMwHnF2lA7hSxBoouZ
/Enuseh6EmCTS0LqTqBOhle18LIYtrXHlgQK8wrNL7hng4eVK6A7kXezmoto
ddgcaXZBFZEJ3pOIqMV7Tze6tDK9hrayTvd89pCcAQPUJ/KCJaIj0t4s59UR
9WJFY2G98fpIQXuJTXSifRFDt3K1nIkVZ8n3Xf6jCAPwhw3Gq2eOcv6cXSRs
l3xA1lFPax2U0SQqFvoho+k1xlgsPkDkiHwQP/5A44lTX5Y7/jSmLjWNHf37
7rOO81UrMJ4bS4DO0s3YgwNxKjuWsjCR5vV+A5ABDh/EQZT1ASShBvgOON83
1RDY1YiYCloe+Naq48CNj00QgNbPr4Sqi+C3aNCiOGCnvm9Y0rIAY06gdR7I
ICtlypI7ssXFP7zsmgdFAUG7kl8Uhw61umB4lJJlnXu1UMCUqTOmzbyze0eJ
C5epSH4yUR8DLurFWIqHYt20RFrwHroR9xR+N2saXGpM03kRsrx4GKrYrSMF
/4wAPimOvGaWt2Wh2hKn3/YRUUm8u42T3F5lzMad2qZDD1pTlq18T5js4gPd
vFLYXN7Ul+IHCkRMewwoKC2/vnJrVWvL4XV+PhnwKQEH6Gc3GhN1KTld2Jja
6S1Z9L/RHNjmrkZ3pKyXCnuJZIkKKYnflgEuZOC72DKTtRkzkOMdXRHfAcN/
pQGY2yvm6Qm4gj+7CORAcPi0QV0EwVHEkpTAU7+sAamZahj1E2Jpuy3khJCz
FqA+RnuDAZ1zrXRSLkFBgM8sAj1EL5bXfT1vWOXcXfm5rcn8LXe1FVBxWSXK
z8DODlHZJCxklc10eYKZ8wrmGOhltgnwwvYTtZ/ZoWTCkFHzvx991MqS7hjw
Wno9+yckrQRowxazan+69Mwudr8OsghL/PQAgAER8j7UvJMMCCbjmYm32nJ1
LDWA7cS4kuj19caknKlOHg1xpwmrA0/+9SaAcTBPVpx88ClUmCprnGK/UGjY
0v2TqIsYoVaNixMDMxJHtzAjMJNfazJ9q24lZxUL96fcgpONqTJIsjeUQz3u
z8rbqfaC+viZOEwt5/HlBig8begiEjwznaOfGgYvWEIeQNKlKMOG7S0xkZRD
3S4QY7k1jdwL0fv6bK9Y07Fw4JapC3g195XT/e9yr9QnCYy4Jmar/murYJV1
Ms0Re1tDhj3qbODMvuN0yEqlsOo0g2gYEofWpx8MNQHLbR3NvMwAyhWa6GJn
avEAxzR28DvdK/Xq8+LKfg5+l6VVAo1lEQV1i5AG5jYCJbjN/R2sxvLxu17x
4ynWLVHkljsE4dTxjSj9T60x0jRoUTYbM+S6ZCAPLa/Az4DpdzTB9GA1She+
c9KqmMeY1DIRatIPVbLGcSg2SGLFDKHwmOxkofQ0iXlKuyzW6ZRvoHvPN0+l
sXC6kDS+lxhgsMWipShEeyOCHqzEanydRNd4ZqF5nZcLIZDD7aKgYIr3gNPO
yj995BFKbmQznHBm+ZAsZsB8Qw4yig/pxcZUT3XPQBE+X3MIPB7+yxtr8GxZ
uJLBSXH4Myr5bubusPQ7dmiBywNyCbO/yJhRI8fnYHVrR3MtYiite2ol0to6
rgNr/Lk5jqAqWdrVcuMZk6FEN9AFvAlNK4vQRIep9zuiywYHo7i2dsPCmuZz
V4BYnF9AnuVbTJGXHBbYtKmk4+9MLPd+xKsWTXlPzm1+A2IwivPeeeed57jH
OrsN2LS85g6Dk1Xa14YN175fFHzscqtcz7PdMzoAIaHZHxmlRBnRFXpNkcrD
RckV58YYFS/XikBr9N/67ARufEBK8nPKbyTqhfRR+Lvpu03GFDkRHuY7ZKAc
O/5EJTafnIvoBsSmHFMisXKe+0a7xYDN5Qk2tXIpF4t5L5h73gqMVlTZHTsu
fEM1Hjv6hIIo9MXHU2SOunhxXRtLc685kSOnAvEBURjIDAfT6nOX9DMxo5Dl
kvlvtszoJBkkOvQ5yPjCSkx3hWK1Uo9nH0uRPdriytVl2hc4ySXzhDxyFYGW
y+EGUQQ1a0xtnvzwT70LAYjmDJLIXOpv3Wq5CxyXzRxgQDCsp/+eIrUmsBFl
gIs6p9yYsGwcw1uhARQ3XYSMCotElRIPECPzUKz9xHVtWD3kxxaHlY9HWx6m
cwxQnbMhc7iB/cA5+tEm6OKgvRimVFTCjTWRzb+fH35k+I8ycxTT6vlWJmfY
fruztkw5clxSnN2W88lCj3MBULEC8ZGJnwzego80R090QgtUdHbGPHZ7Ndn0
E3czhh8dnq0rU2/mY0k2k9CpZeidbcDzHDec5q+Cj+LDAyBE8xKEP84xxufp
C0JA3j4eaB6WbftIByOIKyVo3zmk4POMeXHBBW2keMD2DACY9n5AjJ6f7GWm
aaFJcjIvFAWH165Fv7X8nsDHEl+8vnK6BOFhKGRTxozPtkGmqOYdgQsOUT9k
jBwQcTrBucauYwAij/tkyvzcucuwtBWeZs4XkRwwfPD7JcYcHbF1NA2K20/O
pw0e9n+TQcG8OT1831RJtlU1xyHyrEAKw0cx/+9O0qlglFm62JjKuTZ8FDXY
OSx8b3XjRx5LH4lfOJull8gExdtxhB1ppeiWavVcZAzvNLhOWryR3Eq3LxIm
rVqA21jzF0W2LlPFkeXyDEZ9wlO9s3LlS98nnnfwY2uGjn10wIYysN80LNhW
YtkVYX2QivzAw6ddTOi4u8gPBIwz6aZwAjeZWrxOeNeEl03StvxXn7Ok/EEr
4PYcA4aNNYh54yIREym/V/Du4wn1ets+9cBfn1A45HAZ2FDi12BJnVhY4b/S
VOgG0pNgG9iExdks8C+oAf8NowTfOTN8lgXOlIrHHjRr6Q2VFtQYmnHukvBE
UXMsXcVKXr2wBvDXNwZc51dG4F4dSLu0wUtQn3qyZ0tWjLcX2vv1ki0uIhuJ
ezJ9Fs8SNpcCQ1ap0YtqIL3NgHSA861mMSRfAzSgOU7ZLZdGBwuBE8uG4wVO
NXrBBtL35DHLtLv3P4cIau5PjjsNI1jKuJNzHZ1a77HxugDU4pPY+GADNH6g
nYrLnZGAafmkg+BrV2FJY2SpwpLKz5kM9ASHV78fUllMfdypN1QNH2gRlfUD
i4O+LZ4o9Af7x4olWRf7KARIuB+aqJXYkwqRdaFqiK8YVXatqzYQFqwKtazd
Agu+FNdiUaDVYmgdVpiHk1vSMI+V2pMeHdO27RhvDah+0rUlB9nKES+W6PaW
fBi6pA1DjwCNQI8tcFk9pIbSm/l0NaRaE7CwxY40OWsoWUNDl+TlcImkAAlZ
V0AlF2DuViaHcvNZ6mFNFUGd/4PerSMNgwChU0bghnOOsJ7kFksczVMXT1Fb
ztJj+XtWomxdvB1THTZkoY9rtEXRe7xzxiKh1L42EODFBtJZJ9chHII8j35N
xjqY8plr2ErR5Lrs6sRiX26jbG5BRX70MRhbP90EPo47Sbqt1Iy6yNgFzCIz
+ABLWuhZ+3sefDDwkW7gyN7W+Ju3vtUqi+zc1Jmb96cGgEq/C+v/4mSWYUa+
xFUUe1yZYCEIWoJAjDSoT9ZSOAgiw9c7cbZ6GTFgQRkGDfxC9DA4l1/IwPgg
4Nri4MFwIIVnHev9G3c7yZYdhUqd21Zh5002cJRIfJNrP7jKzzE7nd4MbAlw
vGsQI8ZZExHCy2LY080kXN6qtWvkKIspIHnY6415Oiss8lVB36Eilq9eJPDo
RLMaHgtqGQH+eGfcax/VJxI7qSpHbMULPMVyqlOa/cEssYqs2s9X1qDiVcOi
wkoqcqucCc1N8eJv2nTFO7WCZiWjyzU5qSMEjEqwUApbQZb2cYqJwE5gqcyx
zoDBJS5EvmkghuqT3LhIxBgFHSNBjF3pBHHs4mLo0iguM8GJSneSqqGXudOw
rRyqOmZIhG1MOUgrLv5nGtCxuavDEwiWkSn4ysOAMp2EAQl4eTVXSFEmZmXi
F5ZzMjrmDT1au1Udstp2QZjINZ9GCiSDLYLPpWZFQXLJxZRbK0eDNJYh+mQO
VkaQlvOPXkZnCW2w5hZpQ9q7F0irF+noRpTNNZusCtLpmUC0P6MSkRRg0/FH
uSLrhsa4rHTnMAZ19hREnRt4XOZoVhbspjIurttLvqzkeOqNK/2+FKzoqIUU
2EkcI2kC1ikGplxyJcqSHdSBbUq7sdA0tC+I00t0gXbwUMpZYrqPTibJFR1y
Wte0LuJN67HUTh3CiehAXlXBBwUpS1WanmQA4zJ5qb6mzqeg8yt8umnwYJaF
Ic7XhHarNV23QuNZ/F/Th2OCnagq3Ec+8hGVfev9rCAEbZJaNqdVZt7lj1Ml
j8xN9s5FgpxqwFcac5KKRxoN6vSaxGkT30DqHNHSz5kEZN5SJUExNhOeYyHD
3TjbEeeYXq7iHcMiw80n0pihgl9RLckiZPzpI4+wX6AiTSsVcGkySMpvg8Tv
pn5H2VdPM0BzV8xk3mU6tTk9AG6iPBnGjVaoISWFUAyFN90vmZlQChxLX85S
ZBI9SEWEKRuL72exKjIBgccYAF7L7E7VRAWmqGjh3U0wxDc86jsRw4VrlZAb
J9KMHdbkKNCCcU0gyYLc1cnoaBaH/UNa4V0DQJ6K3RcY4Eza2LAWaYnNPCye
4ktPRziA28CqSWvd2uAOKEbnfiFXSMn7sSY4YIeOpKOSmZ4iIPi6MwRUnO3u
MkNOvebAj9c1DBeecl9ady7oDAzrfhB32jTLCyW14L8OgA1fFgCfyyopvgIb
rUidcqgI0fbUq1fn8fPG5tLI2Ew5SD8Ut8G/oCXrahLGDrChNzudEW+EnffX
Q53zzW4mKivSwZBOKMioOBEvxnnCUHSIEoBbjOLlzGHLVQWdw1BRN70PbgT9
bMLVlUXmEwbTuJFe2sqD4WPsHzXM5DTfzmIGrEBG2fuLBDIrDpHOIz2IULWC
pbFbnXuQOQFWGxMaup7S+2zKSSFJLkmJVq1cCF6HNHdvvH5P6JWsucFjNMkx
b7RJZYkmrbyMe5LAW8QcmSsiZvHNhAcdDtgiffZNNmxSXUODoHiNpUpI/d3d
aiHV7mSD2jsG/mmZu7yEOdeqww3o0YFZwRyCywabebNBUGM2TlLemwDovp5I
7XvfqzFC5DP2O9n5vp5oFfPzzgq2LvBhlz9A8HmWVx4GfGkNCJm6Kb6UoWPi
S/aH8DCHwgSRsW+lJquEYmFPLPfOEotqXDwgOsCLBT8cyMEY2iS+JmHa7q9q
5pHXNxP1XjbR+iQOG3wF0dE1UIyVnzRZiZ/MLCbTj83YBlGySp/b6pxu0PV1
8ZrfPbPpjRodmXvXrftY/Fa65di/58+JsbfEIiALE24PdfTZfx8xuMMDOSBp
rLZJ47pUJmyfTUmiURm44qx3Z8kkUhwKxME2eBqct3KQJgyIXJg0sv28c/st
w+6WNXUkcYSeU4YSzUTTquV5iMmuBrXsmgcrHE/jAVnacWJdEnWza6pPgsCu
WyxOUjJx3twJEw/JoQfzHqwOr2y8YaYz91EUnFRuWCNfABhZVokRMnu0U5qu
LbijCVpekJMFvC2OLLIYeYoSC/qJ5NXiqndnlOJjFy2/b9xLGeAY0brRyNX7
zJysxEDf3Bzwjl57eNvJtniZwbsq9JHlCc3LK4h/VUDJ7pbUM2RdorXNTRKO
C+3/Iua4swmUl+XLC7ZiuY3FgjFyCVOgV6RLHCVnJeGpOJZsnCRE75ZkeK3N
BmmFbm8OvL3Elq/YreV4tu81llIZGakMWcJtbdTT1HfTLBRLPtySs0F4hRrh
xAUuo7i5Joj8yH03Qofc/eide9VO8ZA91Y3sShVYqC4p2IrOI/UqkdCRW7Sj
wMKlgdcPlox8eehUQm+eYl5p7AWjYF7gFfalD0aoRV5z0cx8ISyUVOSyEjSu
LHoHXEJ4o/ea87m7wTVwzkxLY2432hyiy5yuzkOuMEYQjoWNZFV/n0yPK2TU
xvDzTSja8+3dxlOLAz8LytL9DxU4mEiXWTlFrZsKJo39ptSOMWNWO3L2To7u
YaG0UpBOyBce472qDmhLitj1vXW7iiqNVgWHHWE5tLuXYqyXLBL6SEU8IV93
7CWV6VWBgnCRzfr8Ts6cG5hhFl1JUzneokkztYMQdWUyinVcPEpM8CUUOhYH
Wnu1jYTMH7ouJExJjn3uvrBKcXat8/yY7XEG4jhJQytMwApt04tGiY0THdia
+MBwUs2xxsmdHj7dnaWptCKtUmtT8pyzGTSGULeXZp+iB/2+hKei8hYRMDgM
mOnoADTYL8nQa4059Wz0MDNI06RqAyjmpSE6nwyTP97gPIwXneUFHF04Srys
dWPo1EhoYS8zppP45lI/jXXeN/j5OgaGSnQwNsT1i+nC5H5jDftwBxxHlLOz
NgyklRIlQCc1QCnr0ytr1YeqvmSvG0Uss24II5i9VC/jQIOwELnP6NYUcBHv
8/NzxezMTDEzPV1Ml//Ozs27yjKV3jmXOxVJVORIvTIBIdzjVJnL4wyx+J61
xDLJOC3vN0xOqgHDi8kHdpFE6y+1usWDwTA7lJU9lDDPTIdKNtOAfbv7e3p2
3joXUIMI8V7IJeEpImryeKrvW8xP9Wsxk5fjoNJ52WGIr6WrLkd4fNWpmdli
bj4uL8eVp6wDBFbGDtdBhrruY/M3GvOsSNexIo+pbZaqIFoDy3eMm3IRZ//h
7Jefyh/baGH4zQJerkSahZNfq4erNuVoXfKvz0mwDLJxGlZl9+kjYcWjKUyh
6i0KlSWVcFEXq2adf92Gyc1jIlsXK6FMvKmiF+j7EA0jUuKa4BqciRzNqPyk
Z+yyVewYK9aOsODKsFn7+5cMcnJLuFziq/4UbbQrk7SQ1CpcKERVm4UQzZBV
B40FHIz9oyZYkJwOXIowNzvjmB2vfxNshPBZnB++74awuPjW5+uatUzt1N5u
JDFyy0J2swplRMXAsTxcxwIKiT+DvrUeMY7bt/zP6WJmdo4QYh1s4yuGo7xb
lqBZNBrIOoIlTbpT7DClBzF4kDL3+ev5sbpnA//yie56HS/e9iVJzKG4NX4i
QBzcG882IGcFj7wvyTPD/A9nLr53HB1ic4hYnVH5erXf9cHQsjUNrxGdsJYs
R5VRk6q/zx0INXMzxBvwl3U+3CW7toEGGE3Q/UBp1xvUnmIiuqqlMh1inBFV
lXOm7y4SJKWumeTvDFGu5kOmxNLaPqc5tsaJmwbOzIXvt7s6ixuqsaeNb7h8
X2tjSvhClN0cUOEmsTLz3Oo0p1QapRjzpliWeqQLikOLZ5xpd5x345/VBGeS
beYrHrOyWYUrK3uIb17VR1wwIcafFKwS/GXH5zmmEbIoosxNTTadhG8pv6R+
pg7gosbJvn3HPkvwJZdba0MRvzfClViOUmqSdmSo4VmDrkgxDxfmHMgiJ4yz
9ES0FQpMT3dpJi74lBCBes9Pz9f0IWU+jRmJ6wuz0udN6KjxmYPsxrqqp01R
xrcC6sAKVu3VCadXqeEpBsW00FlsJdhW2DetGJCmNvXj48waW+BVmWtsQxNs
yeEIL/6d/uMveVBIW6WEwvZIhQqKJMwEUeEOV9XU0wKF6PA48etXJSujal6k
K2OVxxDLs7+/X2zcXtKqB7HrpzVbPr93tjYa6KNgWeTPrVcboXzN8hst1ViE
f8cGrKLp1jpJ4mRdSeGxBm2algten9Ml1op4jaxRTUkPWaPUgQy9aAlPc/tq
9HpvcZYSZG6k2eygPCL11bwsWyUViNAURnUMWRusT+TiPSCbatLr02418N1y
Y5XEys2raHejKtrqe6vIdtPq2KfnMgmEub1eFliJMnkQaLyY2bifOy3X6Ef/
PKzP6o2F1KzShXnYNRAFRHkh4HYWkeUDdK9Ike437wJ7oWu0i2qQyypVXTSw
4BUiBpbpiKl2xhK7YlSL4RajekVtTcTUReDzMfbTxTa0BcQ7UhSPF/fu72fl
Pq2LuXbkIg8KVobtpy2IWatWvsasUSt/MMw6H02UZeiZzFUGZa7JsQ0lUQg2
cy2uDCI7pEvKSMxwNpKQaHJ2jD3TaVHpW91jHXMCn7khxbfUNYOXFs4KeGpL
yqxlIyO4soDA/IyaR082KzlNZslD7j3GM7PkKS8ViMM9rwYx7jPyjefzrIQ8
9IIdE5NH1Qlhlc9Cr++fpaKZUAEK0ROYRMoPeODGcJquSZ3TXlqsJCUllyYX
hRqQNrQlJRk5gARxMT9XLs2McuhPI6gxB0fHwjxypDvZJWJGVi+If0c99nOp
LQ7Xe4tlax8vNpYbcXu5Obds+Q79Lht0jJ6OF+tW73erccUXs51Zcw62Mm0M
y7Ut37qwP1+eroMwDyDL32xX4p9ca/P9p0Z4ZfMuIPEwiitXVKOtTx+CqNRS
6MusLB+892veG1DOjmozUUplGleHKjppURrq6rW5LuDN1+ttlDtNao4DXy5/
PL3p4bBrXg7JmXuJPLI3GzhIPJ1yB7WVW+Ol0hWzHvuqK3EwR+eGxE1Re9BE
QhuclKhTC5AmlKE7qF6lwouwaSkEjvD7SBzLhOrDaYlwNp+u5IXNmWJZGYWp
M9B5KZcVs1vuBbuo9SfGx393ZzGqcJlJhlem5TTPkRKQuDRVfZ6jxGzB1iVm
G+K13mu/wq9LuPpOnC/WhSftmu8s85yT5LQHDrQiCDcsPBvh7eLtZ35He4gy
Z13mXMpDRGrzyKVvMb7bOoMImiKjuok/aWmJ6pkSxYxqFyD2LMFHj0gJItSf
XomuLC+DTIHXBfxI3W6cMa1OgbCcR1bSfnanQ3LxsQTwXmsLg3VNcBRcPgke
PN10C6eFxDgs8WRVYnMegkix98mejKfUE2aVwWPrPurae2zGKw+oB2XdvvN1
NpQQ9odLt4WVzQzVZzbB4Jgfwl2eyBvYXxvK+xzC38IYJ+zpnFFkn9xWh6xO
qouywuQmkuRimY837paTEvx469ZjHF64WCNrSKKpgtdB/W6EkaY5SM+xeSk5
awz4cfx+3CCMPmda1YVZvEy1PB6+qGNKHFY6C1+fjkn6g+8jxQpfAqm1JXDp
bcZcVEEPVIrssydAcR4aTdXDicReFtuvrNWfFYGzslymm2BhwTStBhjiGDFo
09+hmqInHHdoRU4SxQqcvadEkKYGGV/Fba2zAEZSI/BjJcvc3QQ9I87o+rkA
rYcST1TOu4GddojfO0xmJf2L0N1KGwP/rQm0o8neMiC2YgPR0Zjs8EKSakX7
w/KRZhvlZPsiIiuNXGU46vCwu0F7gbzOxWR0WXj6eYNC3TIvTVW3tOxJIQKH
uWbmsldHbqzsR1XWVB+ztFLOezbGfj3FzmJywyzs0MWOxZKFynioyFJcfzQ1
oK0CkrIPFYeRk6oVEX9DlfR1EXBb0Nprf+wL2zwxHfTi6UXV6Bo8scxC156E
P6zL8hrb2jGA/mj6Y6Gam13fLLf7JjImZCWLsFG86XevoFuhDhxYthp0w9YN
XD3Q4ulw2oubIGfBfDOdXBxlOlzon82TjYi/tqbsVKXFJKcT0C0MC6vIsuVX
MCt/bZmxbAzB0V/OzOi9dZObnNaHfWI41cYdq8TVYCloHEGBqQCFW47U86Hy
9KABcwIyD8texDzs8katyriW309Y7f5FSlbXk94Sm704FEReWthW1dtoiDQ0
hl5H8DDGayrFFwnlvrL6Um0lQYF1ucwqG16ufmH6NK6uBHqBBLPtdqe05wTK
XPhQ2neFtmkrZsVV77EsbctH2cnBt8KjaMqubp0lBbdDBTYGTyBzsaPovLzP
XHOXVfm0hRQb1RUx4m1/1o8+KEgIKSy5ryvkaPtUWJ9un5CV4XQGgq5KkTJo
hhjHis0Toi4XcoVuX1vROa30t96Xb16WSd+KnDFT3zPOA5noKtu9MqytcFCf
Ycex15FnjbFvRXsRsEwG9iIMJgWnTImkhPRE1sA6O8gVaPS1k0DPq/Ipghk0
wsiwmWEqJS07l3qTsY+sk+2JooUbLXAQIw1v7fcln8eL208J2zC5nNYXhE1y
NNjBmIY8Seye0ARFA6SDWZi6LWdI+NDBszRpLmjmlifTXVGkClJZDEvcEZ4z
nXy77n5VHZIiwQwB2gg/TXOwahIMo2NCUzbTogUThOXHmuJ+OcybVq1Kd5RU
En/PVREpWSLOqIOlEKdToiDdj2+CuGLhjKimZpWrdtDROXRIcifOeKvRBzug
6YJXvsfJ42e/vzcxkno+PFldCFmXkDIsqhR3HJrSLm3wkka4sxKbmmawuqoZ
0SkA8E4LTwxxepTGYm1RFpGR7KuxZlnkrVokparBcU2Q1NQxemlgkTq/mNzF
240+VCUrf7bmD6fMMjiWKVV74tk0pVKksL6kj15jBzZCSgiDz5XK5AzFrJb4
Z84Kna0IKVjIe75DHhRMbdaRwnmL0Qer3Di+7oN+Hz9KNtnu9KrHsKfs6wvF
06fak2hwhxm99qQYZdT1i23y4srD9Rmd3nZXavl2wui80lRLjM5MR1HTppjl
ylU6dO0FwWuNPqq9ip3oSrI7GXWODs1rojP25o0+5YPqJsvC7QnnFv4tA+HF
NiVfnuLaR6HJuz/tcQ3vfqvmOyvkauGaS0hpq9kLkG0NcJ3kD0gNfFXyygpD
2mWkrFppWWBuQSzr9hVUflmK5S5TREq1M7MhpUAovKkLjzGbaspUuc7CrOVR
MurL4wLrSQOL/kq0XmR9peZE+d1Sm7dusSkyw5XPmVCxfskBsPwyFm4ud31A
N9bBf+TBiSsj6mNpjgfEG5bwl5YDs0pX8UF/05NRgZSUgF6QIqVpraEX1giN
m40+lgXAdTyS3QvVHOyqdy9YtC2W19a+7to4eblNKDZOCJy3OKh1miOWndK+
thpQ810waUipOq8hr4UQxGdSITvxRljKRz3cKS08z4NZQwtvddPUprpPz77J
aO9s2s6eb55aEAa+uLLo9YpY0871JSMxV66QSraAFbpveO4ETTfnJAAe9/wm
2+K/uHdFCwcaQAgWFqqvJiHhe/fdLrmg3DvFypVbP1mpL+laKRUl6yyvlIXU
Ctqwts81Ob0AYZc2RxIFnUAzRCfWTkkxFAwK2hJZkZksl8zn9e/Ow0EVlXCt
oK0KxjY5N6noB74ReI8A6tFBVAxW1vDrlTLDDOboCwugj2s+qQ4nthKEZD49
JVoWSqRSsdcUQdd5OXHIv8aYGNzMszBxRMIHN6o7CDnIyYSxNEr1scI9xeoI
F7JFbj/ZY8108FaA/sbRgzmZLg8sVAeqC1nKsrR4xbxRZZRaqb5Q1rxgKAXv
DaMEz2KGbn6rUh1ZIpByeTs915Fxbc2of9OgBy+yhQWLAVQc+339sFiwNMeX
GptlS0PGmFQIq2NQqckcQA6R0VPOyrdJGviokKm3jRIlfB8AzGMIYTIwbmjI
EBkl531lM7nhcQ0x0GM1zaShKnhonXtPhTFzxkr77dbR46Sdnli1KMXyjlhp
ikp0UhWtg90l3n26invKSh3m6dipNlrhI90xemxQ0UhtdVAdgZc3QIk+Dl6h
aaT1djy15RpmJ5azhe0/hiuggqEwD4D2AOWKrsBaNXomk92CTlba9UYfVnKi
VSeW4SFc/RNMuxJX73rFjy9JdkquV7QiJWyQ6KtSgSt3HtcUNYtCHxHQM5hK
ZuGVbzvUR2j8TdDXGX0cZdCQHAlKirBIoLBKVwuXDsc5cioWG2sOVuCW2Rfj
0CsTAYdZ9eiLhkUVX4+o/XL+ioyXNUBVED4dlBH0frm7i/hkeo2bpFD1qqud
pToB1orgqhCmTjHggqSAR4f0h8YXX6VoXh54rdHH0cb25NI25GX66xOItPbs
OfWyFFzF9aKvUOIsrUtoobUiR4oxkt75euEAGIny5K4Lu1pHvOg6ZwsjJ7qp
A/r7/+Gyy/rsatIV8atkmCOm5dl53pnqEl257Z0hxHCR42hvI4RMM+mX5KVz
peim5pca7U9y7b3HqVx+72/J0ynlDHwWKO0YjCRd/swRWQW4eI0la+GCJoC/
wwEClqpDepSfcY3R3qoxzesBTzMh4wHnXknLjmqxo1N105VOXXTysThG2IYZ
VtzN4NGBRhRmsLFCQL7TdWdezby5AS6UAp86Uki6K/5o13AsoV8RAyPvX+0e
Y3PK1LBc5/u51yzxuxxY2ofso7YvMdpb9aAZLH02EI4QuTzcyoDkNJv0Zvar
c7YFr+jGJsTq7s3J7ocmvfTFRvtnMAkk+XtpoKnKr5scrBAIXP2DNg5jaSbJ
AdkGt5Qls3yPgyq905mgepHR/lQ3PvILhN5RptlSuK1DAOr35bUApo5Irrs1
uMq8ywGodyKIOGS3Ju2fGe8BUePlGoEmlV18zo7JqVKAVxtNNzCWk+uih0bC
ex0StC7rkXCV0f5pxpwMjyly/JYmUkTEpxanhuvaYFsaMRDsRxtNXSG5tohJ
AAG2tHRYxFipXZwPrZmEvwPvygbIMrynYnu7zb8kVUnqKMkfY64rUVP+LdxR
4k+WzshkpfV+kNhisRfpti400oHykplNVxh9nGjMk7GX3tgnTCZc/Pcen/eo
zadStx1LEF1lCBjh/vSUzyb3GEqNAATmNFKk8ZEQzfQ80jYZfZweEIRCH332
Y/RSBG3cnQVRvG/cF0eqMQDUlXhSExkffu/u/TjCW2Lq4dMuzq7msnyu7gYU
X3UAggZK75LDgEpwBT0OCTQLlS55MSpvgIiLlFNNdOaUaLJmiV+euZ/UGtT2
p8+BSG18vyYSMkzv+jI9/YxbLedwOe1IcctBf+AWpEo4tfa0yzrppjk2gjxd
eVFe8Y6N8cggT5mie7UbvapMHUl2UtFEuRnMTLlxV62QZquvnBwp0n7FaPcs
JlKdIrKnEGXQBcETytMZRtqIDxFzMyggaEBChtwapnkzpNo5owTNZdWQZS4J
Afffv/b8qByWRfeWG9fpwC0pq0VnlF02TpSPC7VmpDCcbvAuzs+4729vuKHP
RvdKiUcjbwm4lzhOrse3onPWlwWyE4MKGs1hhUGVKfP24VzBMFhXsQSRsT7L
TIhRs7QaxJTUzh4AxCgXiYNQWHYfTpuqZOdm/Q/RkB57/OSTyR1quawTFux4
eRp0NQpo4tmyGA8gW7nRNSXXRnh4fxGxdIgzwG6B7Y7gjcvdDmKWGddY9bx2
MHlS+E7xXIuZMGSS1UXM3EHWEic8easagfU++tlNC0ULeJcYr7iSD53syFXw
yiTVCdZN03dW8hwb1mlpled7nr/P37gzwCp1UyeWgHOx8co5bgp0UkYd/Kjw
08l5MP1YbcnlNjw/Ys6d5vGB+hlfZMz4XDeIPooBjVx2QX6qoBOeqWqc7GCC
MgNHHaaFXcmOhqgEwjP9dGtw/8EAifacwoUMxdJ65Tw3hTQE2CjjKku6STml
zuFSIWUw2bm5p54sg4njYXAF4z43TQCnw8X4Hc8uMF4hN12xXKfy0/6tM4XU
dxajqyrkFWQM6SnZhQ1XDQv2z9WDvdF4ZSO/onTQe+4p/DzHmK9ZzkP9t5g9
eWQ4jhyxd0RH+gDylcNC/PP1EJ9fudCeT/SmfuLREBk66QJJw6047SN/Nymy
lR4HVSS0Zo1LXvLZBlcMiwFL0bk9YEWnqQtWzqvESnQFBOmmf/fSl/aVlZ/e
05ekjOVydMFLD5OEX4mjoyDFpjtunRFjdDSI2ekQo61e0SrBHM81unluMt/A
s7JLREQB37ev5OaX73qk2olXUyZ3y4xpgrEDB3cvIb/v0KEWnaxWlhnMWMTS
4LbqjhJpb7aRJp7RcxogTfn6xBsCRg9mW52km1/Bof0CLM/X/tkXviCuQygK
LJXFXgDJFyPFxh0BG9oPJdg42+jmbANEqdTx1+94R7+f1lKzRQYXHE0zZ9zE
o0gAJtcZJdCc6q7NFO8tsspauCOsba1nA7qq29e1hKjOQm50DtWJ9sh3C121
E4BafMqLS+SOPN/ABnzEcqFS1AefUY3U8t+61sdXLc3Cqhxnmf4VZyo38mMV
Zoc5deawEP+wg1gHRvCh8ORZRh8XVy5Y1/v6//kpxaZNQS6INZkyRn1NWI0D
xyzak0Sbzw/MUvgDxOPQWHmbw4r2JXqsnNkAK2oBYYWK2Nu69dzXOGysjISn
0ElyJ1id855v70ubVCBGb2/oCRsGQEyUpnKnjRhKWLAOdl9SuYbuaO13TzsN
w9/Z37VLILScow8++GDmqk8unqvKetTlKxRi2ArSgGCXZ4ixLosIZ5ObXR3U
NfqwahJ/zPWBULQOsFMGhHVWj8/l6cK7pOF7J6qYKakjucpVx7iSpAHgCqsk
tm/CcxrhqknR7E5D/LiqdFQLGbtclF4LNXxyj9Kjvr226Pddchg5Ya10YS64
kYamVxhNXVqD10MoQ6sRKjwZZJXa41Ls7Ybo+IR7hmXxl2RauHAGSNs7bkuF
37r8Nb2OJd9EMR5YTdNJKUBvejIerzPKxGIB6gZEWXaDQHxFQFOUWSc12O9l
iKPJ7EBWhJegwFVJOI0D9vykwVVBl371FNdUayFY4GcPjrHo2pGoXSXGqALZ
1xrgCUKKczCjFB/jDlkr41qSlxhHcqk8LpdhtTpizmCKLU/wIceH0nHaTZGS
38ViVeYfiozYGwxR5Z9xDp5XD7/XpcMIRA+udkOUiabjB1wFWac5gR541vW6
/5OBgl91z8B/6Rw4/nqm0Y7zAMnTW4KPYysw/lUZ4oz5rGLMKGoRzCDJ8bkG
/108WobdLgm4LhDV1hY1ls3CjCTMlvaC2P3YR9nJikLKWtS7pCoUwtQrzlaM
TA7Bi2bYO45XZeC7Xibju176/aouam5RjNKTXNJsV5+PwQceEuD9GUY3nK0N
l4LOcRBce0/9yeFoqD46mfJyKUiVOMBYfdIo16PoleGkC31gAFtprMlKHC+8
ZaDbYGIdY6ymj6a3Wb4zrINO2IWUByynGN3wSWLtk0Z1ZfEKVR3IWqh0QFYu
N5xGSl3wljefF0N7FpCu22gxTmBSGOKumLb9alP0bzXIyiXGdyE1dGBLvKBP
N7p2aebuIEEpe0X+mOkKSqSbJYot96axDsidtTJ+OalLJ31CBWi0Dp65N7wv
pmu0HxbzAP1kh/nUMY+NgQ1ystG1O9YR1834zDZm9vG1rP6wgqVDZTePOSMg
0h1wzLQRHgfMhIqmwzhIHahg0nBhn2R07Q5HLfeK9t89lRMytsz4rm+U+OlJ
7053/qocAfBCEQLGMLZLKZThPOjrhwWb84h1BT+R8cVaow93rKe941EMUCrI
f7liTahhO17p8MHau8vVMgcgl5KWaC/+ddlUw4DjSu93U48DtANQ8tMqIaIq
PiViSW2JDq5rM0rFEK18cEswJodI0TUQxmWchKww2eGhdnczdMHjteASLnmC
0c1LKqdKRfJ1rVcK+umFzYNEoZ9Qnne88oCoyhDHONqLxZJLu/ew+84YFjM/
4TADLOigK7AEbB3fADNBDnSwiLItKfwN28hi/Kk14OV+yQUsvpecOUIGMOQL
yw/tywYkg2AjUjR/MvB0HR4D8UEuHWd0s9mYbTcwKZ1/UE39nUwRspQcVQQo
PeWznrlOyXR1qKQRIj7rpqA1U8/hjjXac5FH7YSERJMKJRVJFebvqtiXvnS+
zVjkZjiDjVEwGrQUvukeOUsAEh+sWCNgf8Pmf5I+s8Z4xVX6PELX+IpuO7Xy
KaqQYOlQkgSsbIs777v6rdE42RW7Fmyfc7DBPah1QfyOZ6uNV7YYJOYWcsU9
tI1KEvuT404jV1iSJxDBnNbVcDtgWaV/DO1VBpVoA5RH2QjWB8NO1adnsaZY
26MbwBpsDML9jh0uh4XuAxOXlrZD0syR4FO3v2O+J9oezB7J1ay/+caC9zfd
QNpD6DfpUUZ7V2AkHN7SQrrkMSLIIb7O+4tPflIne2U5YBYHsth5S8wJCu5w
Nm4D5ZNmvs8BqDcm/qXzWkdW7sqJTKEqpyWuJwTgNt+57YPmsWh/UDwmCKOS
IQTZegOYRul6X3DPIEvheQGDNtfrRp6Ldiayd2HdQ9eTvwhDwPeexsVOPksw
kO7heJGWBr4tUgnytNHFkhZoD3laPuifWSvlCkYuXfN/vvIVGXfXn25wc9Wx
vCRmxZo+wlGiUkAZanTHY9PgppVFvo05S4kmfVCh19v2KZ0epTGrjBKor6K4
j/SSPGuqcjUrkruUTUnc2gpkJecZRdVmK05kBvgpnsi8hzad9nj49/l2S4x3
3W9tuXULyYSoedY1IMi1hd1SuFlryms+f6N/58TDBN0vuFlLyAKGijrZZWhM
VkmyjrcTD3RcpCAohb1IJ8KTRNrWHepXgYh+ZGaXbQ8XRmZ455RY0FYWxgH/
m2yAGVV/Y/O3PvhBuX5iaurq97aYfhIXbAR5pHoZ99mpCpESwXrgHy+mk3wV
SJEso0WSSQuuGbHgC+eoaKE8gn/Xui3hlQavmSw89z/vvNJQ+/veUklN96jw
hKHKNeNTVdFBnu3kWzz8nVHlHEtRDnApSudw1IpwNLTlydwB1quYHoIY2F7+
RELX6M9V3/KR7HXrrv95yWwn3UPTgBS60ooCp0kIx8GpLb9zyOTliSDC4Ac9
fVhIP+LggJdT7wvoA8i6swC8JSH2xIDS7nTy3eK0nwSWtQrBHF+kA5UXKjeB
hpFOsSwaxo+6Z1LkTq8mBvBKQqsSWNty5B2ujS+YgaGKQBZ8cUY6VS4STIO+
GtGpc2h1sTG1dSgrZU2ehVe0n/yRIi/T4LCoul93SYBD1hT+cmd6Rz5d+Dka
wfEH7hm4bsJ02nBkynEyvPPmwA51Scq05NYCRya4TiGWRZQ1aOHHuMf6LnPI
y0Yw/GHgD2L1CEUBJsBG7e/gMdghJ1eBWMp9VUSp8JcORDocfl/D6FGJCaCE
RhD8saMmtNdV1ImyynavNWiBdXRKIWSGZoUt9Wnz3E1Wmasp6hGObMj3zhhp
g+RlgrC5GgH4qOMx2GrglN4wLduACVD5iNcY62BpdipqJLsAOfiWBE9LF6pS
h6LvPHzwaFcgCt85EMe17SzSxWeWNJLvLkmmC2IgRl5+JwsK/L2mwYqocwOp
Q8nnG4WUeLPCpy97UWouUictSrQaOuzzWGDiAptsOb+eaLHDmFw3ZnhSsYjn
Jw4eOiDK9q9wWFIjms+ZpqzycWQ1ZKayGtQi4W5yASLPSsQi6QwcfdFFL0Ax
1sQaWf7WkV5OFpF2GAu6TsuQxO54y4SPM3yv61KsrbIexvlO6INy+aU6iAv/
w0ijgg6iXtSu/PgtUrjIurthYImkRmOEHTsufEOdSGG5OJ7qPaAscQbIOYqh
AvmLsbzHwk6hFHH85Q5WTBIHO+T8HMheoqfi1lc3BDnweqmmI5FNLLpVZkrx
yjTH+7BD/TpjLo5R9TIfhIgY9uxY0UA336zAlLgnUkM+lRqqLIiIVzoi1Ci5
aZRoUNXXpHI96Xt/9oUvpGCv32ifv+cwkPgwYK578WWdihDX4DDJgosBfYln
amS0kRi90ZifJeE5QwbKma6mZVB2XK1PxQnYnJHoFw5U4zXWmnT0a/O6bR/M
0mcXD7lP0QVzA9dJlbhAlJnuLMFRYn6PXujbp/Efq5yY1HbkNnf+1InEQ++5
54zNojP60j8F7gDa9qmRQj8Z1j0177DnqPIyWlgqULUmHmt7f3vDDU3Ks2bX
YGyflUR37D7L4amr2O4799xzBzkMsyBqWBvVEk9bvt6PcWvlNu5Y1q3fCrXH
8wORcaYWupKoLC6DT3ZOWitpEExEkXILE1wyAxCLaBJMADNeKXO3SrTFtQRe
CUlXzd/NO0/E1iRB+eef/azkaCKCdGD1MtoHK8/Z9UgjEK38bvagQ31KPXf4
mw5MooXTYtqbH7mcIk4HvzOxHHytOjVuIjueUz4FBkTq0for0bFO2g0Ny8qw
f8W5UbSCj8sT6Y3JGgQ9zBfWx1F3YmGlGSLSPxXhYoZJxN46DtCIP1mwrApk
JtlBWveHk4QcHK9MYAmmI3kAYJ1oS1P6FRFOseiVBj6eOezEjwwEJbk2MnG4
VOnMKVq8wsDWshpOYelWTH1yjJ0sHO6Dgs/vv5YjcIyYoYFiUwrMRLQwAQqG
nQ/+XGdMcpXNCKzDsWxeavYGRYJlHyk8zzp2n2u+Zfe6YaFZ7VndQTjK9D6B
fKVoNFpcW0lbpqYutWOxwaG8WCqdg7CnXWjZlfS+UlVQ8dDF0HfWOP8cZNwB
v5UUW/CHzF5qzNe6wUVdpyJFGmECVdsw45rtYUdG3aWw4q+hYeXkLagqkjFS
KMPbw3qTAatU6i/XRnIc/O6zqFVH3/YWxTfuO/VUeoI+e42Bovk3DVtzDiOY
SMpcyCqSds5340s3INsl+HuzYiC87bAf/n7NsmXo71vnHXPMhAHDIE6RBZWq
E3nfKGjwO9/ZLqmocscLpRpaaibHeaKsmV2OcwywDkPCcFJg9/7ZbbzVS9SC
8mWTgE2DtVnBOdaJtQ/9r9YcffSfHTrxRHFSD79RmsJyL/2c0OIHspN2bMKg
JEs2vbUaAMgtE3jXl/dUzuzDBwAn8MBkA2cjRu7iTuMi8OH2xwQNBTSqyBEy
6zsSRC41ofSVEdWnsGBxGTtdfR8MPhBQQLKzwbwRNfX6N3xMAiOks4XKHJ2d
28/3qWT+vkveSFLKEiUMiqHrKlTPn0Li3phsBZXB60FOGbWDoCWidXotiFJd
oLhMnyg5WHSXeNe16gvEjMKIQAxVDrTOPA8dEK0pUIlFSsUtdgp0KFqBFxgT
eWpgfZ7S8CTE9CmgIAof5CmIWW4hYFmwIuJGhusRlAKu5LNbdQ7KSJHBCf7Y
id5abAVrEWo8mSWXGnz9yEo+SWYYUkb6c0VxaGWvxzKQEu+k6RgTVmK1iFuJ
rIEY9t3NYLf0Dj6gD1gghyhU0QrmCmAn6nyeAZO68eKaY4rin5c+pSVC/Sfv
estbfLs0N0btlL2fO+tqTJcOKWgcDg0Ql0MBfwc7BeUWbTcpbGe4GFL7C4GL
Q2Ptrky+v9OxW5pUWlBa5wTyM1xvMoYXymGxywVHQ8PAR4rhK/DaUrIotFNc
Gu3yHW+4kPwJ3tfKfBVTwrCU25vuKH/5iA84wy0g3KpZ4ow193MMLsL4hziA
eCKC4muosBaJO2YCfF/mCRkuUSPIZVIoQn0/b0LSWv3QsJM+LxANtiIIpegE
9RTPaLe74xQ9nS5FTk3kdb/t+W7OZ779QS61I5YjuFY4Sp1V6QPNYKnAFJ95
4OvfJbHcKOJrgXJBEF/ANR2obge/kG93dcA/mJniwh1JYDBOPUxo4wnrou9E
9bTF/lPRPz6075aPN07ds2By5YzopheoR+IsJZcdlyrVaQwMRzdK7ckOdZBA
koAwpOzOrzHZwVnJahIk+OP7upc/NHXxE6YEfsawME3FJEfkdVVYE/GXaxel
j+VZWb7OFloKqSrrg5utkZuYEhwMjP6+Ymr/1Cl/YWUwNIKpOoAct3MFNztS
CgvrB75G8DocdLQejrgNrdmKsEjYR4f+dXwcU0H1nJKjazprze9bs+U7U0t/
l/6SYpDJWYGnmzBpG3ZBleDKQGkyW0lbwo6B+IRiB0gZYRBA4CWkzzsVaQIM
TUKRAAq/iyfl8/sufUd/qthn3idAedBjzdWbEtv9u3HyDMXU+r3wBf6kL7r0
k8yahIwQL8jawTPn23U8+WbtNkO5TfrDs1H2hzmn7QBb3K7nvvB2zsAd0BKG
dh3XzocZVDuk6uBbWg3uz5+hGaK/4ReqZqXLgea8d6nrSPcbp576w1+68MIH
P/WSl8z93K23znf+bRe74VqN01olJ2ZgJu391tOxKwFb6zt3Lf3Jx7d2P/74
VPfL5sGgkwdgdNFkf7ClfrCl3E/pQHJtoHNAD2l5pR0q8N34kLC4m8Tdh7Hj
fvHlL3/s3ttvP0iLNr7oxZ+IFr/8QIxCIEENhIBa/e1vf7cYbP2WZttMxbwh
hnfuPH/7gbvWfnj/Xad87L173vbY0CoeV2KB2gqpCdOB7hJzGikwCo0Imip5
6qCdumoAbbjGBUwIW1Z2fRUofChbeSwckJqoPPqpCwCfOiwwfP0uZgZtAbPG
7Mm4ngyuJB9ypkjTGAWjOvIC1Ak0IsV8PBhQXgk8hTd5GnzGCg098xvCzIFA
4NRPwgmMFtXWTEgHz9COkiXb9LOly44US5ywAQawtNB4sdTrGAbrfLl1ffOy
YeFyV8hRyUjQCuZLjlI3Ve/TUyDpc7vFskCGeI5XKT8Bet2zknmGnF7jMpJh
5u4SEijk5XHcdZjGM8CCD7aNo6H40CNXzY0o/ijj2dJh5/dLxkIN7fpIO1uU
L+iTBpjLjNkeO+wAdxmdnW9AMLIBQnkoKwsihvSYYQe92+jMnRbN08D0xIaO
0sui59fktSKWkNby9Gxi1BVypb3+rk0/W1H5rLGBAMxvpUtiBlat0kbwOe1h
SW15L/qbq+GhDNtEw7k7KZqftTGyhOiOEYN4jmwCg2Qk5aXixqNScfjIuqCq
X28gOKxzGVa9/JjIThgIgAWKw6bEBUCt85UWEL/YgKMBsCEmXF1sMn7mJkzv
VtZm/WwVOzo8lVEdcTStjPp7xgJPDISvBSbXMfDVHnJyvoz4qBZT2tGWihd4
wck9UrVdRlKYM94lNchecJ6fabKFhytb2Y15UQDCgmHY+Zo7uLay48qFWb+I
PvXMi7eZuab0ae3s4yvps2HxQ0+nfo4oH+DELZEPD9QUn19PJ9RUERHoNOFk
0A3bGVZ16M5+w8D7ccN2xuWJqs5vHz2qfpOj0kP3+3mmnSa1Vr2eOGrEqGpg
Gr5FjmWnTFgZmEPbj5/nzvSJjTWL7UzPeujOftMAc7XZGb1ndfE1/+2AYz9k
0E2mpw7bmc8CGZ4w7NKUdSmufjeMYtBwRUBeFN3nkC6GgGpq7/tB0KY77ECP
pBBt2Z0rK007+31j1uPDdja0eHryX/yjKlocRWfeAhums982ZlZ5FnEUA/gk
+mE6+x1jZlb5uiQcT33UDGXVNH95w2dbGrbjiiXp5hzBTFf8B352+ffRXLJr
qEpOqFXpkihrlo/+PcLoduX3EYjfT8/+bfHSjZ4p3rLUeIUPzlrltqLlz1Sx
H9DDv296KBm4RQ8r/ALrFSca+Ix6+mkmG+1D6hnPqNOzvv/f+QT9U+Fa6UWO
WjwJ3cwXszPT3lMxM1vMR5uobTftRU3dhx0f0/Rcztz35+fwVuQvmZ6ZK+ZV
iMKNoP1oS5IJR10nAISZJu2kjKv1OqY1My0umuXld9Pl8PPcrXY5uXY09eT9
EqyWwtvcfGzTiJcIUHUWwkZfjrl3/dR8m+kZ9N0Eoa7N0hJ5M+TTIwTSOqUY
MBC1zEZUPQK8j2sE09AutDl+1XfP64MWLpjsgyE6kNJlcrc8hbK009PbXRxs
PL5BKW5S2G1iAPyM2YeKN9x7R+ZUFDYlI5DfsZGREnktjXeNt2nErp9SGLjE
15g8jn3AHSM8KOJVU7Mcsg9g6fDcHGOeqDa8r1Dkdk03QVEyjU7+9dwMY7dH
m2JmIYq20LIw/IsaOLoYKqKIVhT9e31Mwx47ZZOu8UwulvTdOp7giXJuxnvB
ue3yRm0Nom4lQwl7qh5qZRTCCnTriMXaN4PQ9pr8bTVays9TNpXz88AYZkrR
4ocp+cjcjMe3xcPTeF0IqGQz76WPqYv5MFL1yi6M7mWhrY8rhGGq2ImcAape
CkLSkzuddkTk8/OBEjwXoVm9Qe8WjVZ9u1dEdbFqoUM0vfT1FAXVzQzqVAqX
3j7ZHOWckp/jzEyCx7qlWXiXGFqOIt0WC+RkrukIkVwqV3NVzS7QUtfvDBUP
FX3VD1kCOl6HshqEa/h7BhCNlZkM1qSr0c5ErorGEW5s+RmlkDBF/2KCYZGL
pHhEWlg8eVEG3SqkOk5dG2sbtqKkGtlO+j0h3yDxU+17ceR7lPF2GGm63Cwz
s3PFXKkAzs83J+Fxr22E7yaKaprOn2XTHTcQZj3rNEa+hTgDQ0ubEXSYwghn
4Pe8Mj3E8tGzeX1C1GoJhah1KPz7g6hjKV2yqYwJjIYdq9VxeubEYDSs2tbS
sAG07vs/JQHHiS1upbXhCuaC19iy/B8R3qqIhSbdMpqOSs9I6WwQPcO7T7z2
OaAKWNFzRu9uHisKnIVEKvlsyatl0CYLDb3A065Kba3WwLMpxCqJWwNP0iNQ
PzQV15CaRtOydBAbB4OqH0PMpFtoK538VHOkau+MaV3v/ZSBhjVSFigQPRcU
/loLtKZtP5o4jT+4Bbq2iDws84a3pZLm3TMxkL1plj2fSUhajxeWpMRYzapn
1tWsDRmIvdqNGC9WNfVPpIgN4yjlPV2sOmwbmKxWtyOhqr0vyeLF8mkk06nb
G4SJCqaqXQGCs0gmLMjU2wlIMzPakxi7lfI2SwvTVzE9HdHkfGCfTpM4MiF1
wwGTOGgqt0P59+zMdvFYweMqWHMKXzvS4MrF7PKX2k8vTavci8oPZrkXu7w4
4pBhEohzzh2avJVpehdjnESzqPfrVrsP6e+BYW4ymqUfVa9/uViWt5bNSndW
YzzCaipsRJjq8M6cigQpr6EVCfJNV0RNI/iwbl7jUm3YjAj+/fEogJISrJMH
qxKiribgeReo8qJnRvuldKwrcBZhzERyOvailMN4pTsRGVvREHmvJ4tBC6D6
U4sTNHAOfUwrtzFCH4yecSHMJEY07URVMAJSDPdyDFuMc0UNEZZ/z8+qURPE
TqudZ2CmnMpAM1lePROTrJxk8KPEBPxGvS2URoSewipIyVEtjlb5xcPgPGjZ
8+xsWDw58oQ20B8w6rONvn7WzcKd6OtE7F+aWFM4kttHqgkPPbXQMO2INZYM
62wv+SLsSh0sF7JzHR2lhWSwI6aMpumYcfitYszjFdELLRzlcemWCEA+z2j3
M25A+uMfm/9ePOX/A8jeTu4=\
\>"],ExpressionUUID->"1414f909-82a8-4e5c-bf16-fbeb21bf6ff7"],

Cell[BoxData["\<\"Plotting plane x3x5\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268622716866`*^9},ExpressionUUID->"f9fe9258-c3b8-4d79-a1b3-\
9ca907165ee6"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226862277356*^9},ExpressionUUID->"95726722-ce2b-4a15-83f2-\
72ed8f89d235"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268622824078`*^9},ExpressionUUID->"491f710f-3721-47e0-a97e-\
ea3c496ba2d6"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxle3k4Fm3YfhvZU5YoEil7loSkbmQpsqWQiCzZIlspS0RJdgmJEqJFiyWi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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd23c8V/37B3AjGVFEZYbKKImQrByUMhsqpYXMyLqTlZCSUSgrSUShlFVW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       "]]},
     Annotation[#, "Charting`Private`Tag$25995#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxdmHk0lt/XxhURKSLKUIZCilKEDJ0MJaJJSUSmSAghEklmkjKEkMjUqIhE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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwV1GV7FgQYBeDB6BzdMRiju3PkgNGjG0a3gJSUQSrdnQpKd2OCgoJBd0hL
KCUd9/vhPucHPNdzQmP6RfeNFRQU1E8EOjbBxCEu8YhPAhKSiMQkISnJSE4I
KUhJKlKThrSkIz0ZyEgmMpOFrGQjO6HkICdh5CKc3OQhL/nITwEKUojCFKEo
xShOCUpSitKUoSzlKE8FKlKJCCpThapUozo1iKQmtahNFHWoSz3q04CGNCKa
xjShKc1oTgta0orWtKEt7WhPBzoSQyc604WudKM7PehJL3rTh76B2/EB/RnA
QD5kEIMZwlCG8RHDGcFIRjGaj/mET/mMMYxlHOOZwEQ+5wsmMZkpTGUa05nB
TGYxmznMZR7zWcBCFrGYJSxlGctZwUq+5CtWsZqv+YY1rGUd69nARjaxmS1s
ZRvb2cFOdrGbPexlH/v5lu/4nh/4kZ84wEF+5hcOcZhf+Y0jHOV3/uBP/uIY
xznBSU5xmjOc5RznucBFLnGZK1zlb65xnRvc5Ba3ucM/3OUe93nAv/zHQx7x
mCc85X+e8ZwXvOQVr3nDW94ReP5YxCaYOMQlHvFJQEISkZgkJCUZyQkhBSlJ
RWrSkJZ0pCcDGclEZrKQlWxkJ5Qc5CSMXISTmzzkJR/5KUBBClGYIhSlGMUp
QUlKUZoylKUc5alARSoRQWWqUJVqVKcGkdSkFrWJog51qUd9GtCQRkTTmCY0
pRnNaUFLWtGaNrSlHe3pQEdi6ERnutCVbnSnBz3pRW/6EBjvwHa/B+nMmlw=

         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$26015"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"1877.5632524337097`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26015"}], ")"}]}], "+", 
                 RowBox[{"39.23391456257338`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26016"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"39.23391456257338`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26015"}], ")"}]}], "+", 
                 RowBox[{"2605.2065706835965`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26016"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$26016"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$26015) (
         1877.5632524337097` (-1. + Charting`Private`pvar$26015) + 
         39.23391456257338 (-1. + Charting`Private`pvar$26016)) - 
        1. (39.23391456257338 (-1. + Charting`Private`pvar$26015) + 
         2605.2065706835965` (-1. + Charting`Private`pvar$26016)) (-1. + 
         Charting`Private`pvar$26016) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9805867047941716, 0.9828094614353261}, {1.0194132952058284`, 
      0.9828094614353261}, {1.0194132952058284`, 1.017190538564674}, {
      0.9805867047941716, 1.017190538564674}, {0.9805867047941716, 
      0.9828094614353261}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]5/\[LeftAngleBracket]\[Sigma]5\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]3/\[LeftAngleBracket]\[Sigma]3\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.976704045753006, 1.0232959542469942`}, {0.9793713537223914, 
   1.0206286462776086`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268633016*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ExpressionUUID->"4c7030ba-779e-41b8-ba68-f54d050a99fe"],

Cell[BoxData["\<\"Plotting plane x4x5\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.7562268633214464`*^9},ExpressionUUID->"89c1a25a-a9c0-4265-ad5a-\
3156cac20c19"],

Cell[BoxData["\<\"The center of the ellipse is at {1,1}\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226863327364*^9},ExpressionUUID->"1ed908d4-f275-4db8-9e98-\
871869c1c170"],

Cell[BoxData["\<\"-----------------------\"\>"], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226863333415*^9},ExpressionUUID->"ba030536-1b90-4d79-8fbc-\
c0a74a1cd00a"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->4], {0., 0.}], CompressedData["
1:eJxlW2k0Vm24llIkEkJShsgQGQpJ9RAqZMhMiiRCMhYZMiakKJmnUFJRhgZK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        "]],
       FontFamily->"Helvetica"]}, {}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], FaceForm[
      Opacity[0.3]], LineBox[CompressedData["
1:eJxd23c8Vu//B3DJSkrJjKSIZESISh0NW0i2iIxsFVFIKKNBhQoZhSgjPkpW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       "]]},
     Annotation[#, "Charting`Private`Tag$26132#1"]& ]}, 
   GraphicsComplexBox[CompressedData["
1:eJxd2Gc8l+sfB3CKjozKSKFJRnQSiRAXUWQnLRJJIqvQIiujjHQolCQkP2kZ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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0., 0, 0], Thickness[0.006], Dashing[{0.06, 0.02}], 
        LineBox[CompressedData["
1:eJwl1Gd7CAYUBeDEjBB7E4QQRMxYEXvGyjASEitmrNhatemgk9boHnTSYXTQ
0hodtHQYLa29N6Wo/ebx4T3nB9znnrD0zKTRgQEBAWNFVmcjOznISS5yE0Qe
gslLPkLITwEKUojCFKEoxShOCUpSitKUoSyhlKM8FQijIpUIpzJViKAq1ahO
JDWIoia1qE0d6lKPaOrTgIY0ojExNCGWpjSjOS1oSSta04a2tKM9HYijI53o
TBe6Ek8CiSTRje70oCfJpNCL3qSSRh/60o/+DCCdgQxiMEMYyjAyGM4IRjKK
0WQyJuuGjGM8E5jIJCbzCI8yhceYyjSmM4OZzGI2c5jL4zzBkzzFPObzNM/w
LM/xPC+wgIW8yEssYjFLWMrLvMKrvMbrvMGbvMXbvMMylvMu7/E+H/AhH7GC
lXzMJ3zKZ6xiNWtYy+d8wZd8xTrW8zXfsIGNfMt3bGIzW9jK9/zAj/zENrbz
M7+wg538ym/8zh/sYjd72Muf/MU+9vM3/3CAgxziMEc4yjGOc4KTnOI0ZzjL
Oc5zgYtc4jJX+JerXOM/rnODm/zPLW5zh7vc4z5Zzx9INrKTg5zkIjdB5CGY
vOQjhPwUoCCFKEwRilKM4pSgJKUoTRnKEko5ylOBMCpSiXAqU4UIqlKN6kRS
gyhqUova1KEu9YimPg1oSCMaE0MTYmlKM5rTgpa0ojVtaEs72tOBODrSic50
oSvxJJBIEt3oTg96kkwKvehNKmn0oS/96M8A0hnIIAYzhKEMI4PhjGAko8ga
70zGBD7c8AfN1ZtB
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{"1.`", "\[VeryThinSpace]"}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$26152"}], 
               ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"2348.4891397368533`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26152"}], ")"}]}], "+", 
                 RowBox[{"60.44652959200071`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26153"}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"1.`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"60.44652959200071`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26152"}], ")"}]}], "+", 
                 RowBox[{"2615.4083390329183`", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1.`"}], "+", 
                    "Charting`Private`pvar$26153"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "1.`"}], "+", "Charting`Private`pvar$26153"}], 
               ")"}]}]}], "\[Equal]", "0.`"}]],
      Annotation[#, 
       1. - 1. (-1. + Charting`Private`pvar$26152) (
         2348.4891397368533` (-1. + Charting`Private`pvar$26152) + 
         60.44652959200071 (-1. + Charting`Private`pvar$26153)) - 
        1. (60.44652959200071 (-1. + Charting`Private`pvar$26152) + 
         2615.4083390329183` (-1. + Charting`Private`pvar$26153)) (-1. + 
         Charting`Private`pvar$26153) == 0., "Tooltip"]& ]}], 
   {RGBColor[0, 0, 1], InsetBox["\<\"\[FivePointedStar]\"\>", {1, 1}, {0, 0}], 
    {Dashing[{0.02, 0.02}], 
     LineBox[{{0.9818820806959085, 0.9828094614353261}, {1.0181179193040915`, 
      0.9828094614353261}, {1.0181179193040915`, 1.017190538564674}, {
      0.9818820806959085, 1.017190538564674}, {0.9818820806959085, 
      0.9828094614353261}}]}}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1, 1},
  BaseStyle->{FontFamily -> "Helvetica", 16},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
     "\"\[Sigma]5/\[LeftAngleBracket]\[Sigma]5\[RightAngleBracket]\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"\[Sigma]4/\[LeftAngleBracket]\[Sigma]4\[RightAngleBracket]\"", 
      TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{500, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Approximate 1\[Sigma] countours\"", TraditionalForm],
  PlotRange->{{0.9782584968350903, 1.0217415031649097`}, {0.9793713537223914, 
   1.0206286462776086`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{
  3.756166022902919*^9, 3.756166180340079*^9, 3.7561662866800036`*^9, 
   3.7561663420964165`*^9, 3.7561665071526756`*^9, 3.756166570936696*^9, 
   3.756166730115667*^9, {3.756166948747594*^9, 3.7561669723547354`*^9}, 
   3.7562267183105087`*^9, 
   3.756226864398117*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztvQ2UX9VxJ/jc/49uSegDIZBAGDUfFgJszDdCfDXmSzYYBNhYGGxECDKO
TUwcb4KDbdHYCSSTY2HPTIiz7siT9YRMklmc2ZnGc4Y5ipOdMM6OT5/Z9QzO
crKyz2TdszknR2dm4hCfWee/71e36r669/3e6/dvNdiZWR+3kF6/d2/V79at
W7eqbt13PvCxhx965IGPffDBB6Zv/ugDjz78wQd/evqmj3y0fNR7Q1G84S/L
nx9MF/j7qCjsj1H5/9H38AeeZH/fIn/vFaPFxWJhYaFYLP91gj0bLRaL5bOF
xVHxv5JvFub2F/tn5+WbTfpscX622L9/rlgo//WH7pvNsZ/5Ynb//mJuYVSc
GPtZKOb0mf9mfUYH+hn4frTvkwg9fxDa+YH8Z1i+Pifd7pef2WJuXpqb0l/7
L9Hb/KxQ088InJ1fLPpdWkxpmSC8K33/r/yn/GhhTlqaK3vAk9HighChTUxS
OkcBhbmFPgG/N07LKb098uxrnt4G9hxKodnJGsECQct3/bHa52QHmGeL+cVW
ssPrgwQ0w3RSIOvLSIVupblIiWAaPmEUL930UJu2nyBy5VBmBHsx7ymmnr+I
qf57ohG/IDyzJgXlj7wzt8Bm1HK7YoL4+ylHAbvQRC8bWWAyoV17ciK1CUeT
Jv4Vjo68/gr2l38HFLOBckNIX7du7D0bCMZWYKMSG992fwX76yUQhf6+5vXm
lGgLaXJuoZrDVTc9FS0PvOthIiE2FRs/Lv3XoLcAjarZv3G/WpibLVXQ/vJf
mIjlnyVhc3PzsspN+IlbtjpfQ2uyNo08woMV6IcB9AduVfR92Ops7RlYsiix
UaZ9hJFf3djuKtpuLpl+5V4jf+/HxUe/STV06JZp9w3Z2lVbQQIsvsfj2haE
akWPz7yG2tCwWPl/+74S+0jfPeJ+32RrvU5/3+2Fy1koyexzA2frQzLI1Td9
bU7QcL/GQN24sl312n+9m0gt66XXQlW/5Xcr0f6QtLES7dr7/nd90yxuhQ4z
r7jZ1L9TIjJ73L8rRaJoxwFKlY8tJUEA3LKk5iwE4fpj6o98twRNNxNIJzvQ
0NjfCrQ96Dj0kzZQLW3l+G4Mw3pTJjX4VWKtqzG0WidSYtRUuw+28F83VtOp
uTgkz24ifQwb+xgmfbjfMxLGazr9tt9xkJrbm8xIHcU5ifXl+Gyg3JaPLT02
UInJV8lBOlBBNK4bq+l0sR2SZ61o1voYppuaukz5X4/XdPrt2AO1RHu5Aq3s
jGywsq1CravV2UqI38Ud4lKIXDdWV5OtXU10eGfpEfA0DJP33O8ZieM1zTfN
4w1uc3vpszC467PBZfvAmvbeoGjWtbBNcDxrWQnfNlZ3x4/RXfM7rSNRo2OY
LjTtyma8ptmuboxBHqu9oILXjTfI/USemLLwToFB1ZWzxK4/5r6GSV+NGuO/
q8EdZIOLGbx2PPXc7PFZE5u1KRUQzm2v8Pu3HXN/w7S/plHoMMD/7ahoe8/r
zuPGM5aWBtwGNO6pmAnY1YDq3F37LLs+EwnxHVXArJCptexeVte81A1N3Ljc
HlJCmULI5aCrDe9cRglkWSRnKTlYse4yT2W6IbqBrikrujFaXhdpG3zp8/rk
GFlol2MVhS7+i9RGrptHNe9+g76/foX7anvnpihR5uEStlfKdXEMzff5pze3
tbhhaR+GTUH3LLqw5hZ0hTePJTO3pvR33Z15AekbV7TNzEHots9TLf30W343
blts6z5uG3F5iqOyvxSr4ET0IQ2dhMfihL4K/xmNyra/ij/e4J4WPTyJnfXI
s+PJsw0dn630txZqfuWVV+Kz4Qr3u4b0wXD5YWHQ9T3jY35/If/b9cwr5ngh
7fWTZyXv8uob/pbLyw+rjx8l3nI5KPbPt8gBGd+lhGAzefY+8uz9HZ+9V/4c
JBOw/JF3tvwwCGLPTupCyLeani3nw89n44j5fP1KNQahWHZj2wllP6HP/CC+
rUsH39TR943Z6O8gVD+fN3qqNvA6hFwHhP57CBiPZTyBbuPpHALU/5zztFX+
8/qFEPsdGAMTH5dnfU88vvlW+qo0o5ycko3ACkbN2GL0XoLu4+S9f9+B4pUP
HzGKv0Dkh82Tl0VGwJgXlJTY1zR80oV4yEijFqF0vz6RAZHvAfq/mMD9Y0Ro
riRc/Dv82V8GFyvh+ma651IC/5fGgv91cusy/XIZQZ3ZsJ8bn6HX3I3J5sIN
ZDAOhmf7Dh069MSBAwfk/bX4W9F79ODBgzOHDx/GTzEhf/amjxw5EtvLFz9g
8Sh5dnYjFq+PK49hcSMZ208G4d7x8ssvg1vwDySeeuyxx4qJwzMzM0Xv5R07
dgAreVP3fvjNyFT0SZJVL88ee+qpp+SNswju5xOcriXv1bDrsvCulO+LTYqb
COEfC21tWVxcBHAmTM/t3bsXQCxu2bKlWBWAEdGytoYEwM2N7w0AKJ6bYGKg
ipPJQL6FADkgdO8k327PATfrbSXdT0xV5sCC6I+ENna+9NJLAPXgo48+CrBe
nZqaKtYKUH38Hc/wg3eEpIkLcFqDeipMumU+98OfNmD20wvCvuf555/Px2rh
ggsukLGSUZI/B5gUGGuMDxqcevXVV6Oy8dj2CYsP5Hiz1flm0tgHQ5PgFB0f
2rdv30s7d+5cIzRNgiZwgcdgCSxGmVlPujgtPDu6YcOGyN9U4O/I9PT083v2
7EE7aANyTkna14WX/yU8Q4Oxo4H8OUTnIBoa5+Fnn33WOmPbx21hVGw48brN
OfAeplsfUw89YcpAin6zC4W/HZ4luj4M/5SsEUo1g+WNpLmwGesblc8+/PDD
GKipVH6tld/oQuFvhnmBsQdnoMLa0TnZw+/Q3oajR48WZ5A2zqvkx+YWyJoM
ko3mXti9e7eAsJXoDqZPPt6F9t8I/YKuvc+V/ysHDOPer/qV+VORmH7+1sA6
3gF7gC2qBG1DWLb3T87oZLowbpyWov1QpUOAu+A9rI8jiHsz+ZzhGI5n9SGc
mMbAHMPwRjK9BuTZY13Ivpv0e33FCqYb5oyyIjoO4rD7hRdeKC7owAfwCyLW
x5ACBkg6JsTfWw59aG+mog+Qevog7tZ+cTFp71QC1OlhEYC42QTGD9qC+IvM
MLfJw10YOId8eB4hgu1thpW2gUwBfNWHfcwLEGwEXka6Vpyg50132zww3mQ+
nUkwXhZvcdHKnuniBgGAEHtCQBjUnqy2u0gfGmwGoaYTFANRCPi3LMZnEEw/
0IWJc8mHD6hid88gbSAUy4ZTSABX+r+aNK0LPcYHYItOUNqxQmBSi6D+Yhc6
P1sBgcagCawxA0FG81ryra7I6AyzI/9WZjPe+IUuhPxyNf0AiFevCVdvI9++
I/0Wo59/K9PtM5QQaeuXqiZyYUp4uYF0fyvB0A0mSJJV7YnYWwsOgZBJNAah
8Gs/QBY+bibfHU9m+pXNuIApLAHyxoEuA/TjpAPdaEGNRJTe0YE4TN+rKzHG
92DQiINIi92IN04g/XaagqeTD2cIIVeR9y4i7W0kUzpMiyF0CIbdRgvDDmnd
RLpbFu348DrS/8mVLpddM/7FDKXNpD3Goy6M0JtQ5liU43lu3+/+Lkww5amR
HRAMJWeAiaJmVtIW0saFpK9OMZVPVmjZsqxbqp5wau/1Sae3kPZ0Vdrxhbsr
pD/WhZAdUWOMSs7lp5iUP+VZfE+W6qnwi9Juzn4hnFQNDMN75YTq3kAppHkD
Azyz9yDEGCebmf/nm970vk98+tN/GN4M7ZZqpEu7Pd+uvQea0vemolqoNQBu
OzcAvPMGSp1SawDPcgSSMSh/LhiVm/uJmREccntHzz33mVcf//SXDt9/qJiQ
P3tf+vL2mS/tK2YWfm3rB4uJhcMXPFr0vv7yZe8vW53BTzEhf04eHD366BOj
csuvP3/v5Q/9XbTw9OGffaGYePTwwYVi8P7D/+A7Rg9+ZDinxpeDockB9lsY
vMPlz85iz2d7rq1jGTp8G98bUxSSkbxwjBmDxsrVQX6KSfmTEDcVflHO6Ro1
5QJdNTAM79URbWmgXOPyBvp4hnUMSgSqv1ctY1Bsz0HVKLHy96WblGf5eyAn
fa/aetcaAKOdGwDUeQOl1ZQ3sBrP7L1/NbPr+wszFxx9eWbH4pGZ6SPfmTnt
T4/ObFj4N4sX3zKJYSybXSy2jGaKw/gp91L4szd6qngMv5U3hvoentl7A/lz
8nszq7/+vy1c8uOYOZgrj42eegozcMeotAt6xzDKWNdM6+Pv0esydewjhG/j
e4Px2ksGbFANbOTvnC7z5GfjyvIqdrFi8imzMFBkncUbe8m3Ic9ssHP00kv7
RocOAfXnR3v2vDQq7dkwUv2jow0bTKs9O3r44Qm81BfNOJCRcVpTlk9tExoU
b9kP2i/k46L31Oixx9Ce62dwZDQ9jWfQmA+Pnn1Wejg5auyXzZlXTFR2Nmaf
mMdhi9A3O2LmvA//GSA+twt+PxOewdQ289v6gIUKQ0/eYDt3ZpeoJ316dOTI
7tELLximL4927CjXVDQ8aZgeGu3bh9/vGT3/PPjFN6r3hhgTPMPvgTveXxxh
zyjDguaeG+3di0mCV9Vkw2ibWWpcQCJgb8sbMxlSxa3/ujNSH4vLwEt5H0Au
9sEyNo4j6AVrcVXSR/mzZbS4CETA+Quj3buBVkmJaI9XR1NTJiWPjg4eBEJT
o1dfDW4LEUs8BrB4LXw1sK8gd/aF7TIwvvm4wxMUt0q6D4ZsYymTqdsJLoUB
q3IJTW0DbcawF2jz7NVcioBrfUVI7IPleambDLRg0h36s+1FOU0VwQHQBKpA
F/IpMhc2Gn0IEuCDYGE+hk96gM7kzDZ2pm5k167qBhxFx+gbCQenRSENMHbW
cQoljIhyToZnGsyB1EWv1ARR8qcQiE4jUAaCB5A+WHyYc5hkQsdEmHQl+8XB
g2/ZA+kEbmHj28dfgbR9MlFpTiCJX20YHT26vnnsIYAx5nlqM8Erg9wNcUl6
AZKeS35cMZiD+IrAMmYQUMA8BMsqXFDo6B6CJZMMn75TPpnMk7uAGhQ9hFGF
swdFaXDp0UJRaTmZcNhEd8HWxsFcIbzeFify0XzgEt2qKywkCIyBGdNbwAhY
RWDKN9HvHjLW/RRi6DKI0gSB6DgyGZk62bVcOLany8X0xZ/6NmB5WyVBue6E
2ykqAXUuwE6AAlkYXXCBzSXoZOMFiLF47e1kZPUohUcGDaI5TDZMXYMlce0x
1b5zpWAp7jkMWIIaHUL1+ACA9enQsHmjaPSgbfFMrJ5VpMf7KrbB5kjtaVgE
WNWAoC0G8ODmowJXUYx5/VgXFs+usI+TQc0s89aaeL2r4gurCuNL9tPHkW40
zRbSDElwEtIDn4IH3ljVPAcBb1QGnWLdbJJfV3UQG7uzmtBYFj1j+DuYleXT
Kj0slXXPjKDQxyQAgjxDjtED2ocSEWURmB/66WY+R3i615Nmb6c4CDmM+7+r
iqTsDTNIVFc2hGLsryX6qguneC+IySTQBHIQXfSAGYx/i0Kbah5mcUq1tZ+7
XgHD5Xg20d03F90ZIeFs0uaqVzMYJpFLNuyWksLy2JkB9+7QD4CH/L/8lxtk
Xh/9L6vWZaD0bfgx7BBR1lzuOgcuO7tMiQfDM4sRy790wCAQWKRN58AcBK0i
mmwgpkj7H1DlXb5XilaxsHDCGX7wpS1Nn4GBFKMv2wmTl3dhKORz9qH4bL6A
uTsCHZi20JsmhPgvzDcR8g2kTzud58Ya3f2EsqWvQiwAjzUJrRGyaJYiN4+d
QpZ2VXjk+61oc4hiIN8GG28SBPn1AgZaHLuTM57KsQNNPxlEGEsN1DE+gw7A
v7uFMlgc+IpKhfn8H8gzhmUV+SSsNkNbFowFWxYy61QoCA79AT4BycaxbFzW
xFn+aqT0vKhuRtEl2MkAOCvtvBLLYuglTrywMzMzGEJ2xOyaMEqY5RAVrxKh
dWRxOZ10H5LWhhhF2FWmnaCZ0JaiiXUaWyExx5TV8W2d+yoptCxCk8Ikg/Ad
lXoH7baQYRyixJ1J2v+pMGb4DvQb/+IvChphAN+MN6ZkgT53uQzdG8CD2PnV
FGIJ8QxhnyGwh0YwPjCtYb1vJy3+dCATUilbRn1dlEmwa1fDJvSJfegtJv+5
ifum5XL1Xp0t5S4SC4T1A8WBoXtHxZWhbGSKj5W0eBFRK8EZMsBgQn2OdEmE
EJoHExMsxtqCoPQf23dZUf1v//yyuWS2S8jzHcAZ6OedxPca2IZ9A4uLZUsx
KzWHogrOig9Utr2qa9ygD30qH34OlT9Txbuf3b6S7IcsMAR/jtpmx4xDCMPb
w6/99PII5G4a56tLera0orZc0yoBoQ+BgGDYTFZAIPFeOkEwCF9ReQiaTtI2
zW/gl5rdilepJ72eMkCmCaNrSM+7CHBXVSJhKxZWKzHitGw5YnNe60AnAIGz
VhKBoBoReTvsF1v0BT10WkY6xm17taLAHrMVBfoBqydL0WNmR5golflbN2cS
3YEFTxZnRQfU+TGDAx6InbmS6JzDNSV0FnTXNjKwof/ownr4l979pK3VGGis
CzS5IocIbV3SKDh9mFhAHjIJe6BfTe2YwO9WqjMq5mIoadmohGdyAMCrLFni
WVpHeDaY+de3lsZ85YyQZfsS0ic7xZ9DDSlhOTc6r6DFbV5husq80sMqGDmf
XoKRhWv/ncvFI/g/BrChcpWqrmdZVUAHmj36g3XrbCNzKemCpTjeWU0IU80w
H8Tq031kvoJI97cul6c3VVj53HiTpxsrzYgJapoRVhCWj8tJLyzp8a4gzJAE
WwIwx5Ujb8vhR3abt4zBEYL/McJ6VjVDfDYWNCz0htYgwbyy+QqNJt6oNxPh
W026nQ3swEqyuYkdsbKDAanNl9yDH3N1uUMmOIH7NiRQgFCEN1SriW2/wYQo
m/xsE8SJEf8JQkmYMX20a5skeJqUIQiCV4vCEMvGPifS3zJm6t+GxMVg7fXV
UuPFDH+H6F1ARIp5RHPWnOsczZiiQLNdWPPddQrv/f3QKES7ZvRfQ97vFfWh
+FnSuXP/27BDO7TxcHMXeoOLbwBsavusmQ70At+fIjwEa7FvbYJm0N5rofem
LvSGagVTEHebu1C24ul2/TOoWTafejXipzt2VWytHYsFiY9pgHb8dI1n6sMQ
Z/UEgfwyAjmLlfwPyrn/tuR/fRtrPWNNRkUDpeMbWbsjFgswU2SSq/Lyo2fe
CTo87BQzY/NsAsetpD0tcAMLn/CdnLs6ebl8X0hoCQ5YyXaF8epNfNsxgg6j
Kw79tY2aIO2T+ZxZhDu4ynswSQx7M7eWbUUnmQzMtN1YZ162vfDcX1dXl889
VxQbbnrqGzS7PWcU7TNdrYzCSImMLjtavoWguzaKTGVIMWM2SNwwZx5bXCx/
zCYIrr2h7YZEHf/bmcgvg4V5EfO5g6Y1O8LmveRdLTsonsNS6cwUljCTxBrz
vi6DgPkagkxOei8K5qpoefwGfO4mJF1P2go8JysnDJtTl8s2O/d8HGE7wCNm
td+mGdvbdDKjGTdEgazoKTE32q2EEHbQ1zFrpg4USZUefCTq4o3HOO8TZtlZ
gyD6A+9+wviLq52dawgKS1y+NdfZBtI+O8nPTMIzyHs/Rp6pibXlX95XlOtA
8er3BxJ/VRMLjiNzm8gpWrBx/GuJITAJC/XA72GhRuQElAVU/PgHoZOULVtg
oUc2kqbZZqELfHgvh6+yssWU2rGjVFtHh2uwkZA5qzYTMPMbMjlud/Vy8RoS
/oP+STbIGDRZ2a+pptbIeZk2kWbOJ89Y/JINASsZ4+K/mI4m2hL9UGwwJ/0K
ITvgq5aLTbjDcYCAoMdBqhNcrR2WRpcpRPxXjLA7SPtaZQWuJ7wLI6Vwk8Ib
wRK7uHK5RIeREMvaO1ckMScQ3ceEtO0pVi+2fXon6U6LnJlfRvKBlAfQ7LsT
jHaNwUOSIcC835b7XDbswZIc4itUtrI0OO8mgcSwAg6MT5Zf+dFAGMYXNhaa
hU5V9r1rD/Ina8MVXdh/K6FpjerwUj/VhJlVrQn6LbpQp6Ye/IrZbKBVdD+b
52w9zJUc2p8iNIa4nHg6AC/6wURU9e9dYFgrO0HR7J3gOo/5/XS53PJ//dEf
2fKHMIHoiLs7sOv0d0JHYLcHiRqZKdyvaPMmmWz4eGKI9J2fHqzStQf+eDtg
k+WR+QHX1ScyNAs7h3AC+fxAeGYWrPgplBsoeR/YkGyRSyPxLcPHTkUGC2Xg
4/Zxemg4Cw5Em6RwBN5Dmg7+IDHIwC4WHayISjKcBrV1Svc446cf5I6CaufJ
HOyJ4oudK2um7EEzJsp7SXe3k+6uJM90/mKttbVGbZ1knY5GlQrx+EYVc5Rc
wmVDvDXKqykc5HFj43lvB17RdM4rnukW0PZuIp6B177fBECqGJt5wgvge2MX
1m0d9MN8EVdAkiQUom7i1LfMJJwImJoKfDAImGf8dNLtleTZMJ0FmDBuFmC1
8NFPGZypDvAA8U7whJTevjejoecVBYRWzPsgOQt4WpJ/XwcUQEJeZgzIaC40
1MJIfZQm9H7Sg20x5icJu6sJkqd2YZfFRNSbiUmPiWC6TDP3MTl9HON+0upb
CDksqUs34TatJENM54DXptgXMq6XvX9aF58dERvODbyZU2bz7yNNvouwp6nN
mCb4NDUVBvnWHkEs03Yrw9LuVBtjSw9hfYB8zjxJWt7Uln7JOxxUCtGMUUsd
tR3oytCuVxSYTxNqBjieS+hkoVF23uUR8m0wrlcBGoxwdBFlBrWMjSaoSWGO
THOu5Omj6FfHrIe8nEd46cIzaM8TA/CM1cJsPl4nXoyRmX4emypPu++9NLDW
+xV3x55FoG7/JHh1SOlmWoVlCjB5YEkT7OwbK6ysmzJLg5XgL57gHd2SQzGb
0RDnyFuXC0JeG7GyzoYemKf+9IJIONsxXUG6Y0eyLiHPmJtY4/eYN5g/Yp3p
cm1RbMwX8L5s1lXNw/KIaeRs5dhYh0Nc1DoubNfE4JgLz0zzyAKkajme28XP
svlRfLz3A+YES//ViJOPPYOlN5GRZVXWdjazZyMmh2Nqm7YVLn3ea/81i8mF
OFjfm54QqMvqgMDm2p4B4iqxJa3+enhmTjwZ21rm/7HVSB//2mMWkgsugb53
r0DHEvaxPNtMr9cUSlu9OYPJBzqJLGEmwXARGanBNF4B9qXvFmblfrVqop8q
UKli817KsfhQB74hHifqs9kd4dHaO16MNYo8FixNRcm3fZqI0WWN+KzQlb7N
+NRmiULjNSGgYTcKsMs6mHphKaybMgiLHbM1CAEXq2s4SNWQLBxLQPjaX6zL
IA7O/L73NWAmEoihVd5L2O8CcVNtaQsKv/jii/FbVklLFw9btMQe0f3u1X/w
B//5Vz74wb+Wf9WMsPHq5a/M1bbSvhTND6atmEq1+X1JHWGsffcR7llh4O3k
PVZg2qonlII4sq22eg+w3P/Fxo13ltvsl0OSyMrW6B/rylgmm4GfxOmMnYpu
DhIj6CPk83e2CJyHTSGy8IdsksJ7ffX/YhN7GJGWZvl6fe5dZSgFp0vfB4ZA
tqJkuy0o8yLfapFif9L0deQ9tnWYJO+xYLcu1rbVkiCZIgxUDWGQvQTCr/nN
pwxhzfP2oSx4N6T4re6ao08FPxel0MvOkp20PZFAyobjWl1S7L1zXR6eHSYl
N72xxDDWF8wLuLfcgdL+791222fFL6FzbkfjsLw+F5E2D0vfbz6wjOmIJLUK
2Ygw9NnaM1M9i91fQUZTfQV5NuFm0iTbzOgcgX8RJCILx87y3fmP//Ff/GBi
4mvmE5VAwGt+BUPbO8ymD8MxacPhfWggWmJDeiQqyTxjALFg0c4Mc+DLPPss
tUs3x2bxh0KDAVz4tr5z2ml/6v07dXBX9rqF5ptpsg21lGFTgU5255pHab5P
WdaZD4VV4mW1YlmuBjuuxTS+2s62XXBhaSlk+LVrrvmBBTCs5Ov2HN9m5wKc
saP/uHnzX3nzVAWpb7MFA4rBZRZQFwjwHlscmY9pikDFNK7CAjhGtgBn/m+J
NjF9ddaY+Hx/OPy/DR9ZijS8hQgL9h+okbBhQ5GmhnkGrifts9yf3EENRplz
lR1JUkCw3CDOZepqlMXaTUbCJqIbCP39X/jCP5eIbBG8TYH/ISwOLG3ob/rw
PZG+PP0XsLyneTom7zF9pVTk+YosKqiq03w0UhVDq1X4mDOY6ATA2RWCf37i
iZcChIhg0BJykNUii7H+YEkq2/t3QcHFsZJnLPyn7Nr+QzR+2Ln1fXIFVotO
Qh/YNc8RcmiOYNFXfxp0APJDIPNAdhsZK5Yuwnzg15NnbybPlEMruydWFBlQ
zO9OHIadnd80bvjPa9d+UhZ9Vfu2VREj4eOkDWaEq2fU4l2SQp+NhAnOmd3p
7Psz5OD3wnQ1EFv/5zqQCGFh13SpxoEfDO3BdDCyc3g7kR1cE31vnoB9JdsW
FHHYPO4+N3JYvtVHCCvs0IHm2FtZSvlXwwhMp58LCUsz5fOMAI76F9HKzp0h
aRdRWklmzJkD0XubiWZnyxKG9T2zSFxVrr4/v4hxWhZzUuDI7pUxB/KGf7FP
0pGRT4vY7y2EgfNdk8ZEzqhf/0lNPDQ9MldDL5JTZSC5FF5v6sicFW5rF1Ay
RvdW8jEyv2vuvwal6wiXbH85JH3cQ7hk+eNqbWPZEP84/qXe/SQarImBPpcW
fz+9y1Rkuyhdk8zTJ4jfRmhmVbXYRQIMg/2kX3Z0jxUJ257SJ1OpBRfv+sMc
XxYuVf5/DzIxMoN/H8GFGW1so7GN8MYyGJnBxw6j5TKJ9xQrS+oO5YwJVgO+
kkxTrISNXYQCze6HgYPlH5KL0TlAmLetcpYGkRDP0h6ZijiRPFONBVPAqp+1
Me6LH8Luk7HpWIEtSWM6R7ViyTbYt2TmfH0Cu+saYUlZniDsMQuYHezT6k7Q
Z9HgL38MAnU1efcu9i7bukyR5iIV0TgS9ZlbFE59kgQKXoQj9yOjDWXNzgpK
/YE6az6ZDVUROrF2emTtSHzWJ+wqBEaCGFofbdaUSR95OROWG+Kdw769EKQd
WvKezGrHum6PoeywFMq2thPf0yq85TIPjYmgH3zajPWzU8Ui7pxPkyZzF19T
BIAdnAxm9TCxO+tsJqM0Dpv5gsnYVAsbeyfYi5Ye3YVTHwJu8+nEHFq6DA/x
DJm/L397s6SyW8ZTp9P+YYlJjKLovWTsstMh7NiCjpaZSWJpfob0z5y5dxCc
turcZ+71rUpZ+buDB0PJFkjEm7vz3/flLmC/Djqw7l0o/pka3uY8EJ/S5QQi
dg/Phwgcp1TsxT7K36tEPPznTz4ZER6H5Xw3w1hmPnDmNbI40eill7Ce2cmw
nGtQzrjeR9BhsVNl2UJUkg3aieXTlL4Qx4pr+JCwHJysSaI3Fo4rCDlXN8t9
K3vVmd7U+hiHFZ8IDrbU6WFOe1H4TGew5ABG8wOEX6F5AjuNTpSG7uNaYdY1
M2qVAlsrxHBmy9+9hCp24nM36eP+8MyKEcu/1MpAbk+s7X3KGLz5BQIb6Jy3
Sh3UFgjm9drf2NPSmbLKnm3txYWoJUzAns12ULx1DA7tO6REYFFgOTi6zFoi
qhxN/MUOrDQltr4/lQaxEZUVkGDCBOOjEyt6It2uj8IPpo9uFMybBPL1zkJu
h9WrhLVPrcqQ6Vt84XMLP/nrKKui3HhXEIyUTqKn3PiDCDBhz62LGRZBvYQx
aQE/nkjmAc/dDRgrpjvsTDHccYd3Py27JpV43x6MRI2hxPxZ/GzpznHP7BO5
X/G8VOacozTl48AS/De5xO2eRz/o7yXP1FKFx+7rhy/7Gcf/pG8PcuvP3nfT
MmrYeBcqjBMmfIN0zsh6wixmttNm20fmRNeqTnC7Lh7esld4Xa1j7d7D3NKx
TizvzWOw7PebaESHNjmozNL8XJEpf1iRpY2zzTC78ZNlIqp1L6vt4XL6AQl3
PMkvCcznN0GRkG7V2PMuKcRSdSgTS4VV3WdxT/WaJSf6Zgh2jPncg1dlxCTi
XVMpKmay7y0B+vrMZd8zgLwKh5uYOQSXOu6qKPnlF5H3Lii5Gi+wI+0KJTvu
liD39g6IMJ/mhY+/SI9yKioS3SlRwZ1zdprYBB7IwBTRSgK03v7SwFgyrq3a
DJi1hGEFy6Jz4jFhCcl3kWfZ6i5ksYrzJxDx8e3gXXYFMKuQxc4LX+00YQky
LvUzkP0uD3/vtPpoNXnv/4OGW0MgVd8cIn4j84szFyUris+yIhikZ2eCsdRu
lMUhmOZk8np1NU9yKCGjHo5xoPQnCmAYMChND6o5Y+cW2SW6rLwLS59wZ4wi
VSyqwlwSbNMbJtUw+dbRwBywbKVVoCT4frTY8KsLH3jWghp2NFPuPuyE8OaU
ppfWTifWezPSPUu7a6zaxqzEbYSEPCCD4dipQpsvGWg/7OmitThSP54W+PM5
7zBzOxkRm6vupouqhqnUa2OFrqzoofoVZCfAnFr58S1Ww6kq/pXSlGcfNbk5
d5Jn96UQvfpqb4jhUoi8AxtwdYJIAzGPPv74434qtqCTnE9lmoYdbnsr4ea0
Dujg29+ovrVLNG2+miktYeZx+LUZZYFf5TepALiFaHEWsWNb1xsyPpxNlpDD
Rp4tcI9V2Av/1QRLLAawclJ3GHCT615gKKmLmq1jeZemat9PyDmzXeUxTlnE
gp2cZMXbNc8JnMsdVY57b/phAnTiXlWdpF210aeqOzmidz+h+cwWtcbcUiw9
n+WgsKWDOU8cPjF2p/h4ZwfW2074ML+SroZ2SEqutr27WcppbQUSxkn6Zfnx
LH2F6UalBS7DiEGmJUTKOwHAprRGaJJjTTkA1daTz43y7+xKXVaIMdTR7dly
7PlJzIFO/Og2z8Lt4lfNab/oEy/avR7UJi//zmzIadJdHpvGe58Nz+Ackuuw
K36StR3yeuIYLIEVsNQ4HGFFSRwT+DuzTrqwgvdaWPFrMFRTJ1bUykpO3FjS
kyebiQkzMdgZR+Zt/1AzH1hIvLk0Dh+2axQDgVmLHyDfXkNwVvr+5PD2/ZG+
sCOcNHe0HOvBE9/+8WPouCQlQzPNLW9HInZsP8YYYE5HdqlMuFGt92eHt96b
M+VjORKGqDkil2LqxGpCYesP3zAaUmFPrDnlFRYFVnvJhGVB3bMJDyw+wfQ0
s5M/RoQu8D+0y/kwieI1ZmW/G8dgPTfsGOsb02F2xWRS8p8h3Xg/p2Mrt9nw
OeOUFx6RLjZVM8+7xTY0M5CMnVnOc3srrA8SBpjtkeV4NtZwOJ28dzvh8uzI
VMuAbaprTMgt4/d4MmD54RaW584CGHjGvJnbCYnMHmE3l2tGaUXLjvr88XQq
Zr+3cNunRo/qKLE1c00Xwd9UzXlvCLfgmMgNs9feRmhmgSDmA2U4MnvSLpz0
E8kVimlLV3TePbvJXQeg/h47PDQOrFZNyPQJg1WfWVlAWb/Z1c7MC5qX9fTe
TOKRZQ6qJS3XlnIszM2XbCOYXrRN8BedqlndBdMTKhXnd+7HN2Nq5p3YEnnR
LB+fI1uVpGt22R9TZ2yDfxXBhR0tYLI2Di5+r4alm+Gi61liK95J+DiF0Mdi
mSd2wAp85Fjh2V2VOolOCVbAadUYGPjjBwihnVnJAb6kTienDxL6bqyeSVe+
CBlb1vwzxTQ6nBxWidugk1mmvPmcaeRiqMPattSyK2MydA2hj5lqAYPJyC8L
yLHzpCzK8lHyTLfsWDrkyI2TectgEHv8hO6Y9HyEyvwElrwkezo2IXPvmlt3
SIRymPTrvmFYM32SY+FzpSzG7obZZ3NA1XUyX5WWJDcgkw/B/H0EDlbARcum
1/Id8B3LNWW6gc0z1v+qCgvZMjksvFUCke+ERehX0pXsW0wdhcNyqF01zpRE
RvYHCdmbSNcsHn5GNa1ie/m00q2vnD06Ukz/zqF3/VOzIBCQ9hptHAjyJALV
VEkxLOYyZ275J0g31xFYmEVyUgZBrlnwb+a2VkmT9HMLHBK7H6yNA4vPecKi
qbBYBleyP1gqevdxQjYrYMEMCBbTtZhTFrD3vuCkDVYNkp1lshutNJz9b2fO
/wuD0oekMeHGgdIn2EBZKZRY8+IB2WsJOczV1gU2Jp3+SJeHLa9G7EPhSx1n
0vYkDbKE6xszF/2nIj82Vh2tqfm7xoCwl/iiVI8nCUq65bbkP7HZmKJhNSGY
+2WC0MJEhp2oCCI4TNpzv2f6lCkYdriKxdonnM4uh+GlmZ2v1obBSXwSz2sY
A6l75QnUpcvXr7RhSExnHYbEgc8UIEsDfHMHyKtltz0nit3kYEUrGwJqTJlp
Njmsj+8fHt4kuWfssB+TenfuJ0puJ7hLWjZwpcMQVyPJliuJGbFTT+cRdNlm
+cQW4S0pC7K9qqZ6WViOha50PoPMLK8xHSxFzwdem9CreKrSmZKlD9ZBC3S2
pPlrhxOamV+AXXHw5vZ5zwq0v6dZdWNbFNNcWVKl5jv7HQ+2TZ12S4qS3wnC
M9yCUrJasVLKLPmPocQugnmIsKcqBxz83uHbPiswqAPaB6RB9jgse7sGfnvG
stoQdspdjrqxIAtTGcyfye6+CN/yfVP5++BjGiSfmIizNSykT8bk948f/YVf
wWF8Bcwn4yH1hAMmeCnstsGSPeOmZoxspyA3sDOtzlY7dkinDY/y9yzhha3H
7PZFlm6n6aaWwy3nKE6qqw4Atz5io2DpXT3F4uJCMT83V8zNzhaz5X/nFxaT
4gqZJNs2HCtCG6SY+DEFg/kSWMoCOzDHzGmWa+6GKPpwmH+U+T2ZXciuemS2
p54csmM0YiywUIJdNu32qghh1YQ4iFC5cpTjMjdb1RabxfjsD/+enV98S/MQ
2bEHKanFhkiXJXNDy/0fLKl6G2E3T4LHe5dk0OMZO2PMcjFZdWeF2bw7Uo2B
RRUUUqwXfvtfg9Qi+7Ea4dx8sbCYFizVioTMfJP29HyCZATaL3SNS3LBplLa
xQ3J3Ch3kWfsDoAvN4th4mZmbpleE+HrOUIKBa3xGMpxMniqSzUPx9MbuvlK
KvP9T+Rb5pxke9/PE+50cmM5F4co/rW5M8dVLXRUuszqo6MmYotAXJSqXTG5
unDnzvomz36WcKy7fauwJe4ynT9JllJN2NMi71kVVVfWkykQV1ATfkSZeA8S
4q4m37LYEbubjYVF2TmxUwnICoBdsyebv04ATBiJ5WxcmJ8LilRHmAFxYSW/
0eHOCGdGDFs4GGAsv5c5MpiB8HYCrMaFk4WIAcb6nWoHMaw6vfjnbDE3vyDg
MUshK7olVkkOHvNi4BnLXGLnSc7sACjaexNpj632zEJhB2kDbwN/JjjWflE6
LbFETh0ymprBFr1TSuwC7lzAn6VGjvcxxE0HAxvh7ThlWUiP3TnD1nIGLNsh
XEaeMWcyy0KVfuVYeFiiWhFknU82IrgwJ8oN/2Kr6VtUULINCdYQBE2eIH2d
QZq5m7zH/I1hwORyl9GoXm2EsduizqpYYhfWSqB9MZd/SD5hVRRCKHRotqHU
IhyX5LDcrCrSm1Py2sVhGWIybWkSuATXnlUh1SoLz7JpFHLz14nN1cZvvPph
1xw11bXMaKJJx8VAiTMI+sLwZDSuqp+qgDbTpUpeosAVClZ3I4lC30hYY8nj
LKHoIkILi/6yQnbMVGf3BQZ30NAyN6yfDGaEbWBbijTUYZ6qwej/PbcwMtvH
W/lsyReq1XSUC2vtF8y3oo1acoXsoG4ibDOnIEsU7gI33rOiVUslC7HzEgo3
dF0UEQd3rfhPE7RVwfC0OH+wtNaTZ+zyJZu7K1FeW08w+BOG2AeyeZLV6ZWp
fTMBkLk5t5JnzDFksj56ZVTs2j8qXokQ9CPZ8+XzZ+ZHbNfG6vWx6udhEWh0
1KrlYb40OZTEqtXVEk2XN6XYuIelu712feP9U0vcNaVjngcXWsbcfL/yr58j
EyTYilPFM7vK1naFcSufaFgj9DI/GrXcbJg8Y1WmmXtZB8oq+EpZpomo+0ao
/tEwUP18oCbIwFSTL45fVBn164jY1Q/D5OoH93t2MwQL7Y4xVvq5bbzkYOUn
yCQ5S8XmlWe0RYzXK2Gs8O9dz8SLZvIMbFYlnDkjWT4uOwKvKsDO30ho4fyl
xyq/J6b6kfEwzUCHqPFSnvBe46U8zXdykUNg8VQKHyLLsZaNOTMNDtrMfkUK
1Gmr1RA988qInoXNx4c5Y5sC3urFTOrb1sbitCWhZffMeGjJPTNLQps75Fug
NUNWqikwM+Cz2bNzd2Geo+3QtWkvdpiWbQ5Zeoo/ym/rR+32yONMwS4uiF8F
DutS6ta1IbwCN/mIEH3V0TGlqjv4d+YlmBEd53PzEtQoleFrTVe3kW+5cynJ
BlHNbbUqJRuETQSWJsH6YJk4URrmq0nakz8HcaLaT2mv0IMTrFSh2kBm24tS
rElP30atXFIWF8pRmnMhjlmEohbg/9jYNmqv23xlIdEp7dFxbl4vqEfmCWSJ
FywuzlwM1t4Ig7Ur/EyUvOAZ/m7aVZ5NyKNe2We122S5RKzkoo6euUXkX2r9
tu9645WqJexx51+OpLgLF0cnZGue2JbVcLz261s+qFn1CzDva4Azb2R+HsId
bTJrRHpmZZzW6pKYx8OZ19H3eTl5xrJ11Gdufh9Jb9Rn7T5zv0Nb0KR1y09M
DZTXy1jMR0rLMRgEWN0RXmbF5pmDm/kkmN/DXKKYYk0jWRmC7XmuTFJY8QDW
vo5aUom600hayEXCxwjrlyufJo0UlT9ORvF12J7lo6gTKiliyuriM7c52ysz
W7Hl7LnZokIqi8quVZlnOblsq89KvVm02T+b3y/2GbyCNuer9YMlBlLPA/LN
YsCX3Vav31qCo7ixGhMMsOJagkGVXBBDO3FD727ztTvR2H1p/ZbftThtGiQk
8T+zewHYsSp2ipilgLDTiNXJVtSJnhdSWZIXO0IxbFAGdsLWG2Qk/pIYeApV
4qKRYR0jqn1cObZz5Zjq2IZsh6iPY/xTbGMZa5ZW2T4+iW+clR+3tJ3K1/7F
GGTzGJyqo5nNFvwP5Fzg1L57hV07P2yZu2r4JD4WhrTmyeeexNocqryXGZZR
2IdFsGrTcSixPmdsrC3YKEY0u76Ppc5vI2OyPpdTJ6uvaI0zFhNkHkm2eLKK
PMoDNgIx8bIFeZ8eBR9Rg6Via1nUVvG+dlVqMB1bkM6zsJRKWBSSe4x/XUlk
jB1dYeeiT1P5iCi6c94102HvF317Qu5FpE1Wg4/FElgZbN05JOvusHkUckHs
lJra6uUbej+HV3j7O+jYSo/XToGzM0hmiBp47nUQfCvBlrn2WRVnnQlJakML
jt0yVpeNo4/vfkClqiml3VtBS+1HWcWEbL0VijXGarkHvroEQ2PJhOdxU1K7
I+WLnH+IcMcO9q5rRiahQqvOQaijy3qyGQV/0BGUr2QCqALiEyKRKa5HPD0g
Nmb0cjh2+o1NtAua0bCVVmZICxq+kg2OVq107qaP6iam0wl1TLCnFO3PLgNg
NqNWvE/W0yrylnzOil2w+Px15BlzrqtZm1xPqTAnV9jp3tKfNK6fQDmW7M8l
wuYJwBA4yYHJAfbbNpZT4w1ptjVk6DYndqTfsjOGzfXda0a+nbmWJVWNLsuR
Fx9ZDe3xMk+rg9meQAWLpIVEwC3wK04gli/ITuGxXdWbOoALMFgNKxa8YPm9
TP9qrSf/zCpsIil0G4GgBesuybB1rJ1g4ugbOpKDDxnWZg9IKVw2rR8kGDJ/
AkuYZakz0+Q95kxQF1Ry7Glbk0rc0AW9pTNp+wmXr8QKelYgR2aFAmjpXObn
kktIcgCb8jPZibZrOgCN9i4gz9ipEk1zTA5RBclb+jD1WDm0QrJOK+xOpDIT
SrupyYkFO2YvMN8yi/WxhEyWgsBQY6qApSIzMzm/XtJFiWykxXGgSPpbluJ2
Y4IhuYwEWaUFC3s8j8Q8rmwduIDwxuJALEP5rBb1zbZy+SW3LjYTKzjgX4qZ
31pAVpqlb4mUWMUnifW01f3w9LELd5v49o4E3+4t5Jmm0yRxDPV6+pOPmIGt
y6u1x/hmBi1zHavhZzm84qRjh9pZHc4zuUJkKyAL7Oq5EAuiSm63an5fjaFe
RudYE3DZUsKy5hWbxNRg15LmKVOV9m48Osr2oCyeylTh/eGZmWayI1P/a7IH
0UXFVnZekqhYmURetrIzk1fVi2XX+P0TVU1LmbdskWSVRNqGw/lZljrOxyol
hWL0iYvX9uMwmFpGpl6p4bXJ/VVPoW1aZW1iAsisBuYSZLFZdnbUShtmG0iW
0MF0BouIrcnUr1M71KMZxr09JB0WhaRqeTzeexwZPVKWCWq78wC2Zxi3DKAZ
F3ICgIksW9C3E7TZCFhB18x7zhxoTH9uI2Sz8qJXZQPCIsvMIf9WJa+kw5c/
bRkfXzMqVpd4bSaYGlfw8MRTHTrH4a74Vwd3/bZ0uJ+AySaOjMUEHrE5wO6L
YP6bFrONRpHY+qMSlSQ6tWCelzmrY77spN6WQ/tJHfiwYop79HvTq/8fCSg7
BD5JQDmXNM0WL3ZfMbsmS0lN6hytJaBVNZJehY1bPTum1Fpm8WiKBK7ztuGp
6moIVn89Pfld8Q465nKswC/DiqWqanmbpMgQw4AXgubkU+kKbor/Ot3/D/HY
B+g4QGhiEbP/MTxLak+u60Knl9F5bNoWq0w3i0PPN4TplJ+8Ip47ivM302/4
thh2B4m8bm3mwywPKQqofLSn2UePh51e0Zw25ElN2u/gDZmbTQztFr7yuzaU
r7OPfOuvR9PFEZkPs4QvltXJeGX79Kd1LvmKgFfmvMYkDonAzEZeEYHptfyO
JRAor3nBNOX1qiN/+B/Aq+QV30boZbYW23ufQrpmBrPtC/3hP3Z8mz3ToxxJ
UOMy8l7tmsbgRFlVk4+5+Sr3xmSpZd20ih5S7LMLgPGUbQbWjg5gsXo3Tce1
2TPtI6kdnoNVWCUzD1bMLnJJKpa8wnS2gmN+RVncFJy9R557CeDI4QRWYTvf
ArEQj4sE0N0xOwe21JFr9oxJq9LXevNANUvGvvVRrZG86pYietOr//xro5eK
nYLeT5KhY8YUQ4qdsjqViAcTN9VrWMZQ4Asqs9sVNspbHnu3MiXqU6JVCYAo
m9fszAQ7CsTUIKvFdgP59pR0xGVas7Pves/hsq7CUWi8vxVBeYXGohiSHcUK
NrBZzEpHznSAAd8+UIlCLN0e7O/a7RycPelCmfLrDAKRG1OdLUyxcWSFDJh/
mDHFZiSb4aySxLXpeMuaf1bFind9bIq8Ll0Xul6pMcNgD6GFeXJYMuUJHTBg
+sHVjEneuzbVBb5me5LXSvLjILed1IHWl84t++M7QAMSWQVxBgMLl7SEWpL3
ribKXvtITGxywyWm/jgw+FqJMSMpg+EOQiLTWBtJN+wq1E+moywav5m9dLPa
6apGcitCzB3MeGNFnNlFa/kBeq+1iWWYDN0mwpu7BNfP7E7saXuJM5TxxiqV
spSvLvw2JdIHF3PNCcZsvhYYvOcJE3kcGBLxUBg+duTv/A7MPQpDU34XM7tY
IgnLNWYGUM37vveLJh626ZRsdk1PS3BxNIQ9XmKaQbDHgCj5FjGyDQSl9xCu
8rBtU2rNpeRblrGq3yZbzpNauC/70x2uhWQkV6DTPcab6pIFC1BZf+TI5/9J
ZP3nCaksW4jpNxYl/lR4llz+GdgcJGziB33qCPssvc4XYpNC7vi2wYtv2yAx
dh8ipLNNdhe28d47mtszZ5E4nDYTPRDmT7IawdfTCQK1OM3QERHJ+VenebIN
zPlnpWqaEhqOJ3Swq+SZU3Q3V5nsc90/JNeaKHyJPaTw+SunsLKMAV9NR2j8
z1P+jiP/7N8BPWgtFp5mkXs7hGHvvXFz+O/aO16k5RDPz95XwRWK2ftsx1az
LEvFywI4ZyuF7lt/gbfeauyXaAB88hig5tpHLZrEVcOCCMxeZodqJjO0SvkN
/9sx2+KBqF03LKSz9xltzGBlIZntGbrlt/5+T0XXe3Qx+8dB12+LoPQU3UuP
/PGfR3TZiV1mhrNjNGxG5py++OKLmpWTXBQLcpmN8Uj1qplqIDOYBUnyM+Zg
JzBkZZmQ2r49IBh/oUKElLrR3uI5SUhlxY53qVCwkwLskCKrXZmbleyILZ7d
o3NqdPQoLADEmmAN2AXi7no3uDZP6cK/soSmYtlXvSo13jPn9pbJt0yLsf0r
S28NrMR4jazyOo7YSPmNx7h8xLhMHooGfSx+xvJpNpA+2GljVpKMbV5ZWTF2
f5yVKlJNKjlk59TlG348lhaxaQyskoLHLGz/aPNYtuLSdECT3SOo/JrTSjJW
Gc6n1JUWTBa2qI2DQVItj8UVHyXP1pP2WCwlmG/tySBhF0zTsqHamLJVKLzu
R9SLrUCdboQ7J52Kkhf3u+S9bR2mO5413cXiz64a2/rOlnc++UdImUQODDQa
8wYrFEl0UZNIzHIzx/tWyrZwo8z6E0w1OQcTV3QAoCm0c1J9TP3vWSWzsNBG
0+K55868FuRJBry6OxOLf1V9OmAnf0rkc+nx9qVVqCH4LsJagKV2FZAhs1QM
h9kTTI2dTrpmKVu6Qdjz3V/5FbAii/RpzXD5IAYW+1O7TA+dbjBkpw/dE/tW
JWUn68VVxbz87yYs7yQolu+yWClr8gzSJMuR0n2NmQvmE14CIDsCgonUCaBg
Bgwhi5ZH+9y1Z0YyVkf8Rh8/+At/NVLvPAseMMWfB8zY4ow2ziDvserwrF92
0popdH1mG0rxA2wjaK6JqqrKauU6KYMyjHbfTjxJuOab3/ymujjsfIxl4bLr
nVl8ka3ZOVxVSl7KMrvihq33CqvFAyWXZJpA0yn/RmHI/RkZDNgPwW5g+vQj
hBWmQFjJnDPJt+zaZiYhzAtqzupyGsLcwjqHaXis6GB+eid2ho4dSWVCkp8S
96dU/XsMnbxEsd+rLJW8puraajvK/Dl9uTCoXs69NkGI41kycyPKQs8uOX8f
4Yct6qzaBrsQkCUwsyOsTLGz/aVKma3WssSdcYyY+XUQf88ws/CLWAZXEdqZ
UmC1g9hGaHMHzJoOpjLdze480eRdHDPDbLN98m3dZ5dYYnAHvToxmDTfVZHh
ZAmXUq86x8kfgfPPthIethE6mKwyPNnBGzb32JE/lUFsBMGH3Nd1e3eQovle
2qgX2xyEWlqV4oR/xXtlriY8sKOCzBhiuw1WLoud0mA4sUWQhVyZblTnh+kX
cZcpH7CE4LuUf53efV6KE8k7PeH9KAiYGDA5LvBFQhhTXl1AwnttFbSYBcC8
KPWTfH14M7AWYcXGRAw4xQoWsDjh0JjuAlWYP7LzsTw+/FfvV/UVP/2Glml5
Vrm460aGrYxs08qS21g6KbuO7g7ltAQMg23uET0WbAEbm3OdwAvZYsmpP8ib
DmcS/s4R8/rXP2N5lizy2ezkTpHQtcAGT2JNyrJPWEHApdPUUpZ9iA+63Ex0
9bPJ9u3e8GpCTknuqYRylp7HJgA7WsKOfioSdj2TaMoQzEluio6Xbi/FtdbS
8I4RIKBcJ6dT2W1Rt5Im8+LS0d2YfcvKnWgmFhZkvxPVcfWZJuD2jC4csnVf
1Y1XoRB15dqKZlERxeeBw/aiPzfUZQRkscgvO/Z7eTWnLZyD2aaLfVJrJEyY
JNMKE2BZ4LhTTl5pmh5PTpGzycuOQuZIFKEeFLMNWdXA29J5LhNQ7d/ErtVK
VX63A9V3ZhcYmOZWGYHH1KtA3fsmZ6TZhGamBdswssNQWXtCKjMR70zVsSiD
c5uh8bFnsNIJmtM4rO7m6GixseAes3bZSsAgDEEmuZYW8m8+38DhVJ7jkVN4
FuVOemXuIz024WMnyNdVPq3gj/yL1cVkPgN26pGtByFRL+77bf0OkNRyWTCK
hdYRicYjfqYjfy3DyVwy5HQMtKtOiqRSvk5Q84rLRuCmRj2w5AlbNylYrkny
3kPVSIxszxnQnPQQ5WIQ6ugsJeXMRaOwWOKbLY39ZliSS1/Y9TYXElhKuFjW
RBdY8N6Ph2e4qBJdy4WVLO9ZfbweKkgSE6ROekHrQvglFO0xdJS95HaIx/Gn
nCRlupdd/sb2dCzvJw8J4D1NpjB/hZg0rF5jAClmyeWytL0LMKH/vi2fZnb3
moFJLq29hpC/vwMc1axrPsNcxaviTguDAsXD9jPZeVoYGFTxcE3LYfHFCCEv
LbDYEivZm2yXz0pjsPQd5rWfIiQyrwlbKljakJ7ubQrlsaBD2N5N5VFfs31t
GQg+KtnWf2p29jsGnui2s7sjP/AbYfOBmuJquwtIsiTYgbP1BC5mzbBtLBs6
NiHZMDXXhaeOl1blUPGRzBrMCJgbIwutquL2WyxMgU7469hD8rGWyIlqJvaq
OuGPj9qAnWrZpvPf6D13V4UrW0ly/JnTtHI+12o+s4sRWD3O5rruS/vr2PK7
Xtksn0EUbd0XbcAScXQb5K0YzJEdXYZoR/NwJPct3Z5Bb/WFneuMenCYl8gP
BzsLejahk1mZbyffqja3+IkYBWwDoZh5Ewfi2YBZY9EgLVWYXBLar7RI9CLs
yeDAf1lJPXb+jiXEs7AtK9DD6l+pWNuOVuKQlhWb7etlsdOFT06B2O8apn9j
NR8V/WS9z5MnQO9thFcWc2WzmN00ykJITJTCzqpvISRofoyfXr6MBcQ7EyVq
3RBN4oVw1DNkC7uEQ1jyCOOfVThiOXVswW6+Q4ivGCQoC5ptE4rVQTc4uTlT
u82TaRs9CBRr+eBf7yIk5s4Ud2SQLoj+W4PGSrg2pSCyRZJdS6bbBxgkmM4w
UGCoBBJRT3LRbAtkluLfxThY2DSUDeUvkv6ZO2UVaY/tHJmaYIGJri4bO0hS
Tl/br8OcDoVYE585xOO8LjCwJN7q6uVF7Dv9jEfXaErqYuaFtZtsLqZBmDuA
wcq0BYOV9cHyu5kNx5z8YSUQ1wi2jiO1x8Kp5gFMWOxKcGzpsq9//fuS7lcT
O3bv4LhX4w5JG+x2FZbBrLwiRoe5IRVzVftAw8YSg0x088zfJnuO5csx25mN
WX52xLJP0Rbjhxl6zdeziAvbxg5GlBbX1OJCwRnRacy63Js06DhOrHyVHmfN
bXw1RpKjpswRw85lsR0lswmZs4dNpa75Jix23q+Gw2xpDIfmr7aniLRe3Vm7
iyy9bIzVkmNDoocTcvtdpHgC600wJrPhonVWWnf/7nANNTDI+TMW2PE4YvVi
TgHmix8P29qNfOmVe12x1QMT//SWW+4VEdalSUU7qc3EtPWVBELmMGIhnXWN
Q522x67a1gXZtjHiVmXhPLZ9WiHsk1tGk/e6Yt/sEhlc+sd//Od/84Y3fDsx
m7R/c7+Ix5RF/a8iA/BOnXGZ231to3qhF0A1eepZwJbVF1mTDptkojHNxXIe
WGRvvGGrXw7Lbs2rD5tsWZhdwqBwuTZ/sXHjfzKFJXXdVRotYCkmLQts/rI+
a7tloSlxyUbPV9VyNDM30DsICavISLHN98VkVMRc67/Wo9KwKC5l17IJo8xi
zL69bdvfiANVd/WxOOaomthJ5T1Wl+LDQQZiv3VnVNp/8zjWTopKmyww8i4y
YBdnbZT9w9YUnoY/KlqQ7T1ZNvBUNUjwxImzVAdJBszey25/l4QElqXH6lS/
h7zHvHcsd4vtG+8jg5LpxZni1qeND6y8eR/tA7RVZ/vY9/euTu/vHY2ammBD
xljVvODkSqO9e/cyztw0GllyAtvmsq1q1+0hu3yBGTBs6rErbDXfEGsv6LXR
DLWqBhu+8Y1v+AiKzLAL88E61eRzrPt7U5t5oqWNZvtuyg8LbAk75GsxSO3e
WJNJw3aT7Bnb9bUZCW0+SbTHDAc2TKwPdlFdkNb22CcTNTvk7sx5DLnmX/kL
nKBUL8pH2+6iWsYdv33+afP4Jqm9+EFKPnVMK5CWtJjMvaX2oix3k+U1M/XA
zqezAWTfMm3LllGW3MCsS1JZw/+eybhdQzo6etRS3RE6CbIw8IchcPAKHoyi
JhBxMe14f++QvN8sAiztJAnfwGOhTSYljq8liDN7nmlZliRoI+MNUFatha2r
bE1mI9jVe8KebayG0pxP2D5eHifSEa8ckVQe7KiOkUIkYD4K17/T1mjEskWw
TMhuTvkyY1LCYLeqZDZsvRg8bEFk9iGze9mwbO0Id3AkiavbYEQAdmdd8HAG
75IuCGq2sneTQ3dp75bHJL4IttfXixbisx0u+s1Uw6YMbHDq/s6AZUsd22Sw
45IsB1w9RoiXIF4wUs+bgujLCiIN+9LuICYhOfzIghDkom/lvyxtkunSHEwf
z87BrJBJSrDg7+o5TXAvH19GCH931mplHkhsyeIpGP6Az8An88dp1Qmkt9bn
ZfSy6OSxEgri1WW6Kl+p8F/m+sozEtghGR+K9M/e2AGnagMrqVuIwQEnBEMU
Jx+Ds0A+Vedru2CnF4D7k7WY7TpLoQvseGrxYwQO5pFj54gY63c3ttcHu+gX
P/CrMKdrSxDXjkubNbemUuYxm57FyjshdmFdJ2I/pIJmx/9lc/gI4ZDFqE8l
3bA6suHbPpSK5fRBSNYpdG0mcXMyVaKYwBW7XoMdtDyuO1qDfJciWyqFzBKh
5JQRsyJZWZxt5Bmbh2yXyNykrDatxn9tqcJkgG4Py0GjwclWlTUtKo7B3ens
rsbkfWYuAqRiruqeA/PWrw3MbGD3abKN3LaGNcTHv/z7rC+GPCuHq4Y0SDZv
CyyqJHxKJhAZeTEBa+qSScXUcsdB8wH8iQL8XaXbkmwkhM/OvDUXolt6HxbG
pHZrO3PtMs/0cYQbdleEVexw+6XKXTLM9Q4EEBo4bFgn5cyqtZ7NleWDrvZ5
kopmUlP2bwVOo9HPdM21RR1lFqtgN/myazHYLRFuLTebEOlQO93A6eeQGd3j
S+qAtcpkht34PQ5sye5S/eVQyTh46/zJUX/YgXm2u7xBKcrTCog+SUixayO+
6DKX3PKPBc4sxBCXHPgkLFAqmc3rVxIKu95C5+y/GN1wQ7GPTIgzM57zFdel
yFCe69uxPixUv6grz1BXZtTGhXNDZ56le8ap2gPfGp19Nl5+aPRrv2b3OibU
td3XtYZwyDQxS3hpLvw0gJqxeQp1I1pf4fAb+rgROp7AcXbkfkwRUN/Q9tGf
/Ml/HG3ebCdTWdYHC1KxzfrFHXBiB+urZHnZM1miOlYSzb7EDPD7Qjkzxir8
d5oR7PACS2BXOi29Uw4O5Pg0pW1aYpL5k1C4lq3G7Jw024ezrPVmC0FSXk2z
YMZpIi+WDH80Gn/Hs2uWA5tzmyWwaYKApUDKjRQsWMtcEFMZbKhIywyszTpd
mZHGMjSCaS2GlmUrQ8zElRiSZ6JdY7bltV0wYemU7AyK1dkvp7EYw5UaiEVI
5FwGS9Cx5RY1Y7M+SJprzUhicORHHCu7cAAlgBPaI/Wzi1bSS0uwMMXUzU74
MM0TxDue7zbXs+buWxYqtsTQBmyjxCYcK3zFzHB2ulOXY0x0dDtSB8pnunCo
ZXDBgd8qI9BiuxM7m2a51kygmdXLrk5ha8wuQhY7ramONJuYUPnYxv98FzYv
JP1OVsrZaufhB55QY90sDOxq/MbMk9XlOiB3FC4hi22F2fE4loeyRckvR8Qi
iHEZZlL3xDg4+ZqfOrPomq4+Ott7izuFZUIxXc9KdbJjACxjkO1km6sHiaUK
eRlp3IGFN/Ksuib3RaeCLbm8VWtqYiriB2WTDUcbSPF/HiTtsvuzWaX+Lmcn
XbKxX1iAk+y72PaUCZb4dScgHsynnUOIZ50gZFdpKIS+hG60tlUBW4mOkbr1
byYU30C6Y7FS5lnWuyGheczSi+sMO0bJAvBaCRCQQfPgx8NHJk5SPZcNzLYu
kIZ9YbJBw4yWk0MKn0XozJvN1psu8OG9kBfQhzCjOaxNGBGW7M1q62yp9I7X
z5LUpwGz8beTwRQYeGeqwV9kS3gOgaf3etI0q3wfjE6xSiydAcIpVQ1Z2Wq2
ILCT9oHUYY6NGcTLhue6QK93ksGglC28wmNxMztnkx94BHnXkqaDA1O84hYu
gYuFJZ4w9TzRzjHbiEwsFwU1+3xRMisOnW9BsK0DOg4ci4gAnN2EEwZOkKcB
5MKUV5QTlsbNVMBA/3TPDC3LSjG05PfsXNmxQpZYypsryPzuN4PM4mc5ZJ41
FkRihzTCLQF9yBXka6RuvLwEVhWGb5SnU1TTZg6VmadvnTlcGlpCwbKB0crL
uVugARjTQ+xKztzGLhpKlaja86tW3ECyujjr29HRhTGigW6XjcbJy0IjmAc8
a6Mk51zCFCtjwsq+bqqUtoU10LOcjw0TdQhnNQPGFwe+/PK/Orb5c0onYPI8
Bg3l1ZyeQGJPBwSqQ0wDuF5sRwkjR+LLigBsLr8dMARYXWBWXbmTwcJQ2cpR
Qf8OFZ8iA4ufXQN9R3OPJLFkAAk05QzAxePBFuywsRnCSvWGPhZVIMRO/nM0
Gt3Cp1YYWAilLhmyNfRJlHJei3nxWJEbdt8Nu23gjUpK2ZdluGGKAnP0x044
aoaET+DDjxS0YSnEp0YsxhQVpQ0uKy8qqb29ioYv8RtP8+WEdZaIxzI8WgqH
tsKL9jR9GeEV28CCRjEMWI4CK8WhG3hv9uNH0sPvWO40PK0SQe84MmwDNkNz
1mCxEZpVE7G67Mwnzw6yslRRBidLhji5msrmuASsUtGc1cZTH5HPjou+jzvH
gC5JUAyr5yA3JcXxpE4uc4BD+2LsWY07VozGVWmJz8ofIYldZPomnSFuqfOz
l916piML6n06NjQdNN5dXVDRO/OsDUmWVi+mD6HArcQM+4dIkyyd6UwlteTE
m4SIWoHjmyoR9qlIWNXglHlXF07eWXESnw0r9WsBMqwbsnoyzyAz8NnRDGbY
sZI+WmEK+27TGehfTr4Fd0jNfsHf4QZ4dxee94aR8vt6rIXMx8fy8NghduYl
YZ5/zSGEnWM2D/4r6alh41AzTKD5sQLc3YW1cL2Z2MkGHYRQVk52BRlT7Sw7
n/HCnLpnVererBfQIf7At1cTzy/6mDx4dl6laWL2XCfT872VuJq1gAko4nIX
4YWdzGahCuajDSb4kPEHjFUvQBIxhKIRVc2NvyXVw3lYjSAD4uUaVPJjhm0c
3zsJX2zL0Oh+y/haLJfYz93xeLzBINQOiZ+8ebl83aXj5eIWpnyNP+9vAr5i
qjKVwgqJvIf0yeI2QeOu9s+AazKu//6KYmoqjP2njo3fnl9wzJ8hgXR7r18f
W9P01DPLTNMuvFexhlVTX32wKCkojhxZuzmXZXkDMnJguYyz5Kmwrx3CdvN7
C5hgkK5BNZf91lWqtLHqnCyecDchhd2uEL6dBL6wF0xfQh9jDAQDVv1TNpwT
EN/LjhGZxCAN+k/Uv08kxN/xTBdlzARbOSCpEun4KdJF2MkPYY4ASbMd8A24
Y2YJC4607BGMUrF+VhSKoFpk3+NtcwgMBCdAEcyiF08syt1OMdJ9BQzjj5Be
1NoHeqZXbH5hnWA7FxYMYia+LnneI48fqfJ26UqiEryAQ1922xwH1dSR0OeW
LUVx8ODGK0o1gzd6EAC4WeSND5PutlZTAYamCRimHjbF8i07isIiPufEWb9o
VqmpO1kP7b1LVhKbYFcNAbq3nSCeMIUDNlOWwwF+/HYBPIL3D5HegmhMQnLM
GB6phQGtJFqCTZy3VxT56WzG+eUVE+NlTzHuL2iGHNISjXudOJgkFqk19gEJ
SxFmBcZVmeITGB9yl6tKGiCSxVrmBJlBGs6E9swXQ1sD5I0Hl4uF+lXz6Qhc
sGmYqiDwigDSgGfMHs5dIm7Lk1CjdiUkAhpW8tUUFkgLJpas5WzNulH1UykZ
Xlqg8XBjwP7lohFyAmuLimnSVRUaNh/wA9Kxg2dlcFnU7zxCzfHVvPHrD1QK
IvXiub+zEgaL2JkwYIcQy2hw9hu9i5dUzZp/QpudNGUZyayvdZOQa0wJM8Ig
3xg88auxRKF3EfbVWMHiAnal4JQKA6aeOGzwhhqHfuC9toxT96HIcYsEMOdd
8FRNwuPjNSP+Ll4gvGv3hZurHT9WcLW0EB9+uAThuxu30kl+P6FDQcJuIme+
tFaKh3/p3U/6YqUYECuTRsf/g13En03TK6oOMknovXDxG4st8t7eOXOT+W9B
vFRxVcIhBTATZS18H+lf/T+Y/hhdCD0kKHw+gN0Fy3rLv7yvIo8VF9VoPWan
jRcViJ/oggmbrEHLD2sCsW7dOqiaKWUm88BhvEC/VBhVSIwngYT54E8mJKlc
wS7F+im1BHoqG6Xaie0x04IlHmoyB3bH+dqXyNBDhL5+FwwfapYh2bLae3ZP
dKnYcqEHUJAdUXqs+pkaGb5fAI5lBHLk2upDpiCX+B00EqvWel2lAM3zayTb
iiJvfICQ0gkT/dBkSA6SqNsIGxJoT08z5g4wwZwCzSxoyXZ3mlKLT9A9moX8
9SpUYX+Io4dlHao9g1HKdWuyDlxfrSHRFmOZxb0u0LAb36aq8Yj5u5sqcQET
UpdNGYOzE89kb3cWGSN2+iEYW2vQHkQDcJsbGvSN1GYFhjYMtHw9q6deHZ86
bHEoA9IsbHnjxvjemCY9u/QtuK4kEGr6FHIUMOpDVwAj8AJ9wep+s+O8QeVO
+Z7wOXpAc2gWM0x7wahIXmFJLAjZTnph4VC1Mv1WDRMPRikU+M3Lxen9pH91
i0n03oRLy1VAyUKhptgNXv725jOgd6GSgJ+opeYT5xIbhSzCCAIah797UlGu
QiquA6vHjubwmg/TJtSzK8lt1dTbJLAnwLx8+3IRYg6bfkSoSocKy2wsuI2R
wvQMvjLxP+75xk3lJro0hg+fcj6s16Iv7A4xO6GADT2wDBEKoahVnjvgj19j
ocPrAB2fFwMdiL/cUDz/fFE88cTF98KgkoWPXYawr1Ig8RmDKK/DESV+XNhc
+aTEtA4zfNJf/mHWpBgPsE5O1Cnm87hKxoAVQAB2mFfDUbSrMOuCrRVqchqs
+IFwnlCJsz3Gj75t8xY/WHVCwwP808TSGqQHN1hh49/tAG604Lqe3CGeE4Bb
gjd6ArtV+JBGrmId/im/GMqfQk1sQKMTWLDy9xBCie8NouhU7w3Ce0/ce/ET
e4pij8vIg78ivoef33rPe14uCXymV/L2RNH7zmmnnS/bhqamlQQ0k5MK8uN7
E/Ln5C8f+On/8qUD9x/5yoHbF37/wLWHf//Itfdj4GSWyEAORwfQ8X890P/M
kQPTX3r50I6nw9gWffPYys/hYmZKXl09OlLI8RWTCSx5EAIsixACqDPEsicD
qTGs7UhFAAq/lWFUlmJQyr2Hb3NUWXvLH83xxGHgh+8rt98Ok/irRb+jWLCx
y/y/e3Y8+N1iarz2ok3VJAv6HnjM38NvDu3bFyYhO4S3ussE3EGI+6FNtiot
o+dHK/BaTH715ptfKm2FpzHfRrhEuAjRbX9cZVkzjqGsFb+gnk2pYq3qYyqW
y9OBHb+FOWc/MvcmZe7JvXlfOnz/IXlzQv4cvnjg+j/EZMbPrx74wCI6RHdT
402WY5h8k0l7+CE5S6/XZJQhwSSE/hR7+Yli8KsfCLjYj4jP5DInY3HTN16/
yThBGuh0GxKrjMnSFNdGqmXXCoO56IVdRpwAeONe0gcL4GjwBTYJ6g5JHnmv
2gXHzftWQgvzA9+2HGbdyTnYtbAzGxm7h7THksAuqtrDjkJu1HWMoQ/Z276V
0MKqwV3ehTGWwXVlO2OwCMVkZVFpTTyCTx6+X/9twgQ7RsUu7+nExM81E4y/
I4NT9lDvJt9qbgccStFZ2as2wZHZWwjBl3Uh7hNK3D+8r3gKNnV/1bpyzyEd
oEOpKIM37iTf6mYAMh29YL3KCxZF7Be6EJInzVRBkOghnSoe/EqcVEokXAPo
SDYBLFP7pqg+j2CCi9z2q9hPdCM8vRwiq9jEMPddomE4fLQvbFYw0lKwhd0N
dUNU389Hjx8biF+idEpb7P6lNzdLfBwf/DBXFouwqJdv+tA9xWMwEiY3bjUy
AS0gFmGWwvATS8D582F8IcEYVwgNCJSxZGfjGEHXhmeJK7Zf+duiwj3YZXyf
roQlPmNOnnMbCZnEtz4GmKDy+S5EfE7+7JukQ2dg+NjpOT2jD0GGE0PC/3+/
Sx/PVOgeVkK9AxsaXiQ1Tzl2R+uS9i6txAzeDZlVX+pCyCzpQJ3aU195sHgW
CBarjy8GYWABCKYRhhVi03IQLunmokpKMBjg0fiVU/v23q8vh+aq+lfMIcZ0
BZ2iboahI4gnFLbk1LEVhpWO1kqj4BWjizaBwaCacuPR/iTpV8+RYtCsfaVZ
bgCG3gDeWMAuJU3qjXuYtWgC+EIrDysS0arI5j/oQuIXQnsmS5jF0ApKEZrG
lABFmFMXkhbCuiH3vaNbUATwJysBRwsSpflyF4rmKoDwoUjPZAUQ9DMoxaAH
4Wusi8tSI1mF2FMqzYhWMR/Ri4z3ZDUVMDRWX+S55U43LR8DMNEW5gP6GVY2
Vfy8l3GXFaLtwh0+OamSGOMM3UxVkIIIKEAIATt885vLnafTFbOQIEgmJEp1
gRyTTplNin/JWDzyyCP4r4hPbhS6wuAJKSyHSzNafDxUVy4RcpCG8QAELCu4
EwRPKg95iavaobJ4mdlhV76y7zvEkATyJi38BrgwgCATn4rtzComMEhC7E3K
EOBbtIG2MMHQtlmQGhq2tR2PQQkUKT4TW4HlR9xNRubWLpBdRz58G+Ep203K
zR5rw/CBWPBg67Lcm9cLlybPfPnLX8bfxB7I6qjJktsP70Fx4TMpMTghf4p4
ok3pa1UVn4+0q5xIzpHF7B8mtC8LCHx4PUE65N5NmvxgWoFcIxbCUpwQiE3q
JSqxMdkSfZ9YWct4LkHjj5E+b8kZWIkLEu19/7u+/NlLLkBgYSbmbxgSwn8m
lXowCFCQGAJD7HBxyvkQ8dUd8TpO3pvC+mgCB4HAdxAgE7THCHWdIAxOojWt
d0DIv/XaFlwGwu7eZB6KzxB49CCqwWOKIQDRi5sgB8fBPW8pnjc4+uE9LNT2
eTER5lNi0z9ByOmExzBSmV9+MplcfoIfEyNcZcPCPcy58YWUMHn/lozYpirx
20h77xiLqSVu6svnB5hngcOfIsTl9xX5cxQlwfF7VmuPVXH/8PiMNV8AlT4L
jMm3cp8aK4O1jTxj7sC7VDb8e6PR0sU0We283Ajwpa/9e6LwX5tLzYKAsw3W
xYT5HCQ8Y65FlkHIajSwOCpTNsxL8+RY8rIEKIMMFMgL27xdQghms5SZF6wW
Azswxpw+sys5Oew9UW/phEkI+SIhhFUr+1ZO3FaT7nFvBku1U8vgJf3bskM8
XUseHGUnv5iLhOXm/52c7+VdsjVM15kKFIZJF/6dY42cA27nvypMsPQxlhr/
rddObVja5DCrzj2LltvcApuPnyLDwi7MOI88Y3tbVs20LZl/qVMseckdfHtP
41zueDlTnNMRr/2lJg1WrUy1lCAWw04IYtqVxVpYFWCWcldjsDmYXrsU9i4C
IjuJxwqOsJuj3kee7e1Cny1X/h7U3+1ACN77RpcO2HKQV9yO4tIwa/23/6ZL
p59oGq6lVDpr7JOEijxYyA7/eTOH5IcmfTBX0f/RhbiLyIc/R7hn3ix2/UgX
4lxZs6Tfzy2HYDT2OEG47e4yUnU/6YOpqNzh3nSjQycmLiYd/AZ5Lz8j1nSZ
wTNdOmWVwFn+8afJt1eSTn9tOZ2ypGc8Y512ml0sdZzVOnnyWDvwEP2TIDrJ
e/jx73yTNi5t500CgKWaxDv/e2yhhd6zCPPM+/2Wlpnqv+2kRn6reZjHR/wf
ESrYEcBOjX1ruR9uJs/YSaT3H8Ozk7oQwuwTdi0gq6TPnr0e3571t5CWru91
Opjyt3HQftTp+2Hx9v8P+N/Cb1d+wCVF9qvu6T/Tl72DaIo8k0Yv+tH/5jfl
Pw1+ianE+40nVTPl/npuNm6t5+aLxZG3J/r81ank1fCjO/VZea4nxMsN/wK+
Sjb4s3MLxaILXYUevJNsTUZw0nTGQEVp9t6EkUA+B1lzs+ZTWFf+brbsflGb
9f6a8J6Qnn1fstVzuC3oJxbXNbcGuBoshcZoFK/NNtLiO7NzaLsLoOGd40rw
5sTBJgDKOOUIEKDWcqDaAYhOmRUgw/t8FvTT2LyOD94Il3gWz+nrPmI1VHFn
bjYb2tnZ/SE+OllNpFHtlYK/kzIQKVaHJr4I322qS1E1KRVA/YaDkQt5q4wP
ydfS4zCSVHVc4jVhj1OH7ICEjc1b6KU5jO8qx5aPqS4o8iK11fcOojBrhhlE
GRmD+q9LEvqqfTAp5paSaAbL0vwfU8cmEabSKonoJWHWD6UyHNEpX8lDB3g2
oYjHZoNOiEK5MBddyPruuk7vEqHuZV2ZemruakMSZ6vkNggLmzfjyPaW+teu
t1yf52qqrs8rxTBXLi2xm1KPLMxFvJkOz4OKVXSjRvlU/liaWKx6ah7ZpeFe
W70bHeFVN03qZCLXjByk15ecfiLki4uVJEQtIlR92M8WD6uIjwU2vdSlpoWP
KUzln+cQNL9GpNMZXH761GjUu28rGufmMhzbhmbpWUKsHCe6PV2QM1rzHpJ1
qRxNCzawWeBX3TgzXLDT7NXYZcnoZBtkLYB7/qcIE52NmRqvWVMrS4mVykH9
Hkz5OWeQqET/VoawrYtieCRWWEq8GYNhFHIbp+0dNg17SSaUTSf/nYlvteLn
1vexie+J5Ouqp9lysszNLxQLpQG4uNhdhCejtVH9blXRLNP1ZzVyJwlg7Nmg
M/gMOILQcd0EuiJhBSmIc95tPWzn46n5UCbUbghNqH3s9kdDqNNVulRTNSWw
MurYjU6wM1eNJ8Pu3VYZJkz7tv+7FOA0yySMtN+4QrngM91Z/qMEtyZhEaJ7
5NWVsjNyORvHzojuk2h9jmkCNrRck/dAx/oCSfQ4IjRf6mrrtMtAwy6IsutS
npst8BoJqUkSxiCK9AqYH16KW0TNw7Q274RjMK75sQxKhoXfpYufakFM7UdT
WfdzP1eg1Ri5HSiAXqgM/tYdaMu7o4Rw6X/8Heh0kXhYFom3pVHmwzPbIMet
We35XCbSvr9qSErEWka9trua55xB2JvdiOlgNUv/qhzYqh9nvOeD1YY2QbLZ
3E4WVe99yQYvXZ9WhJy2uSFINChV7wowzJI1YUml3s9YmpvznsTUrVR/57iC
+ipmZxOZXKzUZ7AkNmWiThwwmYOmcTqU/56f228eK3hcDbVg8PUTC64czKH+
0vvp7dUm96LzgzH34lAHxxwyKgJpIn+AKe4yqXcxxSShot2v2+w+lH+PzXOX
3ph91Dz+5WAxb61uK3+7UCPUoZovNraY+vDOgosEOa8hiwTFV9cnryb8Ydyi
xeXe0W1E5d+fTAIoucCG9WBjJtTNArwYAlVx6Znzfikf66o0iylmETkfe3HG
YTrSg0SMWTTEvrMysWEAXHtucCoLXEMfs85tjNCHwjNpgpnFiGbDUlVtAnKE
p+oIM8W5vkUIy38vzrteM2Bn3cwjyJSkjEXJumZKqFiFlSH2kgrwI35aOIsI
LVWjYHm5fjnaGAcPnWunZcvz89XgWT1WvAP7Ab2+lbT1+UDF7xTBRPfq315h
JOgdlalpol3PLNVNP1GNpcK6NK58CbpW2SeE7EJDJ/pFstpHzJBX8z7T8FtD
n5ZrPXJFxk+MWIYhApPXkfdCuYkQAf9e978Xb/j/AMIMqCA=\
\>"],ExpressionUUID->"bbdbea7f-391f-4c2c-960e-77f8e7be7963"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ellipsoid Reconstruction and Evaluation", "Section",
 CellChangeTimes->{{3.7561285755704727`*^9, 3.756128582713475*^9}, {
  3.7561293665671005`*^9, 
  3.756129369355744*^9}},ExpressionUUID->"cfb7265c-257e-4a07-a651-\
7b79656e917f"],

Cell["\<\
This cell reconstructions two matrices, one per ellipse-fitting method, that \
each characterize the quadratic form of the reconstructed confidence \
ellipsoid. It also calculates a \[OpenCurlyDoubleQuote]consistency \
coefficient\[CloseCurlyDoubleQuote] for each matrix, a measure of the spread \
of the coefficients along the diagonal of the ellipses\[CloseCurlyQuote] \
characterizing matrices. Finally, the average relative difference between the \
two matrices are calculated to measure the divergence of the two \
ellipse-fitting methods. 

This cell is completely automatic; no edits are needed. \
\>", "Text",
 CellChangeTimes->{{3.756128631442483*^9, 3.7561286530672836`*^9}, {
  3.7561286841461067`*^9, 3.756128746578901*^9}, {3.756129539583927*^9, 
  3.756129588424636*^9}, {3.7561296749209948`*^9, 3.7561297858419967`*^9}, {
  3.7561298847212753`*^9, 3.7561298979718184`*^9}, {3.7561658077620325`*^9, 
  3.7561658079441767`*^9}},ExpressionUUID->"cdec59e9-4b15-4af8-b20b-\
a9defc5f7f20"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Initialize", " ", "necessary", " ", 
    RowBox[{"variables", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"i", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aOutCM", ",", "aOutHull"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"d", ",", "d"}], "}"}]}], "]"}], ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"d", ",", "d"}], "}"}]}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"adiagCM", ",", "adiagHull"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ConstantArray", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "d"}], "]"}], ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "d"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"daOutCM", ",", "daOutHull"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", "d"}], "]"}], ",", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", "d"}], "]"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aconCM", ",", "aconHull"}], "}"}], "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Calculate", " ", "the", " ", "non"}], "-", 
     RowBox[{
     "diagonal", " ", "elements", " ", "of", " ", "the", " ", "final", " ", 
      RowBox[{"matrices", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"ix", "=", "1"}], ",", 
     RowBox[{"ix", "\[LessEqual]", 
      RowBox[{"d", "-", "1"}]}], ",", 
     RowBox[{"ix", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"iy", "=", 
        RowBox[{"ix", "+", "1"}]}], ",", 
       RowBox[{"iy", "\[LessEqual]", "d"}], ",", 
       RowBox[{"iy", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"aInHull", ",", "aInCM"}], "}"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Inverse", "[", 
             RowBox[{"aHull", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["nsigma", "2"]}], " ", 
            RowBox[{"Inverse", "[", 
             RowBox[{"aCM", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}]}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"aOutCM", "[", 
          RowBox[{"[", 
           RowBox[{"ix", ",", "iy"}], "]"}], "]"}], "=", 
         RowBox[{
          RowBox[{"aOutCM", "[", 
           RowBox[{"[", 
            RowBox[{"iy", ",", "ix"}], "]"}], "]"}], "=", 
          RowBox[{"aInCM", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"aOutHull", "[", 
          RowBox[{"[", 
           RowBox[{"ix", ",", "iy"}], "]"}], "]"}], "=", 
         RowBox[{
          RowBox[{"aOutHull", "[", 
           RowBox[{"[", 
            RowBox[{"iy", ",", "ix"}], "]"}], "]"}], "=", 
          RowBox[{"aInHull", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"adiagCM", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"adiagCM", "[", 
            RowBox[{"[", "ix", "]"}], "]"}], ",", 
           RowBox[{"aInCM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"adiagCM", "[", 
          RowBox[{"[", "iy", "]"}], "]"}], "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"adiagCM", "[", 
            RowBox[{"[", "iy", "]"}], "]"}], ",", 
           RowBox[{"aInCM", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"adiagHull", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"adiagHull", "[", 
            RowBox[{"[", "ix", "]"}], "]"}], ",", 
           RowBox[{"aInHull", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"adiagHull", "[", 
          RowBox[{"[", "iy", "]"}], "]"}], "=", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"adiagHull", "[", 
            RowBox[{"[", "iy", "]"}], "]"}], ",", 
           RowBox[{"aInHull", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"i", "++"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Calculate", " ", "the", " ", "diagonal", " ", "elements", " ", "of", 
      " ", "the", " ", "final", " ", "matrices"}], ",", " ", 
     RowBox[{
     "as", " ", "well", " ", "as", " ", "statistics", " ", "for", " ", "the", 
      " ", "consistency", " ", 
      RowBox[{"coefficient", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"ix", "=", "1"}], ",", 
     RowBox[{"ix", "\[LessEqual]", "d"}], ",", 
     RowBox[{"ix", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"aOutCM", "[", 
          RowBox[{"[", 
           RowBox[{"ix", ",", "ix"}], "]"}], "]"}], ",", 
         RowBox[{"aOutHull", "[", 
          RowBox[{"[", 
           RowBox[{"ix", ",", "ix"}], "]"}], "]"}]}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Mean", "[", 
          RowBox[{"adiagCM", "[", 
           RowBox[{"[", "ix", "]"}], "]"}], "]"}], ",", 
         RowBox[{"Mean", "[", 
          RowBox[{"adiagHull", "[", 
           RowBox[{"[", "ix", "]"}], "]"}], "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"daOutCM", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], ",", 
         RowBox[{"daOutHull", "[", 
          RowBox[{"[", "ix", "]"}], "]"}]}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"StandardDeviation", "[", 
          RowBox[{"adiagCM", "[", 
           RowBox[{"[", "ix", "]"}], "]"}], "]"}], ",", 
         RowBox[{"StandardDeviation", "[", 
          RowBox[{"adiagHull", "[", 
           RowBox[{"[", "ix", "]"}], "]"}], "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"aconCM", "*=", 
       RowBox[{
        RowBox[{"daOutCM", "[", 
         RowBox[{"[", "ix", "]"}], "]"}], "/", 
        RowBox[{
         RowBox[{"aOutCM", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], "[", 
         RowBox[{"[", "ix", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"aconHull", "*=", 
       RowBox[{
        RowBox[{"daOutHull", "[", 
         RowBox[{"[", "ix", "]"}], "]"}], "/", 
        RowBox[{
         RowBox[{"aOutHull", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], "[", 
         RowBox[{"[", "ix", "]"}], "]"}]}]}], ";"}]}], "\[IndentingNewLine]", 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aconCM", ",", "aconHull"}], "}"}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"Abs", "[", "aconCM", "]"}], ")"}], 
         RowBox[{"1", "/", "d"}]], ",", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"Abs", "[", "aconHull", "]"}], ")"}], 
         RowBox[{"1", "/", "d"}]]}], "}"}], "//", "Chop"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Calculate", " ", "the", " ", "final", " ", 
     RowBox[{"matrices", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aFinalCM", "=", 
     RowBox[{"Inverse", "[", "aOutCM", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aFinalHull", "=", 
     RowBox[{"Inverse", "[", "aOutHull", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Compute", " ", "the", " ", "average", " ", "relative", " ", "difference",
      " ", "between", " ", "the", " ", "matrices", " ", "produced", " ", "by",
      " ", "the", " ", "two", " ", 
     RowBox[{"methods", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"delta", " ", "=", " ", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d", " ", "=", " ", 
     RowBox[{"Length", "[", 
      RowBox[{"plist", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"num1", " ", "=", " ", 
        RowBox[{
         RowBox[{"aFinalCM", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], "[", 
         RowBox[{"[", "iy", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"num2", " ", "=", " ", 
        RowBox[{
         RowBox[{"aFinalHull", "[", 
          RowBox[{"[", "ix", "]"}], "]"}], "[", 
         RowBox[{"[", "iy", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"difference", " ", "=", " ", 
        RowBox[{"Abs", "[", 
         RowBox[{"num1", "-", "num2"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"sum", " ", "=", " ", 
        RowBox[{"Abs", "[", 
         RowBox[{"(", 
          RowBox[{"num1", "+", "num2"}], ")"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"sum", "==", "0"}], ",", " ", 
         RowBox[{
          RowBox[{
          "Print", "[", 
           "\"\<Error: Cannot calculate the relative difference because the \
sum of these two elements is zero.\>\"", "]"}], ";"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"relative", " ", "=", " ", 
           RowBox[{"difference", " ", "/", " ", "sum"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"delta", "+=", " ", "relative"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"ix", ",", " ", "1", ",", " ", "d"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"iy", ",", "1", ",", " ", "ix"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"delta", "  ", "=", " ", 
     RowBox[{"delta", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "/", "d"}], "/", 
        RowBox[{"(", 
         RowBox[{"d", "+", "1"}], ")"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The reconstructed matrices are \!\(\*SubscriptBox[\(A\), \
\(Hull\)]\)=\>\"", ",", "aFinalHull", ",", 
      "\"\< and  \!\(\*SubscriptBox[\(A\), \(cov . mat . \)]\)=\>\"", ",", 
      "aFinalCM"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The consistency coefficients (average differences in diagonal \
elements) are \!\(\*SubscriptBox[\(acon\), \(Hull\)]\)=\>\"", ",", "aconHull",
       ",", "\"\< and \!\(\*SubscriptBox[\(acon\), \(CM\)]\)=\>\"", ",", 
      "aconCM"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< The average relative difference between the elements in \
\!\(\*SubscriptBox[\(A\), \(Hull\)]\) and their associated elements in \
\!\(\*SubscriptBox[\(A\), \(cov . mat . \)]\) is avrd=\>\"", ",", "delta"}], 
     "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7561287662941456`*^9, 3.7561287673486185`*^9}, 
   3.7561288564664774`*^9, {3.7561292160487804`*^9, 3.7561292357864475`*^9}, {
   3.7561298483349895`*^9, 3.7561300383617334`*^9}, {3.7561300774071283`*^9, 
   3.756130290095831*^9}, {3.7941342358430605`*^9, 
   3.794134237570731*^9}},ExpressionUUID->"91f2d58a-380d-489b-98c7-\
0d32526e0c15"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The reconstructed matrices are \\!\\(\\*SubscriptBox[\\(A\\), \
\\(Hull\\)]\\)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3383.6817245898164`"}], ",", 
       RowBox[{"-", "628.6118142850116`"}], ",", "1740.7301021332423`", ",", 
       "1443.6762275774488`", ",", "2.977500878686379`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "628.6118142850115`"}], ",", 
       RowBox[{"-", "2423.78615966323`"}], ",", "761.161152247117`", ",", 
       "798.1180051666466`", ",", "136.36076309483997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1740.7301021332423`", ",", "761.1611522471171`", ",", 
       RowBox[{"-", "4684.12157742775`"}], ",", "1514.9980273927304`", ",", 
       RowBox[{"-", "44.100727262777426`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1443.6762275774488`", ",", "798.1180051666466`", ",", 
       "1514.9980273927306`", ",", 
       RowBox[{"-", "4925.058946640779`"}], ",", 
       RowBox[{"-", "90.04125463463295`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.977500878686371`", ",", "136.36076309483997`", ",", 
       RowBox[{"-", "44.10072726277741`"}], ",", 
       RowBox[{"-", "90.04125463463295`"}], ",", 
       RowBox[{"-", "2590.351231994954`"}]}], "}"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\" and  \\!\\(\\*SubscriptBox[\\(A\\), \\(cov . \
mat . \\)]\\)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "615778.5518823792`"}], ",", 
       RowBox[{"-", "423752.5045593409`"}], ",", "962649.7836269771`", ",", 
       "81691.42155734406`", ",", 
       RowBox[{"-", "1796.4033452609035`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "423752.50455934094`"}], ",", 
       RowBox[{"-", "309421.93546399433`"}], ",", "666032.8842551556`", ",", 
       "70180.22502373681`", ",", 
       RowBox[{"-", "1195.0576851745957`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"962649.7836269777`", ",", "666032.884255156`", ",", 
       RowBox[{"-", "1.7100808805977604`*^6"}], ",", "85999.22068620902`", 
       ",", 
       RowBox[{"-", "1728.9806002821738`"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "81691.4215573432`", ",", "70180.2250237362`", ",", "85999.2206862105`",
        ",", 
       RowBox[{"-", "254328.4240735542`"}], ",", "4136.354886881448`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1796.4033452608878`"}], ",", 
       RowBox[{"-", "1195.0576851745773`"}], ",", 
       RowBox[{"-", "1728.9806002822033`"}], ",", "4136.354886881439`", ",", 
       RowBox[{"-", "3720.0975909896756`"}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "The reconstructed matrices are \!\(\*SubscriptBox[\(A\), \(Hull\)]\)=", \
{{-3383.6817245898164`, -628.6118142850116, 1740.7301021332423`, 
   1443.6762275774488`, 
   2.977500878686379}, {-628.6118142850115, -2423.78615966323, 
   761.161152247117, 798.1180051666466, 136.36076309483997`}, {
   1740.7301021332423`, 761.1611522471171, -4684.12157742775, 
   1514.9980273927304`, -44.100727262777426`}, {1443.6762275774488`, 
   798.1180051666466, 
   1514.9980273927306`, -4925.058946640779, -90.04125463463295}, {
   2.977500878686371, 
   136.36076309483997`, -44.10072726277741, -90.04125463463295, \
-2590.351231994954}}, 
   " and  \!\(\*SubscriptBox[\(A\), \(cov . mat . \)]\)=", \
{{-615778.5518823792, -423752.5045593409, 962649.7836269771, 
   81691.42155734406, -1796.4033452609035`}, {-423752.50455934094`, \
-309421.93546399433`, 666032.8842551556, 
   70180.22502373681, -1195.0576851745957`}, {962649.7836269777, 
   666032.884255156, -1.7100808805977604`*^6, 
   85999.22068620902, -1728.9806002821738`}, {81691.4215573432, 
   70180.2250237362, 85999.2206862105, -254328.4240735542, 
   4136.354886881448}, {-1796.4033452608878`, -1195.0576851745773`, \
-1728.9806002822033`, 4136.354886881439, -3720.0975909896756`}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7561668447091417`*^9, 3.756226776839795*^9, 
  3.7562268811940784`*^9},ExpressionUUID->"c9faf8f2-7244-47e5-8b38-\
72702a62c6f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The consistency coefficients (average differences in diagonal \
elements) are \\!\\(\\*SubscriptBox[\\(acon\\), \\(Hull\\)]\\)=\"\>", 
   "\[InvisibleSpace]", "0.07745377327150839`", 
   "\[InvisibleSpace]", "\<\" and \\!\\(\\*SubscriptBox[\\(acon\\), \\(CM\\)]\
\\)=\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm[
  "The consistency coefficients (average differences in diagonal elements) \
are \!\(\*SubscriptBox[\(acon\), \(Hull\)]\)=", 0.07745377327150839, 
   " and \!\(\*SubscriptBox[\(acon\), \(CM\)]\)=", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.7561668447091417`*^9, 3.756226776839795*^9, 
  3.756226881198942*^9},ExpressionUUID->"66ad4dda-1cba-4489-b1aa-\
14255a0896be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" The average relative difference between the elements in \
\\!\\(\\*SubscriptBox[\\(A\\), \\(Hull\\)]\\) and their associated elements \
in \\!\\(\\*SubscriptBox[\\(A\\), \\(cov . mat . \\)]\\) is avrd=\"\>", 
   "\[InvisibleSpace]", "0.9509386429318204`"}],
  SequenceForm[
  " The average relative difference between the elements in \
\!\(\*SubscriptBox[\(A\), \(Hull\)]\) and their associated elements in \
\!\(\*SubscriptBox[\(A\), \(cov . mat . \)]\) is avrd=", 0.9509386429318204],
  Editable->False]], "Print",
 CellChangeTimes->{3.7561668447091417`*^9, 3.756226776839795*^9, 
  3.7562268812040215`*^9},ExpressionUUID->"29e8bb3d-a8e0-40dc-8d4f-\
4167ca20adc3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1264, 661},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 3460, 62, 650, "Input", "ExpressionUUID" -> \
"2b72e9b6-19d2-49ca-bcad-7ca3c600975b"],
Cell[CellGroupData[{
Cell[4043, 86, 428, 6, 70, "Section", "ExpressionUUID" -> \
"9c0ed206-b84c-4484-9046-0eddbc6f2836"],
Cell[4474, 94, 609, 14, 31, "Input", "ExpressionUUID" -> \
"32e9448b-6481-4ae1-8304-61a7521b59ec"],
Cell[5086, 110, 7484, 208, 685, "Input", "ExpressionUUID" -> \
"ce4d1521-b14a-4278-9100-69a463c6c622"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12607, 323, 214, 4, 70, "Section", "ExpressionUUID" -> \
"f4ec3887-773a-43bd-9d55-bdc532d57e65"],
Cell[12824, 329, 1196, 17, 145, "Input", "ExpressionUUID" -> \
"7224941d-0dea-4b09-9213-b1c3caaa248d"],
Cell[14023, 348, 2354, 60, 164, "Input", "ExpressionUUID" -> \
"155d6491-2b35-4e0b-9c77-b4a6100fa3d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16414, 413, 167, 3, 70, "Section", "ExpressionUUID" -> \
"f0dba2db-d99d-4dea-ac1a-4a39d912fae3"],
Cell[16584, 418, 644, 10, 50, "Input", "ExpressionUUID" -> \
"b54ed4d0-2d3e-49a5-a77b-ca805af63a4e"],
Cell[17231, 430, 1500, 47, 88, "Input", "ExpressionUUID" -> \
"a35e4336-234a-41ea-a6cd-5a11b5182b68"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18768, 482, 179, 3, 70, "Section", "ExpressionUUID" -> \
"55ecc271-3bfc-4aa6-95ae-657cf82f42a1"],
Cell[18950, 487, 1595, 23, 70, "Input", "ExpressionUUID" -> \
"22e6b0f3-4b9e-45a0-94d6-5eee94976ad2"],
Cell[20548, 512, 1172, 27, 126, "Input", "ExpressionUUID" -> \
"278a4f69-e2eb-4102-9d99-8887773e85d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21757, 544, 223, 4, 70, "Section", "ExpressionUUID" -> \
"f6526e91-7948-499d-9355-ef0a894166ef"],
Cell[21983, 550, 817, 15, 87, "Text", "ExpressionUUID" -> \
"88a0ad96-b0a0-4ef1-8a76-895d11448d38"],
Cell[CellGroupData[{
Cell[22825, 569, 32888, 760, 1833, "Input", "ExpressionUUID" -> \
"ea1259eb-63cc-4e1a-bbe1-24d9ef121c34"],
Cell[CellGroupData[{
Cell[55738, 1333, 499, 8, 41, "Print", "ExpressionUUID" -> \
"bbc8415a-59dd-42cf-aa35-d518d360cc2e"],
Cell[56240, 1343, 405, 7, 22, "Print", "ExpressionUUID" -> \
"5df7a4fa-40b3-42e6-aba6-118f9ad58dd1"],
Cell[56648, 1352, 423, 7, 22, "Print", "ExpressionUUID" -> \
"a0112528-5da8-4d8c-b64f-b39351530cfb"],
Cell[57074, 1361, 407, 7, 22, "Print", "ExpressionUUID" -> \
"e395f6cc-642a-4105-b0a8-4e9f18408590"],
Cell[57484, 1370, 76155, 1287, 517, 41290, 715, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "d46fa057-808e-4f2f-b947-2f755b3af1f0"],
Cell[133642, 2659, 405, 7, 22, "Print", "ExpressionUUID" -> \
"e3a0722f-453f-4fe9-83bc-fbf046b5ea57"],
Cell[134050, 2668, 423, 7, 22, "Print", "ExpressionUUID" -> \
"da6e2ee5-900f-4a62-8dc3-8379ef54de67"],
Cell[134476, 2677, 409, 7, 22, "Print", "ExpressionUUID" -> \
"56ba382c-2fbc-4ae0-9362-96392bb7b2be"],
Cell[134888, 2686, 71196, 1208, 517, 38439, 670, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "43444d9b-eeb1-443a-9d9e-2682eded2799"],
Cell[206087, 3896, 403, 7, 22, "Print", "ExpressionUUID" -> \
"755ee215-dcbc-47d1-a59f-774370b06b3c"],
Cell[206493, 3905, 421, 7, 22, "Print", "ExpressionUUID" -> \
"dd939b21-e76a-4006-805a-498bab76fc24"],
Cell[206917, 3914, 407, 7, 22, "Print", "ExpressionUUID" -> \
"876968c1-6d09-4faa-85c9-d14fa0a1586e"],
Cell[207327, 3923, 71177, 1207, 517, 38194, 665, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "f0782792-d81b-4e77-8e5e-ec1a40961116"],
Cell[278507, 5132, 403, 7, 22, "Print", "ExpressionUUID" -> \
"331a92eb-f69a-432a-8597-1da83bc86337"],
Cell[278913, 5141, 423, 7, 22, "Print", "ExpressionUUID" -> \
"f2f6af93-88f0-40c2-aeb7-4d39cfe12634"],
Cell[279339, 5150, 409, 7, 22, "Print", "ExpressionUUID" -> \
"2c759a49-8dc4-4bc6-8b6f-73fa764914b4"],
Cell[279751, 5159, 80768, 1364, 517, 45689, 788, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "e0b0cefc-905a-49c0-87bc-2168854c2849"],
Cell[360522, 6525, 405, 7, 22, "Print", "ExpressionUUID" -> \
"4ed2a5c3-4a03-443d-a2e0-dff2b10de70d"],
Cell[360930, 6534, 423, 7, 22, "Print", "ExpressionUUID" -> \
"483effec-ec59-4958-afd1-88a8a3a3a769"],
Cell[361356, 6543, 409, 7, 22, "Print", "ExpressionUUID" -> \
"a68aaf1e-840f-4838-82dd-f994aaf3ddf5"],
Cell[361768, 6552, 72386, 1226, 517, 38692, 673, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "5eb1095d-850b-4d51-9572-48da5b0f1770"],
Cell[434157, 7780, 403, 7, 22, "Print", "ExpressionUUID" -> \
"d47762e0-ae77-4b44-aaa7-4572ebfec43e"],
Cell[434563, 7789, 423, 7, 22, "Print", "ExpressionUUID" -> \
"4581f486-7222-4b6c-9555-4f9cebf2667a"],
Cell[434989, 7798, 409, 7, 22, "Print", "ExpressionUUID" -> \
"aa240a45-7873-443c-8678-f79d8cff2483"],
Cell[435401, 7807, 72535, 1229, 517, 38719, 674, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "74045acf-63e6-44f1-a89f-ae459629338c"],
Cell[507939, 9038, 405, 7, 22, "Print", "ExpressionUUID" -> \
"ad69351b-baee-4c5c-ac07-75133423c909"],
Cell[508347, 9047, 423, 7, 22, "Print", "ExpressionUUID" -> \
"39f563ef-c774-4308-aa7a-d96a449e9046"],
Cell[508773, 9056, 409, 7, 22, "Print", "ExpressionUUID" -> \
"1dcc9103-5a82-4a18-8428-5954ae36457a"],
Cell[509185, 9065, 80438, 1359, 517, 45825, 791, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "cbc4c294-ebf0-4eee-8c04-17fabf6fb5de"],
Cell[589626, 10426, 403, 7, 22, "Print", "ExpressionUUID" -> \
"0edfcd3a-687d-4fbe-a98e-4233184cac2f"],
Cell[590032, 10435, 421, 7, 22, "Print", "ExpressionUUID" -> \
"c238fa4a-7381-4aa5-b5f7-6282664504be"],
Cell[590456, 10444, 409, 7, 22, "Print", "ExpressionUUID" -> \
"e0abe8e6-a0f6-437f-8ec1-93e586694038"],
Cell[590868, 10453, 66216, 1126, 517, 35471, 621, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "1414f909-82a8-4e5c-bf16-fbeb21bf6ff7"],
Cell[657087, 11581, 405, 7, 22, "Print", "ExpressionUUID" -> \
"f9fe9258-c3b8-4d79-a1b3-9ca907165ee6"],
Cell[657495, 11590, 421, 7, 22, "Print", "ExpressionUUID" -> \
"95726722-ce2b-4a15-83f2-72ed8f89d235"],
Cell[657919, 11599, 409, 7, 22, "Print", "ExpressionUUID" -> \
"491f710f-3721-47e0-a97e-ea3c496ba2d6"],
Cell[658331, 11608, 79842, 1348, 517, 45040, 777, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "4c7030ba-779e-41b8-ba68-f54d050a99fe"],
Cell[738176, 12958, 405, 7, 22, "Print", "ExpressionUUID" -> \
"89c1a25a-a9c0-4265-ad5a-3156cac20c19"],
Cell[738584, 12967, 421, 7, 22, "Print", "ExpressionUUID" -> \
"1ed908d4-f275-4db8-9e98-871869c1c170"],
Cell[739008, 12976, 407, 7, 22, "Print", "ExpressionUUID" -> \
"ba030536-1b90-4d79-8fbc-c0a74a1cd00a"],
Cell[739418, 12985, 79752, 1347, 517, 45139, 779, "CachedBoxData", "BoxData", \
"Print", "ExpressionUUID" -> "bbdbea7f-391f-4c2c-960e-77f8e7be7963"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[819231, 14339, 237, 4, 70, "Section", "ExpressionUUID" -> \
"cfb7265c-257e-4a07-a651-7b79656e917f"],
Cell[819471, 14345, 1008, 17, 106, "Text", "ExpressionUUID" -> \
"cdec59e9-4b15-4af8-b20b-a9defc5f7f20"],
Cell[CellGroupData[{
Cell[820504, 14366, 12761, 342, 1028, "Input", "ExpressionUUID" -> \
"91f2d58a-380d-489b-98c7-0d32526e0c15"],
Cell[CellGroupData[{
Cell[833290, 14712, 4206, 90, 86, "Print", "ExpressionUUID" -> \
"c9faf8f2-7244-47e5-8b38-72702a62c6f9"],
Cell[837499, 14804, 746, 14, 22, "Print", "ExpressionUUID" -> \
"66ad4dda-1cba-4489-b1aa-14255a0896be"],
Cell[838248, 14820, 716, 13, 22, "Print", "ExpressionUUID" -> \
"29e8bb3d-a8e0-40dc-8d4f-4167ca20adc3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

